"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const Image_1 = require("../Image");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Avatar.scss");
const avatars = require("./images");
const STYLE_CLASSES = ['one', 'two', 'three', 'four', 'five', 'six'];
const AVATAR_IMAGES = Object.keys(avatars).map((key) => avatars[key]);
class Avatar extends React.Component {
    render() {
        const { name, source, initials, customer, size = 'medium', accessibilityLabel, theme, } = this.props;
        const nameString = name || initials;
        let finalSource;
        let label;
        if (accessibilityLabel) {
            label = accessibilityLabel;
        }
        else if (name) {
            label = name;
        }
        else if (initials) {
            label = `Avatar with initials ${initials.split('').join(' ')}`;
        }
        else {
            label = 'Avatar';
        }
        if (source) {
            finalSource = source;
        }
        else if (customer) {
            finalSource = customerPlaceholder(nameString);
        }
        const className = styles_1.classNames(theme.avatar, theme[styles_1.variationName('style', styleClass(nameString))], source && theme.hasImage, size && theme[styles_1.variationName('size', size)]);
        let content = null;
        if (finalSource) {
            content = React.createElement(Image_1.default, { className: theme.Image, source: finalSource, alt: "", role: "presentation" });
        }
        else if (initials) {
            content = React.createElement("span", { "aria-hidden": true, className: theme.Initials }, initials);
        }
        return React.createElement("div", { "aria-label": label, role: "img", className: className }, content);
    }
}
function styleClass(name) {
    return name
        ? STYLE_CLASSES[name.charCodeAt(0) % STYLE_CLASSES.length]
        : STYLE_CLASSES[0];
}
function customerPlaceholder(name) {
    return name
        ? AVATAR_IMAGES[name.charCodeAt(0) % AVATAR_IMAGES.length]
        : AVATAR_IMAGES[0];
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.AVATAR, baseTheme)(Avatar);
