"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const VisuallyHidden_1 = require("../VisuallyHidden");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Badge.scss");
const PROGRESS_LABELS = {
    incomplete: 'Incomplete',
    partiallyComplete: 'Partially complete',
    complete: 'Complete',
};
const STATUS_LABELS = {
    info: 'Info',
    success: 'Success',
    warning: 'Warning',
    attention: 'Attention',
};
const badge = ({ children, status, progress, theme }) => {
    const className = styles_1.classNames(theme.badge, status && theme[styles_1.variationName('status', status)], progress && theme[styles_1.variationName('progress', progress)]);
    const role = progress ? PROGRESS_LABELS[progress] : 'badge';
    const statusLabelMarkup = status
        ? React.createElement(VisuallyHidden_1.default, null,
            STATUS_LABELS[status],
            " ",
            children)
        : null;
    const pipMarkup = progress
        ? (React.createElement("span", { className: theme.pip },
            React.createElement(VisuallyHidden_1.default, null,
                PROGRESS_LABELS[progress],
                " ",
                children)))
        : null;
    return (React.createElement("span", { className: className, role: role },
        statusLabelMarkup,
        pipMarkup,
        children));
};
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.BADGE, baseTheme)(badge);
