"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const Button_1 = require("../Button");
const Heading_1 = require("../Heading");
const ButtonGroup_1 = require("../ButtonGroup");
const UnstyledLink_1 = require("../UnstyledLink");
const Icon_1 = require("../Icon");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Banner.scss");
const circle_check_mark_svg_1 = require("./icons/circle-check-mark.svg");
const flag_svg_1 = require("./icons/flag.svg");
const circle_alert_svg_1 = require("./icons/circle-alert.svg");
const circle_barred_svg_1 = require("./icons/circle-barred.svg");
const confetti_svg_1 = require("./icons/confetti.svg");
const banner = ({ ariaLabel, icon, action, secondaryAction, title, children, status, onDismiss, theme, }) => {
    let color;
    let defaultIcon;
    switch (status) {
        case 'success':
            color = 'greenDark';
            defaultIcon = circle_check_mark_svg_1.default;
            break;
        case 'info':
            color = 'tealDark';
            defaultIcon = flag_svg_1.default;
            break;
        case 'warning':
            color = 'yellowDark';
            defaultIcon = circle_alert_svg_1.default;
            break;
        case 'critical':
            color = 'redDark';
            defaultIcon = circle_barred_svg_1.default;
            break;
        default:
            color = 'ink';
            defaultIcon = confetti_svg_1.default;
    }
    const className = styles_1.classNames(theme.banner, status && theme[styles_1.variationName('status', status)], onDismiss && theme.hasDismiss);
    const id = uniqueID();
    const iconName = icon || defaultIcon;
    let headingMarkup = null;
    let headingID;
    if (title) {
        headingID = `${id}Heading`;
        headingMarkup = (React.createElement("div", { className: theme.heading, id: headingID },
            React.createElement(Heading_1.default, { element: "h6" }, title)));
    }
    const secondaryActionMarkup = secondaryAction
        ? secondaryActionFrom(secondaryAction, theme)
        : null;
    const actionMarkup = action
        ? (React.createElement("div", { className: theme.actions },
            React.createElement(ButtonGroup_1.default, null,
                Button_1.buttonFrom(action, { outline: true }),
                secondaryActionMarkup)))
        : null;
    let contentMarkup = null;
    let contentID;
    if (children || actionMarkup) {
        contentID = `${id}Content`;
        contentMarkup = (React.createElement("div", { className: theme.content, id: contentID, "aria-label": ariaLabel },
            children,
            actionMarkup));
    }
    const dismissButton = onDismiss
        ? (React.createElement("div", { className: theme.dismiss },
            React.createElement(Button_1.default, { plain: true, icon: "cancelSmall", accessibilityLabel: "Dismiss notification", onClick: onDismiss })))
        : null;
    return (React.createElement("div", { className: className, tabIndex: 0, role: `banner ${status}`, "aria-labelledby": headingID, "aria-describedby": contentID },
        dismissButton,
        React.createElement("div", { className: theme.ribbon },
            React.createElement(Icon_1.default, { source: iconName, color: color, backdrop: true })),
        React.createElement("div", null,
            headingMarkup,
            contentMarkup)));
};
let index = 1;
function uniqueID() {
    return `banner${index += 1}`;
}
function secondaryActionFrom(action, theme) {
    if (action.url) {
        return (React.createElement(UnstyledLink_1.default, { className: theme.secondaryAction, url: action.url },
            React.createElement("span", { className: theme.text }, action.content)));
    }
    return (React.createElement("button", { className: theme.secondaryAction, onClick: action.onAction },
        React.createElement("span", { className: theme.text }, action.content)));
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.BANNER, baseTheme)(banner);
