"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const react_utilities_1 = require("@shopify/react-utilities");
const UnstyledLink_1 = require("../UnstyledLink");
const Icon_1 = require("../Icon");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Button.scss");
const button = ({ url, disabled, children, accessibilityLabel, onClick, onFocus, onBlur, external, icon, primary, outline, destructive, disclosure, plain, submit, size, fullWidth, style, theme, }) => {
    const className = react_utilities_1.classNames(theme.button, primary && theme.primary, outline && theme.outline, destructive && theme.destructive, disabled && theme.disabled, plain && theme.plain, size && theme[react_utilities_1.variationName('size', size)], fullWidth && theme.fullWidth, icon && children == null && theme.iconOnly);
    const disclosureIconMarkup = disclosure
        ? React.createElement("span", { className: theme.icon },
            React.createElement(Icon_1.default, { source: "caretDown" }))
        : null;
    const iconMarkup = icon
        ? React.createElement("span", { className: theme.icon },
            React.createElement(Icon_1.default, { source: icon }))
        : null;
    const childMarkup = children ? React.createElement("span", null, children) : null;
    const content = iconMarkup || disclosureIconMarkup
        ? (React.createElement("span", { className: theme.content },
            iconMarkup,
            childMarkup,
            disclosureIconMarkup))
        : React.createElement("span", { className: theme.content }, childMarkup);
    const type = submit ? 'submit' : 'button';
    return (url
        ? (React.createElement(UnstyledLink_1.default, { url: url, external: external, onClick: onClick, onFocus: onFocus, onBlur: onBlur, onMouseUp: handleMouseUp, className: className, disabled: disabled, "aria-label": accessibilityLabel, style: style }, content))
        : (React.createElement("button", { type: type, onClick: onClick, onFocus: onFocus, onBlur: onBlur, onMouseUp: handleMouseUp, className: className, disabled: disabled, "aria-label": accessibilityLabel, style: style }, content)));
};
const THEMEDBUTTON = react_css_themr_1.themr(ThemeIdentifiers_1.BUTTON, baseTheme)(button);
function handleMouseUp({ currentTarget }) {
    currentTarget.blur();
}
function buttonsFrom(actions, overrides = {}) {
    if (actions.length != null) {
        return actions.map((action, index) => buttonFrom(action, overrides, index));
    }
    else {
        return buttonFrom(actions, overrides);
    }
}
exports.buttonsFrom = buttonsFrom;
function buttonFrom(_a, overrides, key) {
    var { content, onAction } = _a, action = tslib_1.__rest(_a, ["content", "onAction"]);
    return (React.createElement(THEMEDBUTTON, Object.assign({ key: key, children: content, onClick: onAction }, action, overrides)));
}
exports.buttonFrom = buttonFrom;
exports.default = THEMEDBUTTON;
