"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Button_1 = require("./../Button");
describe('<Button />', () => {
    describe('onClick()', () => {
        it('is called when the button is clicked', () => {
            const spy = jest.fn();
            enzyme_1.shallow(React.createElement(Button_1.default, { onClick: spy }, "Test")).simulate('click');
            expect(spy).toHaveBeenCalled();
        });
    });
    describe('onFocus()', () => {
        it('is called when the button is focused', () => {
            const spy = jest.fn();
            enzyme_1.shallow(React.createElement(Button_1.default, { onFocus: spy }, "Test")).simulate('focus');
            expect(spy).toHaveBeenCalled();
        });
    });
    describe('onBlur()', () => {
        it('is called when the button is blurred', () => {
            const spy = jest.fn();
            enzyme_1.shallow(React.createElement(Button_1.default, { onBlur: spy }, "Test")).simulate('blur');
            expect(spy).toHaveBeenCalled();
        });
    });
    describe('disabled', () => {
        it('sets the disabled attribute on the button', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, { disabled: true }, "Disabled test"));
            expect(button.prop('disabled')).toBe(true);
        });
        it('sets the disabled attribute on the button', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, { disabled: false }, "Disabled test"));
            expect(button.prop('disabled')).toBeFalsy();
        });
    });
    describe('style', () => {
        it('sets the style attribute on the button to color: red ', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, { style: { color: 'red' } }, "Disabled test"));
            expect(button.prop('style')).toMatchObject({ color: 'red' });
        });
        it('sets the style attribute on the button to undefined', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, null, "Disabled test"));
            expect(button.prop('style')).toBeUndefined();
        });
    });
    describe('submit', () => {
        it('sets the button’s type to submit', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, { submit: true }, "Submit test"));
            expect(button.prop('submit')).toBe(true);
        });
        it('sets the button’s type to button when submit is not true', () => {
            let button = enzyme_1.shallow(React.createElement(Button_1.default, null, "Button test"));
            expect(button.prop('submit')).toBe(undefined);
            button = enzyme_1.shallow(React.createElement(Button_1.default, { submit: false }, "Button test"));
            expect(button.prop('submit')).toBe(false);
        });
    });
    describe('accessibilityLabel', () => {
        it('sets the aria-label on the button', () => {
            const button = enzyme_1.shallow(React.createElement(Button_1.default, { accessibilityLabel: "This deletes a thing", icon: "delete" }));
            expect(button.prop('accessibilityLabel')).toBe('This deletes a thing');
        });
    });
});
