"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Caption_1 = require("./../Caption");
describe('<Caption />', () => {
    describe('When no child provided', () => {
        const captionWrapper = enzyme_1.mount(React.createElement(Caption_1.default, null));
        it('It should have renderer blank p', () => {
            expect(captionWrapper.find('p').length).toBe(1);
            expect(captionWrapper.find('p').text()).toBe('');
        });
        it('It should not have child prop', () => {
            expect(captionWrapper.prop('children')).toBeUndefined();
        });
        it('p should not have class', () => {
            expect(captionWrapper.find('p').at(0).hasClass('caption')).toBe(false);
        });
    });
    describe('When child provided', () => {
        const captionWrapper = enzyme_1.mount(React.createElement(Caption_1.default, null, "text12"));
        it('It should have renderer p with child', () => {
            expect(captionWrapper.find('p').length).toBe(1);
            expect(captionWrapper.find('p').text()).toBe('text12');
        });
        it('It should have child prop', () => {
            expect(captionWrapper.prop('children')).toBe('text12');
        });
        it('p should not have class', () => {
            expect(captionWrapper.find('p').at(0).hasClass('caption')).toBe(false);
        });
    });
    describe('When child and theme provided', () => {
        const theme = {
            caption: 'caption',
        };
        const captionWrapper = enzyme_1.mount(React.createElement(Caption_1.default, { theme: theme }, "text12"));
        it('It should have renderer p with child', () => {
            expect(captionWrapper.find('p').length).toBe(1);
            expect(captionWrapper.find('p').text()).toBe('text12');
        });
        it('It should have child prop', () => {
            expect(captionWrapper.prop('children')).toBe('text12');
        });
        it('p should have a class', () => {
            expect(captionWrapper.find('p').at(0).hasClass('caption')).toBe(true);
        });
    });
});
