"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const Button_1 = require("../Button");
const ButtonGroup_1 = require("../ButtonGroup");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const Header_1 = require("./Header");
const Section_1 = require("./Section");
const baseTheme = require("./Card.scss");
class Card extends React.PureComponent {
    render() {
        const { children, title, subdued, sectioned, actions, primaryFooterAction, secondaryFooterAction, theme, } = this.props;
        const className = styles_1.classNames(theme.card, subdued && theme.subdued);
        const headerMarkup = title
            ? React.createElement(Header_1.default, { actions: actions }, title)
            : null;
        const content = sectioned
            ? React.createElement(Section_1.default, null, children)
            : children;
        const primaryFooterActionMarkup = primaryFooterAction
            ? Button_1.buttonFrom(primaryFooterAction, { primary: true })
            : null;
        const secondaryFooterActionMarkup = secondaryFooterAction
            ? Button_1.buttonFrom(secondaryFooterAction)
            : null;
        const footerMarkup = primaryFooterActionMarkup || secondaryFooterActionMarkup
            ? (React.createElement("div", { className: theme.footer },
                React.createElement(ButtonGroup_1.default, null,
                    primaryFooterActionMarkup,
                    secondaryFooterActionMarkup)))
            : null;
        return (React.createElement("div", { className: className },
            headerMarkup,
            content,
            footerMarkup));
    }
}
Card.Section = Section_1.default;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.CARD, baseTheme)(Card);
