"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Card_1 = require("../Card");
const Section_1 = require("../Section");
describe('<Card /> Test Suit', () => {
    const theme = {
        card: 'Card',
        subdued: 'subdued',
        header: 'Header',
        section: 'Section',
        sectionHeader: 'SectionHeader',
        footer: 'Footer',
    };
    it('should verify that Card has <h2> tag for title', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true, subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.find('h2').length).toBe(1);
    });
    it('should verify Card title', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true, subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.prop('title')).toBe('Online store dashboard - Card');
    });
    it('should verify sectioned when it is set', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true, subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.prop('sectioned')).toBe(true);
    });
    it('should verify sectioned when it is not set', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.prop('sectioned')).toBeFalsy();
        cardWrapper.setProps({ sectioned: false });
        expect(cardWrapper.prop('sectioned')).toBe(false);
    });
    it('should verify when subdued is set', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true, subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.prop('subdued')).toBe(true);
    });
    it('should verify when subdued is no set', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(cardWrapper.prop('subdued')).toBeFalsy();
    });
    it('should verify when actions is called', () => {
        const spy = jest.fn();
        const action = {
            content: 'Action Content',
            onAction: () => { spy(); },
        };
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", actions: [action] },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        cardWrapper.find('button').at(1).simulate('click');
        expect(spy).toHaveBeenCalled();
    });
    it('should verify that primaryFooterAction is called', () => {
        const spy = jest.fn();
        const action = {
            content: 'Action Content',
            onAction: () => { spy(); },
        };
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", primaryFooterAction: action },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        cardWrapper.find('button').at(1).simulate('click');
        expect(spy).toHaveBeenCalled();
    });
    it('should verify that secondaryFooterAction is called', () => {
        const spy = jest.fn();
        const action = {
            content: 'Action Content',
            onAction: () => { spy(); },
        };
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", secondaryFooterAction: action },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        cardWrapper.find('button').at(1).simulate('click');
        expect(spy).toHaveBeenCalled();
    });
    it('should verify that sectioned is boolean type', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(typeof cardWrapper.prop('sectioned')).toBe('boolean');
    });
    it('should verify that subdued is boolean type', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", subdued: true },
            React.createElement("p", null, "View a summary of your online store\u2019s performance.")));
        expect(typeof cardWrapper.prop('subdued')).toBe('boolean');
    });
    it('should verify that Card can have multiple sections with title', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true, theme: theme },
            React.createElement(Section_1.default, { title: "Reports", theme: theme },
                React.createElement("p", null, "View a summary of your online store\u2019s performance.")),
            React.createElement(Section_1.default, { title: "Summary Reports", theme: theme },
                React.createElement("p", null, "View a summary of your online store\u2019s performance, including sales, visitors, top products, and referrals."))));
        expect(cardWrapper.prop('sectioned')).toBe(true);
        expect(cardWrapper.find('div').at(3).text()).toBe('ReportsView a summary of your online store’s performance.');
        expect(cardWrapper.find('div').at(5).text()).toBe('Summary ReportsView a summary of your online store’s performance, including sales, visitors, top products, and referrals.');
        expect(cardWrapper.find('h3').length).toBe(2);
        expect(cardWrapper.find('p').length).toBe(2);
    });
    it('should verify that Card is set with subdued option.', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true },
            React.createElement(Section_1.default, { title: "Reports", subdued: true },
                React.createElement("p", null, "View a summary of your online store\u2019s performance.")),
            React.createElement(Section_1.default, { title: "Summary Reports", subdued: true },
                React.createElement("p", null, "View a summary of your online store\u2019s performance, including sales, visitors, top products, and referrals."))));
        expect(cardWrapper.find('h3').length).toBe(2);
        expect(cardWrapper.find('p').length).toBe(2);
        expect(cardWrapper.find('h3').at(0).text()).toBe('Reports');
        expect(cardWrapper.find('h3').at(1).text()).toBe('Summary Reports');
    });
    it('should verify that Card is set with theme.', () => {
        const cardWrapper = enzyme_1.mount(React.createElement(Card_1.default, { title: "Online store dashboard - Card", sectioned: true },
            React.createElement(Section_1.default, { title: "Reports", subdued: true },
                React.createElement("p", null, "View a summary of your online store\u2019s performance.")),
            React.createElement(Section_1.default, { title: "Summary Reports", subdued: true, theme: theme },
                React.createElement("p", null, "View a summary of your online store\u2019s performance, including sales, visitors, top products, and referrals."))));
        expect(cardWrapper.find('h3').length).toBe(2);
        expect(cardWrapper.find('p').length).toBe(2);
        expect(cardWrapper.find('h3').at(0).text()).toBe('Reports');
        expect(cardWrapper.find('h3').at(1).text()).toBe('Summary Reports');
    });
});
