"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const other_1 = require("@shopify/javascript-utilities/other");
const Choice_1 = require("../Choice");
const Icon_1 = require("../Icon");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const checkmark_svg_1 = require("./icons/checkmark.svg");
const baseTheme = require("./Checkbox.scss");
const getUniqueID = other_1.createUniqueIDFactory('Checkbox');
const checkbox = ({ id = getUniqueID(), label, labelHidden, helpText, checked, error, disabled, onChange, onFocus, onBlur, name, value, theme, }) => {
    function handleChange(event) {
        if (onChange == null) {
            return;
        }
        const { currentTarget } = event;
        onChange(currentTarget.checked);
    }
    const describedBy = [];
    if (typeof error === 'string') {
        describedBy.push(Choice_1.errorID(id));
    }
    if (helpText) {
        describedBy.push(Choice_1.helpTextID(id));
    }
    const className = styles_1.classNames(theme.checkbox, error && theme.error);
    return (React.createElement(Choice_1.default, { id: id, label: label, labelHidden: labelHidden, helpText: helpText, error: error },
        React.createElement("div", { className: className },
            React.createElement("input", { id: id, name: name, value: value, type: "checkbox", checked: checked, disabled: disabled, className: theme.input, onChange: handleChange, onFocus: onFocus, onBlur: onBlur, "aria-invalid": error != null, "aria-describedby": describedBy.length ? describedBy.join(' ') : undefined, "aria-checked": checked }),
            React.createElement("div", { className: theme.backdrop }),
            React.createElement("div", { className: theme.icon },
                React.createElement(Icon_1.default, { source: checkmark_svg_1.default })))));
};
exports.UnthemedCheckbox = checkbox;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.CHECKBOX, baseTheme)(checkbox);
