"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const Icon_1 = require("../Icon");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Choice.scss");
const choice = ({ id, label, error, children, labelHidden, helpText, theme, }) => {
    const className = styles_1.classNames(theme.choice, labelHidden && theme.labelHidden);
    const labelMarkup = (React.createElement("label", { className: className, htmlFor: id },
        React.createElement("div", { className: theme.control }, children),
        React.createElement("div", { className: theme.label }, label)));
    const helpTextMarkup = helpText
        ? React.createElement("div", { className: theme.helpText, id: helpTextID(id) }, helpText)
        : null;
    const errorMarkup = typeof error === 'string'
        ? (React.createElement("div", { className: theme.error, id: errorID(id) },
            React.createElement("div", { className: theme.errorIcon },
                React.createElement(Icon_1.default, { source: "alert" })),
            error))
        : null;
    const descriptionMarkup = helpTextMarkup || errorMarkup
        ? (React.createElement("div", { className: theme.descriptions },
            errorMarkup,
            helpTextMarkup))
        : null;
    return descriptionMarkup
        ? (React.createElement("div", null,
            labelMarkup,
            descriptionMarkup))
        : labelMarkup;
};
function helpTextID(id) {
    return `${id}HelpText`;
}
exports.helpTextID = helpTextID;
function errorID(id) {
    return `${id}Error`;
}
exports.errorID = errorID;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.CHOICE, baseTheme)(choice);
