"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const other_1 = require("@shopify/javascript-utilities/other");
const Checkbox_1 = require("../Checkbox");
const RadioButton_1 = require("../RadioButton");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./ChoiceList.scss");
const getUniqueID = other_1.createUniqueIDFactory('ChoiceList');
const choiceList = ({ title, titleHidden, allowMultiple, choices, selected, onChange = other_1.noop, theme, name = getUniqueID(), }) => {
    const CONTROLCOMPONENT = allowMultiple ? Checkbox_1.default : RadioButton_1.default;
    const finalName = allowMultiple ? `${name}[]` : name;
    const className = styles_1.classNames(theme.choiceList, titleHidden && theme.titleHidden);
    const titleMarkup = title
        ? React.createElement("legend", { className: theme.title }, title)
        : null;
    const choicesMarkup = choices.map((choice) => {
        const key = choice.value;
        const value = choice.value;
        const label = choice.label;
        function handleChange(checked) {
            onChange(updateSelectedChoices(choice, checked, selected, allowMultiple));
        }
        return (React.createElement("li", { key: key },
            React.createElement(CONTROLCOMPONENT, { name: finalName, value: value, label: label, checked: choiceIsSelected(choice, selected), onChange: handleChange })));
    });
    return (React.createElement("fieldset", { className: className },
        titleMarkup,
        React.createElement("ul", { className: theme.choices }, choicesMarkup)));
};
function choiceIsSelected({ value }, selected) {
    return selected.indexOf(value) >= 0;
}
function updateSelectedChoices({ value }, checked, selected, allowMultiple = false) {
    if (checked) {
        return allowMultiple ? [...selected, value] : [value];
    }
    return selected.filter(selectedChoice => selectedChoice !== value);
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.CHOICE_LIST, baseTheme)(choiceList);
