"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Chip_1 = require("../../Chip");
const ClickableChip_1 = require("../ClickableChip");
const theme = {
    chip: 'chip',
};
describe('<ClickableChip />', () => {
    describe('when default props are provided', () => {
        it('basic clickablechip should be rendered with default props', () => {
            const onChipClick = jest.fn();
            const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick, theme: theme }));
            expect(clickablechipWrapper.find('div')).toHaveLength(1);
            expect(clickablechipWrapper.find('span')).toHaveLength(2);
            expect(clickablechipWrapper.find('span').at(0).hasClass(''));
            expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
            expect(clickablechipWrapper.find('a')).toHaveLength(1);
        });
    });
    describe('chip property', () => {
        describe('when set', () => {
            it('should verify clickablechip when chip is set', () => {
                const onChipClick = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick, theme: theme }));
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
    });
    describe('onClick() property', () => {
        describe('when set', () => {
            it('should verify clickablechip when onClick() is set', () => {
                const onChipClick = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick, theme: theme }));
                clickablechipWrapper.find('a').simulate('click');
                expect(onChipClick).toHaveBeenCalledTimes(1);
                expect(onChipClick).toHaveBeenCalled();
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
        describe('when not set', () => {
            it('should verify clickablechip when onClick() is not set', () => {
                const onChipfocus = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipfocus, theme: theme }));
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
    });
    describe('all property', () => {
        describe('when set', () => {
            it('should verify clickablechip when all props are set', () => {
                const onChipClick = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick, theme: theme }));
                clickablechipWrapper.find('a').simulate('click');
                expect(onChipClick).toHaveBeenCalledTimes(1);
                expect(onChipClick).toHaveBeenCalled();
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
    });
    describe('theme property', () => {
        describe('when not set', () => {
            it('should verify choice when theme is not set', () => {
                const onChipClick = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick }));
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
        describe('when set', () => {
            it('should verify choice when theme is set', () => {
                const onChipClick = jest.fn();
                const clickablechipWrapper = enzyme_1.mount(React.createElement(ClickableChip_1.default, { chip: React.createElement(Chip_1.default, null, "Batman"), onClick: onChipClick, theme: theme }));
                expect(clickablechipWrapper.find('div')).toHaveLength(1);
                expect(clickablechipWrapper.find('span')).toHaveLength(2);
                expect(clickablechipWrapper.find('span').at(0).hasClass(''));
                expect(clickablechipWrapper.find('span').at(1).hasClass('Batman'));
                expect(clickablechipWrapper.find('a')).toHaveLength(1);
            });
        });
    });
});
