"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_addons_shallow_compare_1 = require("react-addons-shallow-compare");
const react_moment_proptypes_1 = require("react-moment-proptypes");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const moment_1 = require("moment");
const classnames_1 = require("classnames");
const react_css_themr_1 = require("react-css-themr");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const getPhrase_1 = require("../utils/getPhrase");
const Constants_1 = require("../Constants");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    day: react_moment_proptypes_1.default.momentObj,
    daySize: airbnb_prop_types_1.nonNegativeInteger,
    isOutsideDay: prop_types_1.default.bool,
    modifiers: prop_types_1.default.instanceOf(Set),
    isFocused: prop_types_1.default.bool,
    tabIndex: prop_types_1.default.oneOf([0, -1]),
    onDayClick: prop_types_1.default.func,
    onDayMouseEnter: prop_types_1.default.func,
    onDayMouseLeave: prop_types_1.default.func,
    renderDay: prop_types_1.default.func,
    // internationalization
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.CalendarDayPhrases)),
    theme: prop_types_1.default.any,
});
const defaultProps = {
    day: moment_1.default(),
    daySize: Constants_1.DAY_SIZE,
    isOutsideDay: false,
    modifiers: new Set(),
    isFocused: false,
    tabIndex: -1,
    onDayClick() { },
    onDayMouseEnter() { },
    onDayMouseLeave() { },
    renderDay: null,
    // internationalization
    phrases: defaultPhrases_1.CalendarDayPhrases,
};
// @themr(DATEPICKER, baseTheme)
class CalendarDay extends react_1.Component {
    shouldComponentUpdate(nextProps, nextState) {
        return react_addons_shallow_compare_1.default(this, nextProps, nextState);
    }
    componentDidUpdate(prevProps) {
        const { isFocused, tabIndex } = this.props;
        if (tabIndex === 0) {
            if (isFocused || tabIndex !== prevProps.tabIndex) {
                this.buttonRef.focus();
            }
        }
    }
    onDayClick(day, e) {
        const { onDayClick } = this.props;
        onDayClick(day, e);
    }
    onDayMouseEnter(day, e) {
        const { onDayMouseEnter } = this.props;
        onDayMouseEnter(day, e);
    }
    onDayMouseLeave(day, e) {
        const { onDayMouseLeave } = this.props;
        onDayMouseLeave(day, e);
    }
    render() {
        const { day, daySize, isOutsideDay, modifiers, renderDay, tabIndex, phrases: { chooseAvailableDate, dateIsUnavailable, }, theme, } = this.props;
        if (!day)
            return react_1.default.createElement("td", null);
        const className = classnames_1.default(theme['CalendarDay'], {
            [theme['CalendarDay--outside']]: isOutsideDay,
        }, Array.from(modifiers, mod => theme[`CalendarDay--${mod}`]));
        const formattedDate = `${day.format('dddd')}, ${day.format('LL')}`;
        let ariaLabel = getPhrase_1.default(chooseAvailableDate, {
            date: formattedDate,
        });
        if (Constants_1.BLOCKED_MODIFIER in modifiers && modifiers[Constants_1.BLOCKED_MODIFIER](day)) {
            ariaLabel = getPhrase_1.default(dateIsUnavailable, { date: formattedDate });
        }
        const daySizeStyles = {
            width: daySize,
            height: daySize - 1,
        };
        return (react_1.default.createElement("td", { className: className, style: daySizeStyles },
            react_1.default.createElement("button", { type: "button", ref: (ref) => { this.buttonRef = ref; }, className: theme["CalendarDay__button"], "aria-label": ariaLabel, onMouseEnter: (e) => { this.onDayMouseEnter(day, e); }, onMouseLeave: (e) => { this.onDayMouseLeave(day, e); }, onMouseUp: (e) => { e.currentTarget.blur(); }, onClick: (e) => { this.onDayClick(day, e); }, tabIndex: tabIndex }, renderDay ? renderDay(day) : day.format('D'))));
    }
}
// export default CalendarDay;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(CalendarDay);
CalendarDay.propTypes = propTypes;
CalendarDay.defaultProps = defaultProps;
