"use strict";
/* eslint react/no-array-index-key: 0 */
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_addons_shallow_compare_1 = require("react-addons-shallow-compare");
const react_moment_proptypes_1 = require("react-moment-proptypes");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const moment_1 = require("moment");
const classnames_1 = require("classnames");
const react_css_themr_1 = require("react-css-themr");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const CalendarDay_1 = require("./CalendarDay");
const getCalendarMonthWeeks_1 = require("../utils/getCalendarMonthWeeks");
const isSameDay_1 = require("../utils/isSameDay");
const toISODateString_1 = require("../utils/toISODateString");
const ScrollableOrientationShape_1 = require("../shapes/ScrollableOrientationShape");
const DayOfWeekShape_1 = require("../shapes/DayOfWeekShape");
const Constants_1 = require("../Constants");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    month: react_moment_proptypes_1.default.momentObj,
    isVisible: prop_types_1.default.bool,
    enableOutsideDays: prop_types_1.default.bool,
    modifiers: prop_types_1.default.object,
    orientation: ScrollableOrientationShape_1.default,
    daySize: airbnb_prop_types_1.nonNegativeInteger,
    onDayClick: prop_types_1.default.func,
    onDayMouseEnter: prop_types_1.default.func,
    onDayMouseLeave: prop_types_1.default.func,
    renderMonth: prop_types_1.default.func,
    renderDay: prop_types_1.default.func,
    firstDayOfWeek: DayOfWeekShape_1.default,
    focusedDate: react_moment_proptypes_1.default.momentObj,
    isFocused: prop_types_1.default.bool,
    // i18n
    monthFormat: prop_types_1.default.string,
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.CalendarDayPhrases)),
    theme: prop_types_1.default.any,
});
const defaultProps = {
    month: moment_1.default(),
    isVisible: true,
    enableOutsideDays: false,
    modifiers: {},
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    daySize: Constants_1.DAY_SIZE,
    onDayClick() { },
    onDayMouseEnter() { },
    onDayMouseLeave() { },
    renderMonth: null,
    renderDay: null,
    firstDayOfWeek: null,
    focusedDate: null,
    isFocused: false,
    // i18n
    monthFormat: 'MMMM YYYY',
    phrases: defaultPhrases_1.CalendarDayPhrases,
};
class CalendarMonth extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            weeks: getCalendarMonthWeeks_1.default(props.month, props.enableOutsideDays, props.firstDayOfWeek == null ? moment_1.default.localeData().firstDayOfWeek() : props.firstDayOfWeek),
        };
    }
    componentWillReceiveProps(nextProps) {
        const { month, enableOutsideDays, firstDayOfWeek } = nextProps;
        if (!month.isSame(this.props.month)
            || enableOutsideDays !== this.props.enableOutsideDays
            || firstDayOfWeek !== this.props.firstDayOfWeek) {
            this.setState({
                weeks: getCalendarMonthWeeks_1.default(month, enableOutsideDays, firstDayOfWeek == null ? moment_1.default.localeData().firstDayOfWeek() : firstDayOfWeek),
            });
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        return react_addons_shallow_compare_1.default(this, nextProps, nextState);
    }
    render() {
        const { month, monthFormat, orientation, isVisible, modifiers, onDayClick, onDayMouseEnter, onDayMouseLeave, renderMonth, renderDay, daySize, focusedDate, isFocused, phrases, theme, } = this.props;
        const { weeks } = this.state;
        const monthTitle = renderMonth ? renderMonth(month) : month.format(monthFormat);
        const calendarMonthClasses = classnames_1.default(theme['CalendarMonth'], {
            [theme['CalendarMonth--horizontal']]: orientation === Constants_1.HORIZONTAL_ORIENTATION,
            [theme['CalendarMonth--vertical']]: orientation === Constants_1.VERTICAL_ORIENTATION,
            [theme['CalendarMonth--vertical-scrollable']]: orientation === Constants_1.VERTICAL_SCROLLABLE,
        });
        return (react_1.default.createElement("div", { className: calendarMonthClasses, "data-visible": isVisible },
            react_1.default.createElement("table", null,
                react_1.default.createElement("caption", { className: `${theme["CalendarMonth__caption"]} ${theme["js-CalendarMonth__caption"]}` },
                    react_1.default.createElement("strong", null, monthTitle)),
                react_1.default.createElement("tbody", { className: theme["js-CalendarMonth__grid"] }, weeks.map((week, i) => (react_1.default.createElement("tr", { key: i }, week.map((day, dayOfWeek) => (react_1.default.createElement(CalendarDay_1.default, { day: day, daySize: daySize, isOutsideDay: !day || day.month() !== month.month(), tabIndex: isVisible && isSameDay_1.default(day, focusedDate) ? 0 : -1, isFocused: isFocused, key: dayOfWeek, onDayMouseEnter: onDayMouseEnter, onDayMouseLeave: onDayMouseLeave, onDayClick: onDayClick, renderDay: renderDay, phrases: phrases, modifiers: modifiers[toISODateString_1.default(day)] }))))))))));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(CalendarMonth);
CalendarMonth.propTypes = propTypes;
CalendarMonth.defaultProps = defaultProps;
