"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_addons_shallow_compare_1 = require("react-addons-shallow-compare");
const react_moment_proptypes_1 = require("react-moment-proptypes");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const moment_1 = require("moment");
const classnames_1 = require("classnames");
const consolidated_events_1 = require("consolidated-events");
const react_css_themr_1 = require("react-css-themr");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const CalendarMonth_1 = require("./CalendarMonth");
const isTransitionEndSupported_1 = require("../utils/isTransitionEndSupported");
const getTransformStyles_1 = require("../utils/getTransformStyles");
const getCalendarMonthWidth_1 = require("../utils/getCalendarMonthWidth");
const toISOMonthString_1 = require("../utils/toISOMonthString");
const isAfterDay_1 = require("../utils/isAfterDay");
const ScrollableOrientationShape_1 = require("../shapes/ScrollableOrientationShape");
const DayOfWeekShape_1 = require("../shapes/DayOfWeekShape");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const Constants_1 = require("../Constants");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    enableOutsideDays: prop_types_1.default.bool,
    firstVisibleMonthIndex: prop_types_1.default.number,
    initialMonth: react_moment_proptypes_1.default.momentObj,
    isAnimating: prop_types_1.default.bool,
    numberOfMonths: prop_types_1.default.number,
    modifiers: prop_types_1.default.object,
    orientation: ScrollableOrientationShape_1.default,
    onDayClick: prop_types_1.default.func,
    onDayMouseEnter: prop_types_1.default.func,
    onDayMouseLeave: prop_types_1.default.func,
    onMonthTransitionEnd: prop_types_1.default.func,
    renderMonth: prop_types_1.default.func,
    renderDay: prop_types_1.default.func,
    transformValue: prop_types_1.default.string,
    daySize: airbnb_prop_types_1.nonNegativeInteger,
    focusedDate: react_moment_proptypes_1.default.momentObj,
    isFocused: prop_types_1.default.bool,
    firstDayOfWeek: DayOfWeekShape_1.default,
    // i18n
    monthFormat: prop_types_1.default.string,
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.CalendarDayPhrases)),
    theme: prop_types_1.default.any,
});
const defaultProps = {
    enableOutsideDays: false,
    firstVisibleMonthIndex: 0,
    initialMonth: moment_1.default(),
    isAnimating: false,
    numberOfMonths: 1,
    modifiers: {},
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    onDayClick() { },
    onDayMouseEnter() { },
    onDayMouseLeave() { },
    onMonthTransitionEnd() { },
    renderMonth: null,
    renderDay: null,
    transformValue: 'none',
    daySize: Constants_1.DAY_SIZE,
    focusedDate: null,
    isFocused: false,
    firstDayOfWeek: null,
    // i18n
    monthFormat: 'MMMM YYYY',
    phrases: defaultPhrases_1.CalendarDayPhrases,
};
function getMonths(initialMonth, numberOfMonths, withoutTransitionMonths) {
    let month = initialMonth.clone();
    if (!withoutTransitionMonths)
        month = month.subtract(1, 'month');
    const months = [];
    for (let i = 0; i < (withoutTransitionMonths ? numberOfMonths : numberOfMonths + 2); i += 1) {
        months.push(month);
        month = month.clone().add(1, 'month');
    }
    return months;
}
class CalendarMonthGrid extends react_1.default.Component {
    constructor(props) {
        super(props);
        const withoutTransitionMonths = props.orientation === Constants_1.VERTICAL_SCROLLABLE;
        this.state = {
            months: getMonths(props.initialMonth, props.numberOfMonths, withoutTransitionMonths),
        };
        this.isTransitionEndSupported = isTransitionEndSupported_1.default();
        this.onTransitionEnd = this.onTransitionEnd.bind(this);
    }
    componentDidMount() {
        this.eventHandle = consolidated_events_1.addEventListener(this.container, 'transitionend', this.onTransitionEnd);
    }
    componentWillReceiveProps(nextProps) {
        const { initialMonth, numberOfMonths, orientation } = nextProps;
        const { months } = this.state;
        const hasMonthChanged = !this.props.initialMonth.isSame(initialMonth, 'month');
        const hasNumberOfMonthsChanged = this.props.numberOfMonths !== numberOfMonths;
        let newMonths = months;
        if (hasMonthChanged && !hasNumberOfMonthsChanged) {
            if (isAfterDay_1.default(initialMonth, this.props.initialMonth)) {
                newMonths = months.slice(1);
                newMonths.push(months[months.length - 1].clone().add(1, 'month'));
            }
            else {
                newMonths = months.slice(0, months.length - 1);
                newMonths.unshift(months[0].clone().subtract(1, 'month'));
            }
        }
        if (hasNumberOfMonthsChanged) {
            const withoutTransitionMonths = orientation === Constants_1.VERTICAL_SCROLLABLE;
            newMonths = getMonths(initialMonth, numberOfMonths, withoutTransitionMonths);
        }
        this.setState({
            months: newMonths,
        });
    }
    shouldComponentUpdate(nextProps, nextState) {
        return react_addons_shallow_compare_1.default(this, nextProps, nextState);
    }
    componentDidUpdate() {
        const { isAnimating, onMonthTransitionEnd } = this.props;
        // For IE9, immediately call onMonthTransitionEnd instead of
        // waiting for the animation to complete
        if (!this.isTransitionEndSupported && isAnimating) {
            onMonthTransitionEnd();
        }
    }
    componentWillUnmount() {
        consolidated_events_1.removeEventListener(this.eventHandle);
    }
    onTransitionEnd() {
        this.props.onMonthTransitionEnd();
    }
    render() {
        const { enableOutsideDays, firstVisibleMonthIndex, isAnimating, modifiers, numberOfMonths, monthFormat, orientation, transformValue, daySize, onDayMouseEnter, onDayMouseLeave, onDayClick, renderMonth, renderDay, onMonthTransitionEnd, firstDayOfWeek, focusedDate, isFocused, phrases, theme, } = this.props;
        const { months } = this.state;
        const isVertical = orientation === Constants_1.VERTICAL_ORIENTATION;
        const isVerticalScrollable = orientation === Constants_1.VERTICAL_SCROLLABLE;
        const isHorizontal = orientation === Constants_1.HORIZONTAL_ORIENTATION;
        const className = classnames_1.default(theme['CalendarMonthGrid'], {
            [theme['CalendarMonthGrid--horizontal']]: isHorizontal,
            [theme['CalendarMonthGrid--vertical']]: isVertical,
            [theme['CalendarMonthGrid--vertical-scrollable']]: isVerticalScrollable,
            [theme['CalendarMonthGrid--animating']]: isAnimating,
        });
        const calendarMonthWidth = getCalendarMonthWidth_1.default(daySize);
        const width = isVertical || isVerticalScrollable ?
            calendarMonthWidth :
            (numberOfMonths + 2) * calendarMonthWidth;
        const style = Object.assign({}, getTransformStyles_1.default(transformValue), { width });
        return (react_1.default.createElement("div", { ref: (ref) => { this.container = ref; }, className: className, style: style, onTransitionEnd: onMonthTransitionEnd }, months.map((month, i) => {
            const isVisible = (i >= firstVisibleMonthIndex) && (i < firstVisibleMonthIndex + numberOfMonths);
            const monthString = toISOMonthString_1.default(month);
            return (react_1.default.createElement(CalendarMonth_1.default, { key: monthString, month: month, isVisible: isVisible, enableOutsideDays: enableOutsideDays, modifiers: modifiers[monthString], monthFormat: monthFormat, orientation: orientation, onDayMouseEnter: onDayMouseEnter, onDayMouseLeave: onDayMouseLeave, onDayClick: onDayClick, renderMonth: renderMonth, renderDay: renderDay, firstDayOfWeek: firstDayOfWeek, daySize: daySize, focusedDate: isVisible ? focusedDate : null, isFocused: isFocused, phrases: phrases }));
        })));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(CalendarMonthGrid);
CalendarMonthGrid.propTypes = propTypes;
CalendarMonthGrid.defaultProps = defaultProps;
