"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const react_dom_1 = require("react-dom");
const react_addons_shallow_compare_1 = require("react-addons-shallow-compare");
const moment_1 = require("moment");
const classnames_1 = require("classnames");
const react_portal_1 = require("react-portal");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const consolidated_events_1 = require("consolidated-events");
const is_touch_device_1 = require("is-touch-device");
const react_css_themr_1 = require("react-css-themr");
const defaultPhrases_1 = require("../defaultPhrases");
const OutsideClickHandler_1 = require("./OutsideClickHandler");
const getResponsiveContainerStyles_1 = require("../utils/getResponsiveContainerStyles");
const isInclusivelyAfterDay_1 = require("../utils/isInclusivelyAfterDay");
const DateRangePickerInputController_1 = require("./DateRangePickerInputController");
const DayPickerRangeController_1 = require("./DayPickerRangeController");
const close_svg_1 = require("../svg/close.svg");
const DateRangePickerShape_1 = require("../shapes/DateRangePickerShape");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const Constants_1 = require("../Constants");
const propTypes = airbnb_prop_types_1.forbidExtraProps(DateRangePickerShape_1.default);
const defaultProps = {
    // required props for a functional interactive DateRangePicker
    startDate: null,
    endDate: null,
    focusedInput: null,
    // input related props
    startDateId: Constants_1.START_DATE,
    startDatePlaceholderText: 'Start Date',
    endDateId: Constants_1.END_DATE,
    endDatePlaceholderText: 'End Date',
    disabled: false,
    required: false,
    readOnly: false,
    screenReaderInputMessage: '',
    showClearDates: false,
    showDefaultInputIcon: false,
    customInputIcon: null,
    customArrowIcon: null,
    customCloseIcon: null,
    // calendar presentation and interaction related props
    renderMonth: null,
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    anchorDirection: Constants_1.ANCHOR_LEFT,
    horizontalMargin: 0,
    withPortal: false,
    withFullScreenPortal: false,
    initialVisibleMonth: null,
    numberOfMonths: 2,
    keepOpenOnDateSelect: false,
    reopenPickerOnClearDates: false,
    renderCalendarInfo: null,
    hideKeyboardShortcutsPanel: false,
    daySize: Constants_1.DAY_SIZE,
    isRTL: false,
    firstDayOfWeek: null,
    // navigation related props
    navPrev: null,
    navNext: null,
    onPrevMonthClick() { },
    onNextMonthClick() { },
    onClose() { },
    // day presentation and interaction related props
    renderDay: null,
    minimumNights: 1,
    enableOutsideDays: false,
    isDayBlocked: () => false,
    isOutsideRange: day => !isInclusivelyAfterDay_1.default(day, moment_1.default()),
    isDayHighlighted: () => false,
    // internationalization
    displayFormat: () => moment_1.default.localeData().longDateFormat('L'),
    monthFormat: 'MMMM YYYY',
    phrases: defaultPhrases_1.DateRangePickerPhrases,
};
class DateRangePicker extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            dayPickerContainerStyles: {},
            isDateRangePickerInputFocused: false,
            isDayPickerFocused: false,
            showKeyboardShortcuts: false,
        };
        this.isTouchDevice = false;
        this.onOutsideClick = this.onOutsideClick.bind(this);
        this.onDateRangePickerInputFocus = this.onDateRangePickerInputFocus.bind(this);
        this.onDayPickerFocus = this.onDayPickerFocus.bind(this);
        this.onDayPickerBlur = this.onDayPickerBlur.bind(this);
        this.showKeyboardShortcutsPanel = this.showKeyboardShortcutsPanel.bind(this);
        this.responsivizePickerPosition = this.responsivizePickerPosition.bind(this);
    }
    componentDidMount() {
        this.resizeHandle = consolidated_events_1.addEventListener(window, 'resize', this.responsivizePickerPosition, { passive: true });
        this.responsivizePickerPosition();
        if (this.props.focusedInput) {
            this.setState({
                isDateRangePickerInputFocused: true,
            });
        }
        this.isTouchDevice = is_touch_device_1.default();
    }
    shouldComponentUpdate(nextProps, nextState) {
        return react_addons_shallow_compare_1.default(this, nextProps, nextState);
    }
    componentDidUpdate(prevProps) {
        if (!prevProps.focusedInput && this.props.focusedInput && this.isOpened()) {
            // The date picker just changed from being closed to being open.
            this.responsivizePickerPosition();
        }
    }
    componentWillUnmount() {
        if (this.resizeHandle)
            consolidated_events_1.removeEventListener(this.resizeHandle);
    }
    onOutsideClick() {
        const { onFocusChange, onClose, startDate, endDate } = this.props;
        if (!this.isOpened())
            return;
        this.setState({
            isDateRangePickerInputFocused: false,
            isDayPickerFocused: false,
            showKeyboardShortcuts: false,
        });
        onFocusChange(null);
        onClose({ startDate, endDate });
    }
    onDateRangePickerInputFocus(focusedInput) {
        const { onFocusChange, withPortal, withFullScreenPortal } = this.props;
        if (focusedInput) {
            const moveFocusToDayPicker = withPortal || withFullScreenPortal || this.isTouchDevice;
            if (moveFocusToDayPicker) {
                this.onDayPickerFocus();
            }
            else {
                this.onDayPickerBlur();
            }
        }
        onFocusChange(focusedInput);
    }
    onDayPickerFocus() {
        const { focusedInput, onFocusChange } = this.props;
        if (!focusedInput)
            onFocusChange(Constants_1.START_DATE);
        this.setState({
            isDateRangePickerInputFocused: false,
            isDayPickerFocused: true,
            showKeyboardShortcuts: false,
        });
    }
    onDayPickerBlur() {
        this.setState({
            isDateRangePickerInputFocused: true,
            isDayPickerFocused: false,
            showKeyboardShortcuts: false,
        });
    }
    getDayPickerContainerClasses() {
        const { orientation, withPortal, withFullScreenPortal, anchorDirection, isRTL, theme, } = this.props;
        const dayPickerClassName = classnames_1.default(theme['DateRangePicker__picker'], {
            [theme['DateRangePicker__picker--direction-left']]: anchorDirection === Constants_1.ANCHOR_LEFT,
            [theme['DateRangePicker__picker--direction-right']]: anchorDirection === Constants_1.ANCHOR_RIGHT,
            [theme['DateRangePicker__picker--horizontal']]: orientation === Constants_1.HORIZONTAL_ORIENTATION,
            [theme['DateRangePicker__picker--vertical']]: orientation === Constants_1.VERTICAL_ORIENTATION,
            [theme['DateRangePicker__picker--portal']]: withPortal || withFullScreenPortal,
            [theme['DateRangePicker__picker--full-screen-portal']]: withFullScreenPortal,
            [theme['DateRangePicker__picker--rtl']]: isRTL,
        });
        return dayPickerClassName;
    }
    getDayPickerDOMNode() {
        return react_dom_1.default.findDOMNode(this.dayPicker); // eslint-disable-line react/no-find-dom-node
    }
    isOpened() {
        const { focusedInput } = this.props;
        return focusedInput === Constants_1.START_DATE || focusedInput === Constants_1.END_DATE;
    }
    responsivizePickerPosition() {
        if (!this.isOpened()) {
            return;
        }
        const { anchorDirection, horizontalMargin, withPortal, withFullScreenPortal } = this.props;
        const { dayPickerContainerStyles } = this.state;
        const isAnchoredLeft = anchorDirection === Constants_1.ANCHOR_LEFT;
        if (!withPortal && !withFullScreenPortal) {
            const containerRect = this.dayPickerContainer.getBoundingClientRect();
            const currentOffset = dayPickerContainerStyles[anchorDirection] || 0;
            const containerEdge = isAnchoredLeft ? containerRect[Constants_1.ANCHOR_RIGHT] : containerRect[Constants_1.ANCHOR_LEFT];
            this.setState({
                dayPickerContainerStyles: getResponsiveContainerStyles_1.default(anchorDirection, currentOffset, containerEdge, horizontalMargin),
            });
        }
    }
    showKeyboardShortcutsPanel() {
        this.setState({
            isDateRangePickerInputFocused: false,
            isDayPickerFocused: true,
            showKeyboardShortcuts: true,
        });
    }
    maybeRenderDayPickerWithPortal() {
        const { withPortal, withFullScreenPortal } = this.props;
        if (!this.isOpened()) {
            return null;
        }
        if (withPortal || withFullScreenPortal) {
            return (react_1.default.createElement(react_portal_1.default, { isOpened: true }, this.renderDayPicker()));
        }
        return this.renderDayPicker();
    }
    renderDayPicker() {
        const { isDayBlocked, isDayHighlighted, isOutsideRange, numberOfMonths, orientation, monthFormat, renderMonth, navPrev, navNext, onPrevMonthClick, onNextMonthClick, onDatesChange, onFocusChange, withPortal, withFullScreenPortal, daySize, enableOutsideDays, focusedInput, startDate, endDate, minimumNights, keepOpenOnDateSelect, renderDay, renderCalendarInfo, firstDayOfWeek, initialVisibleMonth, hideKeyboardShortcutsPanel, customCloseIcon, onClose, phrases, isRTL, theme, } = this.props;
        const { dayPickerContainerStyles, isDayPickerFocused, showKeyboardShortcuts } = this.state;
        const onOutsideClick = (!withFullScreenPortal && withPortal)
            ? this.onOutsideClick
            : undefined;
        const initialVisibleMonthThunk = initialVisibleMonth || (() => (startDate || endDate || moment_1.default()));
        const closeIcon = customCloseIcon || (react_1.default.createElement(close_svg_1.default, null));
        return (react_1.default.createElement("div", { ref: (ref) => { this.dayPickerContainer = ref; }, className: this.getDayPickerContainerClasses(), style: dayPickerContainerStyles, onClick: onOutsideClick },
            react_1.default.createElement(DayPickerRangeController_1.default, { ref: (ref) => { this.dayPicker = ref; }, orientation: orientation, enableOutsideDays: enableOutsideDays, numberOfMonths: numberOfMonths, onPrevMonthClick: onPrevMonthClick, onNextMonthClick: onNextMonthClick, onDatesChange: onDatesChange, onFocusChange: onFocusChange, onClose: onClose, focusedInput: focusedInput, startDate: startDate, endDate: endDate, monthFormat: monthFormat, renderMonth: renderMonth, withPortal: withPortal || withFullScreenPortal, daySize: daySize, initialVisibleMonth: initialVisibleMonthThunk, hideKeyboardShortcutsPanel: hideKeyboardShortcutsPanel, navPrev: navPrev, navNext: navNext, minimumNights: minimumNights, isOutsideRange: isOutsideRange, isDayHighlighted: isDayHighlighted, isDayBlocked: isDayBlocked, keepOpenOnDateSelect: keepOpenOnDateSelect, renderDay: renderDay, renderCalendarInfo: renderCalendarInfo, isFocused: isDayPickerFocused, showKeyboardShortcuts: showKeyboardShortcuts, onBlur: this.onDayPickerBlur, phrases: phrases, isRTL: isRTL, firstDayOfWeek: firstDayOfWeek }),
            withFullScreenPortal && (react_1.default.createElement("button", { className: theme["DateRangePicker__close"], type: "button", onClick: this.onOutsideClick, "aria-label": phrases.closeDatePicker },
                react_1.default.createElement("div", { className: theme["DateRangePicker__close"] }, closeIcon)))));
    }
    render() {
        const { startDate, startDateId, startDatePlaceholderText, endDate, endDateId, endDatePlaceholderText, focusedInput, screenReaderInputMessage, showClearDates, showDefaultInputIcon, customInputIcon, customArrowIcon, customCloseIcon, disabled, required, readOnly, phrases, isOutsideRange, minimumNights, withPortal, withFullScreenPortal, displayFormat, reopenPickerOnClearDates, keepOpenOnDateSelect, onDatesChange, onClose, isRTL, theme, } = this.props;
        const { isDateRangePickerInputFocused } = this.state;
        const onOutsideClick = (!withPortal && !withFullScreenPortal) ? this.onOutsideClick : undefined;
        return (react_1.default.createElement("div", { className: theme["DateRangePicker"] },
            react_1.default.createElement(OutsideClickHandler_1.default, { onOutsideClick: onOutsideClick },
                react_1.default.createElement(DateRangePickerInputController_1.default, { startDate: startDate, startDateId: startDateId, startDatePlaceholderText: startDatePlaceholderText, isStartDateFocused: focusedInput === Constants_1.START_DATE, endDate: endDate, endDateId: endDateId, endDatePlaceholderText: endDatePlaceholderText, isEndDateFocused: focusedInput === Constants_1.END_DATE, displayFormat: displayFormat, showClearDates: showClearDates, showCaret: !withPortal && !withFullScreenPortal, showDefaultInputIcon: showDefaultInputIcon, customInputIcon: customInputIcon, customArrowIcon: customArrowIcon, customCloseIcon: customCloseIcon, disabled: disabled, required: required, readOnly: readOnly, reopenPickerOnClearDates: reopenPickerOnClearDates, keepOpenOnDateSelect: keepOpenOnDateSelect, isOutsideRange: isOutsideRange, minimumNights: minimumNights, withFullScreenPortal: withFullScreenPortal, onDatesChange: onDatesChange, onFocusChange: this.onDateRangePickerInputFocus, onArrowDown: this.onDayPickerFocus, onQuestionMark: this.showKeyboardShortcutsPanel, onClose: onClose, phrases: phrases, screenReaderMessage: screenReaderInputMessage, isFocused: isDateRangePickerInputFocused, isRTL: isRTL }),
                this.maybeRenderDayPickerWithPortal())));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(DateRangePicker);
DateRangePicker.propTypes = propTypes;
DateRangePicker.defaultProps = defaultProps;
