"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const classnames_1 = require("classnames");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const react_css_themr_1 = require("react-css-themr");
const DateInput_1 = require("./DateInput");
const arrow_right_svg_1 = require("../svg/arrow-right.svg");
const arrow_left_svg_1 = require("../svg/arrow-left.svg");
const close_svg_1 = require("../svg/close.svg");
const calendar_svg_1 = require("../svg/calendar.svg");
const Constants_1 = require("../Constants");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    startDateId: prop_types_1.default.string,
    startDatePlaceholderText: prop_types_1.default.string,
    screenReaderMessage: prop_types_1.default.string,
    endDateId: prop_types_1.default.string,
    endDatePlaceholderText: prop_types_1.default.string,
    onStartDateFocus: prop_types_1.default.func,
    onEndDateFocus: prop_types_1.default.func,
    onStartDateChange: prop_types_1.default.func,
    onEndDateChange: prop_types_1.default.func,
    onStartDateShiftTab: prop_types_1.default.func,
    onEndDateTab: prop_types_1.default.func,
    onClearDates: prop_types_1.default.func,
    onArrowDown: prop_types_1.default.func,
    onQuestionMark: prop_types_1.default.func,
    startDate: prop_types_1.default.string,
    startDateValue: prop_types_1.default.string,
    endDate: prop_types_1.default.string,
    endDateValue: prop_types_1.default.string,
    isStartDateFocused: prop_types_1.default.bool,
    isEndDateFocused: prop_types_1.default.bool,
    showClearDates: prop_types_1.default.bool,
    disabled: prop_types_1.default.bool,
    required: prop_types_1.default.bool,
    readOnly: prop_types_1.default.bool,
    showCaret: prop_types_1.default.bool,
    showDefaultInputIcon: prop_types_1.default.bool,
    customInputIcon: prop_types_1.default.node,
    customArrowIcon: prop_types_1.default.node,
    customCloseIcon: prop_types_1.default.node,
    // accessibility
    isFocused: prop_types_1.default.bool,
    // i18n
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.DateRangePickerInputPhrases)),
    isRTL: prop_types_1.default.bool,
    theme: prop_types_1.default.object,
});
const defaultProps = {
    startDateId: Constants_1.START_DATE,
    endDateId: Constants_1.END_DATE,
    startDatePlaceholderText: 'Start Date',
    endDatePlaceholderText: 'End Date',
    screenReaderMessage: '',
    onStartDateFocus() { },
    onEndDateFocus() { },
    onStartDateChange() { },
    onEndDateChange() { },
    onStartDateShiftTab() { },
    onEndDateTab() { },
    onClearDates() { },
    onArrowDown() { },
    onQuestionMark() { },
    startDate: '',
    startDateValue: '',
    endDate: '',
    endDateValue: '',
    isStartDateFocused: false,
    isEndDateFocused: false,
    showClearDates: false,
    disabled: false,
    required: false,
    readOnly: false,
    showCaret: false,
    showDefaultInputIcon: false,
    customInputIcon: null,
    customArrowIcon: null,
    customCloseIcon: null,
    // accessibility
    isFocused: false,
    // i18n
    phrases: defaultPhrases_1.DateRangePickerInputPhrases,
    isRTL: false,
};
class DateRangePickerInput extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            isClearDatesHovered: false,
        };
        this.onClearDatesMouseEnter = this.onClearDatesMouseEnter.bind(this);
        this.onClearDatesMouseLeave = this.onClearDatesMouseLeave.bind(this);
    }
    onClearDatesMouseEnter() {
        this.setState({
            isClearDatesHovered: true,
        });
    }
    onClearDatesMouseLeave() {
        this.setState({
            isClearDatesHovered: false,
        });
    }
    render() {
        const { isClearDatesHovered } = this.state;
        const { startDate, startDateValue, startDateId, startDatePlaceholderText, screenReaderMessage, isStartDateFocused, onStartDateChange, onStartDateFocus, onStartDateShiftTab, endDate, endDateValue, endDateId, endDatePlaceholderText, isEndDateFocused, onEndDateChange, onEndDateFocus, onEndDateTab, onArrowDown, onQuestionMark, onClearDates, showClearDates, disabled, required, readOnly, showCaret, showDefaultInputIcon, customInputIcon, customArrowIcon, customCloseIcon, isFocused, phrases, isRTL, theme, } = this.props;
        const inputIcon = customInputIcon || (react_1.default.createElement(calendar_svg_1.default, null));
        const arrowIcon = customArrowIcon || (isRTL ? react_1.default.createElement(arrow_left_svg_1.default, null) : react_1.default.createElement(arrow_right_svg_1.default, null));
        const closeIcon = customCloseIcon || (react_1.default.createElement(close_svg_1.default, null));
        const screenReaderText = screenReaderMessage || phrases.keyboardNavigationInstructions;
        return (react_1.default.createElement("div", { className: classnames_1.default(theme['DateRangePickerInput'], {
                [theme['DateRangePickerInput--disabled']]: disabled,
                [theme['DateRangePickerInput--rtl']]: isRTL,
            }) },
            (showDefaultInputIcon || customInputIcon !== null) && (react_1.default.createElement("button", { type: "button", className: theme["DateRangePickerInput__calendar-icon"], disabled: disabled, "aria-label": phrases.focusStartDate, onClick: onArrowDown }, inputIcon)),
            react_1.default.createElement(DateInput_1.default, { id: startDateId, placeholder: startDatePlaceholderText, displayValue: startDate, inputValue: startDateValue, screenReaderMessage: screenReaderText, focused: isStartDateFocused, isFocused: isFocused, disabled: disabled, required: required, readOnly: readOnly, showCaret: showCaret, onChange: onStartDateChange, onFocus: onStartDateFocus, onKeyDownShiftTab: onStartDateShiftTab, onKeyDownArrowDown: onArrowDown, onKeyDownQuestionMark: onQuestionMark }),
            react_1.default.createElement("div", { className: theme["DateRangePickerInput__arrow"], "aria-hidden": "true", role: "presentation" }, arrowIcon),
            react_1.default.createElement(DateInput_1.default, { id: endDateId, placeholder: endDatePlaceholderText, displayValue: endDate, inputValue: endDateValue, screenReaderMessage: screenReaderText, focused: isEndDateFocused, isFocused: isFocused, disabled: disabled, required: required, readOnly: readOnly, showCaret: showCaret, onChange: onEndDateChange, onFocus: onEndDateFocus, onKeyDownTab: onEndDateTab, onKeyDownArrowDown: onArrowDown, onKeyDownQuestionMark: onQuestionMark }),
            showClearDates && (react_1.default.createElement("button", { type: "button", "aria-label": phrases.clearDates, className: classnames_1.default(theme['DateRangePickerInput__clear-dates'], {
                    [theme['DateRangePickerInput__clear-dates--hide']]: !(startDate || endDate),
                    [theme['DateRangePickerInput__clear-dates--hover']]: isClearDatesHovered,
                }), onMouseEnter: this.onClearDatesMouseEnter, onMouseLeave: this.onClearDatesMouseLeave, onClick: onClearDates },
                react_1.default.createElement("div", { className: theme["DateRangePickerInput__close-icon"] }, closeIcon)))));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(DateRangePickerInput);
DateRangePickerInput.propTypes = propTypes;
DateRangePickerInput.defaultProps = defaultProps;
