"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_css_themr_1 = require("react-css-themr");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const classnames_1 = require("classnames");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const close_svg_1 = require("../svg/close.svg");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
exports.TOP_LEFT = 'top-left';
exports.TOP_RIGHT = 'top-right';
exports.BOTTOM_RIGHT = 'bottom-right';
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    block: prop_types_1.default.bool,
    buttonLocation: prop_types_1.default.oneOf([exports.TOP_LEFT, exports.TOP_RIGHT, exports.BOTTOM_RIGHT]),
    showKeyboardShortcutsPanel: prop_types_1.default.bool,
    openKeyboardShortcutsPanel: prop_types_1.default.func,
    closeKeyboardShortcutsPanel: prop_types_1.default.func,
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.DayPickerKeyboardShortcutsPhrases)),
    theme: prop_types_1.default.any,
    testingThis: prop_types_1.default.object,
});
const defaultProps = {
    block: false,
    buttonLocation: exports.BOTTOM_RIGHT,
    showKeyboardShortcutsPanel: false,
    openKeyboardShortcutsPanel() { },
    closeKeyboardShortcutsPanel() { },
    phrases: defaultPhrases_1.DayPickerKeyboardShortcutsPhrases,
};
function KeyboardShortcutRow({ unicode, label, action, theme }) {
    return (react_1.default.createElement("li", { className: theme["KeyboardShortcutRow"] },
        react_1.default.createElement("div", { className: theme["KeyboardShortcutRow__key-container"] },
            react_1.default.createElement("span", { className: theme["KeyboardShortcutRow__key"], role: "img", "aria-label": label }, unicode)),
        react_1.default.createElement("div", { className: theme["KeyboardShortcutRow__action"] }, action)));
}
exports.KeyboardShortcutRow = KeyboardShortcutRow;
KeyboardShortcutRow.propTypes = {
    unicode: prop_types_1.default.string.isRequired,
    label: prop_types_1.default.string.isRequired,
    action: prop_types_1.default.string.isRequired,
    theme: prop_types_1.default.object.isRequired,
};
function DayPickerKeyboardShortcuts({ block, buttonLocation, showKeyboardShortcutsPanel, openKeyboardShortcutsPanel, closeKeyboardShortcutsPanel, phrases, theme, testingThis, }) {
    const fakeThis = testingThis;
    const keyboardShortcuts = [{
            unicode: '↵',
            label: phrases.enterKey,
            action: phrases.selectFocusedDate,
            theme: theme,
        },
        {
            unicode: '←/→',
            label: phrases.leftArrowRightArrow,
            action: phrases.moveFocusByOneDay,
            theme: theme,
        },
        {
            unicode: '↑/↓',
            label: phrases.upArrowDownArrow,
            action: phrases.moveFocusByOneWeek,
            theme: theme,
        },
        {
            unicode: 'PgUp/PgDn',
            label: phrases.pageUpPageDown,
            action: phrases.moveFocusByOneMonth,
            theme: theme,
        },
        {
            unicode: 'Home/End',
            label: phrases.homeEnd,
            action: phrases.moveFocustoStartAndEndOfWeek,
            theme: theme,
        },
        {
            unicode: 'Esc',
            label: phrases.escape,
            action: phrases.returnFocusToInput,
            theme: theme,
        },
        {
            unicode: '?',
            label: phrases.questionMark,
            action: phrases.openThisPanel,
            theme: theme,
        },
    ];
    const toggleButtonText = showKeyboardShortcutsPanel
        ? phrases.hideKeyboardShortcutsPanel
        : phrases.showKeyboardShortcutsPanel;
    // let showKeyboardShortcutsButton;
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("button", { ref: (ref) => {
                fakeThis.showKeyboardShortcutsButton = ref;
            }, className: classnames_1.default(theme['DayPickerKeyboardShortcuts__show'], {
                [theme['DayPickerKeyboardShortcuts__show--bottom-right']]: buttonLocation === exports.BOTTOM_RIGHT,
                [theme['DayPickerKeyboardShortcuts__show--top-right']]: buttonLocation === exports.TOP_RIGHT,
                [theme['DayPickerKeyboardShortcuts__show--top-left']]: buttonLocation === exports.TOP_LEFT,
            }), type: "button", "aria-label": toggleButtonText, onClick: () => {
                // we want to return focus to testingThis button after closing the keyboard shortcuts panel
                openKeyboardShortcutsPanel(() => { fakeThis.showKeyboardShortcutsButton.focus(); });
            }, onMouseUp: (e) => {
                e.currentTarget.blur();
            } },
            react_1.default.createElement("span", { className: theme["DayPickerKeyboardShortcuts__show_span"] }, "?")),
        showKeyboardShortcutsPanel &&
            react_1.default.createElement("div", { className: classnames_1.default(theme['DayPickerKeyboardShortcuts__panel'], {
                    [theme['DayPickerKeyboardShortcuts__panel--block']]: block,
                }), role: "dialog", "aria-labelledby": "DayPickerKeyboardShortcuts__title" },
                react_1.default.createElement("div", { id: "DayPickerKeyboardShortcuts__title", className: theme["DayPickerKeyboardShortcuts__title"] }, phrases.keyboardShortcuts),
                react_1.default.createElement("button", { className: theme["DayPickerKeyboardShortcuts__close"], type: "button", "aria-label": phrases.hideKeyboardShortcutsPanel, onClick: closeKeyboardShortcutsPanel, onKeyDown: (e) => {
                        // Because the close button is the only focusable element inside of the panel, this
                        // amount to a very basic focus trap. The user can exit the panel by "pressing" the
                        // close button or hitting escape
                        if (e.key === 'Tab') {
                            e.preventDefault();
                        }
                    } },
                    react_1.default.createElement(close_svg_1.default, null)),
                react_1.default.createElement("ul", { className: theme["DayPickerKeyboardShortcuts__list"] }, keyboardShortcuts.map(({ unicode, label, action }) => (react_1.default.createElement(KeyboardShortcutRow, { key: label, unicode: unicode, label: label, action: action, theme: theme })))))));
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(DayPickerKeyboardShortcuts);
DayPickerKeyboardShortcuts.propTypes = propTypes;
DayPickerKeyboardShortcuts.defaultProps = defaultProps;
