"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const classnames_1 = require("classnames");
const react_css_themr_1 = require("react-css-themr");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const arrow_left_svg_1 = require("../svg/arrow-left.svg");
const arrow_right_svg_1 = require("../svg/arrow-right.svg");
const chevron_up_svg_1 = require("../svg/chevron-up.svg");
const chevron_down_svg_1 = require("../svg/chevron-down.svg");
const ScrollableOrientationShape_1 = require("../shapes/ScrollableOrientationShape");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const Constants_1 = require("../Constants");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    navPrev: prop_types_1.default.node,
    navNext: prop_types_1.default.node,
    orientation: ScrollableOrientationShape_1.default,
    onPrevMonthClick: prop_types_1.default.func,
    onNextMonthClick: prop_types_1.default.func,
    // internationalization
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.DayPickerNavigationPhrases)),
    isRTL: prop_types_1.default.bool,
    theme: prop_types_1.default.any,
});
const defaultProps = {
    navPrev: null,
    navNext: null,
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    onPrevMonthClick() { },
    onNextMonthClick() { },
    // internationalization
    phrases: defaultPhrases_1.DayPickerNavigationPhrases,
    isRTL: false,
};
function DayPickerNavigation(props) {
    const { navPrev, navNext, onPrevMonthClick, onNextMonthClick, orientation, phrases, isRTL, theme, } = props;
    const isVertical = orientation !== Constants_1.HORIZONTAL_ORIENTATION;
    const isVerticalScrollable = orientation === Constants_1.VERTICAL_SCROLLABLE;
    let navPrevIcon = navPrev;
    let navNextIcon = navNext;
    let isDefaultNavPrev = false;
    let isDefaultNavNext = false;
    if (!navPrevIcon) {
        isDefaultNavPrev = true;
        navPrevIcon = isVertical ? react_1.default.createElement(chevron_up_svg_1.default, null) : react_1.default.createElement(arrow_left_svg_1.default, null);
        if (isRTL && !isVertical) {
            navPrevIcon = react_1.default.createElement(arrow_right_svg_1.default, null);
        }
    }
    if (!navNextIcon) {
        isDefaultNavNext = true;
        navNextIcon = isVertical ? react_1.default.createElement(chevron_down_svg_1.default, null) : react_1.default.createElement(arrow_right_svg_1.default, null);
        if (isRTL && !isVertical) {
            navNextIcon = react_1.default.createElement(arrow_left_svg_1.default, null);
        }
    }
    const navClassNames = classnames_1.default(theme['DayPickerNavigation'], {
        [theme['DayPickerNavigation--horizontal']]: !isVertical,
        [theme['DayPickerNavigation--vertical']]: isVertical,
        [theme['DayPickerNavigation--vertical-scrollable']]: isVerticalScrollable,
    });
    const prevClassNames = classnames_1.default(theme['DayPickerNavigation__prev'], {
        [theme['DayPickerNavigation__prev--default']]: isDefaultNavPrev,
        [theme['DayPickerNavigation__prev--rtl']]: isRTL,
    });
    const nextClassNames = classnames_1.default(theme['DayPickerNavigation__next'], {
        [theme['DayPickerNavigation__next--default']]: isDefaultNavNext,
        [theme['DayPickerNavigation__next--rtl']]: isRTL,
    });
    return (react_1.default.createElement("div", { className: navClassNames },
        !isVerticalScrollable && (react_1.default.createElement("button", { type: "button", "aria-label": phrases.jumpToPrevMonth, className: prevClassNames, onClick: onPrevMonthClick, onMouseUp: (e) => {
                e.currentTarget.blur();
            } }, navPrevIcon)),
        react_1.default.createElement("button", { type: "button", "aria-label": phrases.jumpToNextMonth, className: nextClassNames, onClick: onNextMonthClick, onMouseUp: (e) => {
                e.currentTarget.blur();
            } }, navNextIcon)));
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(DayPickerNavigation);
DayPickerNavigation.propTypes = propTypes;
DayPickerNavigation.defaultProps = defaultProps;
