"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_moment_proptypes_1 = require("react-moment-proptypes");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const moment_1 = require("moment");
const object_values_1 = require("object.values");
const is_touch_device_1 = require("is-touch-device");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const isInclusivelyAfterDay_1 = require("../utils/isInclusivelyAfterDay");
const isNextDay_1 = require("../utils/isNextDay");
const isSameDay_1 = require("../utils/isSameDay");
const isAfterDay_1 = require("../utils/isAfterDay");
const isBeforeDay_1 = require("../utils/isBeforeDay");
const getVisibleDays_1 = require("../utils/getVisibleDays");
const isDayVisible_1 = require("../utils/isDayVisible");
const toISODateString_1 = require("../utils/toISODateString");
const toISOMonthString_1 = require("../utils/toISOMonthString");
const FocusedInputShape_1 = require("../shapes/FocusedInputShape");
const ScrollableOrientationShape_1 = require("../shapes/ScrollableOrientationShape");
const DayOfWeekShape_1 = require("../shapes/DayOfWeekShape");
const Constants_1 = require("../Constants");
const DayPicker_1 = require("./DayPicker");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    startDate: react_moment_proptypes_1.default.momentObj,
    endDate: react_moment_proptypes_1.default.momentObj,
    onDatesChange: prop_types_1.default.func,
    focusedInput: FocusedInputShape_1.default,
    onFocusChange: prop_types_1.default.func,
    onClose: prop_types_1.default.func,
    keepOpenOnDateSelect: prop_types_1.default.bool,
    minimumNights: prop_types_1.default.number,
    isOutsideRange: prop_types_1.default.func,
    isDayBlocked: prop_types_1.default.func,
    isDayHighlighted: prop_types_1.default.func,
    // DayPicker props
    renderMonth: prop_types_1.default.func,
    enableOutsideDays: prop_types_1.default.bool,
    numberOfMonths: prop_types_1.default.number,
    orientation: ScrollableOrientationShape_1.default,
    withPortal: prop_types_1.default.bool,
    initialVisibleMonth: prop_types_1.default.func,
    hideKeyboardShortcutsPanel: prop_types_1.default.bool,
    daySize: airbnb_prop_types_1.nonNegativeInteger,
    navPrev: prop_types_1.default.node,
    navNext: prop_types_1.default.node,
    onPrevMonthClick: prop_types_1.default.func,
    onNextMonthClick: prop_types_1.default.func,
    onOutsideClick: prop_types_1.default.func,
    renderDay: prop_types_1.default.func,
    renderCalendarInfo: prop_types_1.default.func,
    firstDayOfWeek: DayOfWeekShape_1.default,
    // accessibility
    onBlur: prop_types_1.default.func,
    isFocused: prop_types_1.default.bool,
    showKeyboardShortcuts: prop_types_1.default.bool,
    // i18n
    monthFormat: prop_types_1.default.string,
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.DayPickerPhrases)),
    isRTL: prop_types_1.default.bool,
    theme: prop_types_1.default.any,
});
const defaultProps = {
    startDate: undefined,
    endDate: undefined,
    onDatesChange() { },
    focusedInput: null,
    onFocusChange() { },
    onClose() { },
    keepOpenOnDateSelect: false,
    minimumNights: 1,
    isOutsideRange() { },
    isDayBlocked() { },
    isDayHighlighted() { },
    // DayPicker props
    renderMonth: null,
    enableOutsideDays: false,
    numberOfMonths: 1,
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    withPortal: false,
    hideKeyboardShortcutsPanel: false,
    initialVisibleMonth: null,
    daySize: Constants_1.DAY_SIZE,
    navPrev: null,
    navNext: null,
    onPrevMonthClick() { },
    onNextMonthClick() { },
    onOutsideClick() { },
    renderDay: null,
    renderCalendarInfo: null,
    firstDayOfWeek: null,
    // accessibility
    onBlur() { },
    isFocused: false,
    showKeyboardShortcuts: false,
    // i18n
    monthFormat: 'MMMM YYYY',
    phrases: defaultPhrases_1.DayPickerPhrases,
    isRTL: false,
};
class DayPickerRangeController extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.isTouchDevice = is_touch_device_1.default();
        this.today = moment_1.default();
        this.modifiers = {
            today: day => this.isToday(day),
            blocked: day => this.isBlocked(day),
            'blocked-calendar': day => props.isDayBlocked(day),
            'blocked-out-of-range': day => props.isOutsideRange(day),
            'highlighted-calendar': day => props.isDayHighlighted(day),
            valid: day => !this.isBlocked(day),
            'selected-start': day => this.isStartDate(day),
            'selected-end': day => this.isEndDate(day),
            'blocked-minimum-nights': day => this.doesNotMeetMinimumNights(day),
            'selected-span': day => this.isInSelectedSpan(day),
            'last-in-range': day => this.isLastInRange(day),
            hovered: day => this.isHovered(day),
            'hovered-span': day => this.isInHoveredSpan(day),
            'after-hovered-start': day => this.isDayAfterHoveredStartDate(day),
        };
        const { currentMonth, visibleDays } = this.getStateForNewMonth(props);
        this.state = {
            hoverDate: null,
            currentMonth,
            phrases: props.phrases,
            visibleDays,
        };
        this.onDayClick = this.onDayClick.bind(this);
        this.onDayMouseEnter = this.onDayMouseEnter.bind(this);
        this.onDayMouseLeave = this.onDayMouseLeave.bind(this);
        this.onPrevMonthClick = this.onPrevMonthClick.bind(this);
        this.onNextMonthClick = this.onNextMonthClick.bind(this);
        this.onMultiplyScrollableMonths = this.onMultiplyScrollableMonths.bind(this);
        this.getFirstFocusableDay = this.getFirstFocusableDay.bind(this);
    }
    componentWillReceiveProps(nextProps) {
        const { startDate, endDate, focusedInput, minimumNights, isOutsideRange, isDayBlocked, isDayHighlighted, phrases, initialVisibleMonth, numberOfMonths, enableOutsideDays, } = nextProps;
        let { visibleDays } = this.state;
        if (isOutsideRange !== this.props.isOutsideRange) {
            this.modifiers['blocked-out-of-range'] = day => isOutsideRange(day);
        }
        if (isDayBlocked !== this.props.isDayBlocked) {
            this.modifiers['blocked-calendar'] = day => isDayBlocked(day);
        }
        if (isDayHighlighted !== this.props.isDayHighlighted) {
            this.modifiers['highlighted-calendar'] = day => isDayHighlighted(day);
        }
        const didStartDateChange = startDate !== this.props.startDate;
        const didEndDateChange = endDate !== this.props.endDate;
        const didFocusChange = focusedInput !== this.props.focusedInput;
        if ((initialVisibleMonth !== this.props.initialVisibleMonth ||
            numberOfMonths !== this.props.numberOfMonths ||
            enableOutsideDays !== this.props.enableOutsideDays) && (!this.props.focusedInput &&
            didFocusChange)) {
            const newMonthState = this.getStateForNewMonth(nextProps);
            const currentMonth = newMonthState.currentMonth;
            visibleDays = newMonthState.visibleDays;
            this.setState({
                currentMonth,
                visibleDays,
            });
        }
        let modifiers = {};
        if (didStartDateChange) {
            modifiers = this.deleteModifier(modifiers, this.props.startDate, 'selected-start');
            modifiers = this.addModifier(modifiers, startDate, 'selected-start');
        }
        if (didEndDateChange) {
            modifiers = this.deleteModifier(modifiers, this.props.endDate, 'selected-end');
            modifiers = this.addModifier(modifiers, endDate, 'selected-end');
        }
        if (didStartDateChange || didEndDateChange) {
            if (this.props.startDate && this.props.endDate) {
                modifiers = this.deleteModifierFromRange(modifiers, this.props.startDate, this.props.endDate.clone().add(1, 'day'), 'selected-span');
            }
            if (startDate && endDate) {
                modifiers = this.deleteModifierFromRange(modifiers, startDate, endDate.clone().add(1, 'day'), 'hovered-span');
                modifiers = this.addModifierToRange(modifiers, startDate.clone().add(1, 'day'), endDate, 'selected-span');
            }
        }
        if (!this.isTouchDevice && didStartDateChange && startDate && !endDate) {
            const startSpan = startDate.clone().add(1, 'day');
            const endSpan = startDate.clone().add(minimumNights + 1, 'days');
            modifiers = this.addModifierToRange(modifiers, startSpan, endSpan, 'after-hovered-start');
        }
        if (minimumNights > 0 || minimumNights !== this.props.minimumNights) {
            if (didFocusChange || didStartDateChange) {
                const startSpan = this.props.startDate ? this.props.startDate : this.today;
                modifiers = this.deleteModifierFromRange(modifiers, startSpan, startSpan.clone().add(minimumNights, 'days'), 'blocked-minimum-nights');
            }
            if (startDate && focusedInput === Constants_1.END_DATE) {
                modifiers = this.addModifierToRange(modifiers, startDate, startDate.clone().add(minimumNights, 'days'), 'blocked-minimum-nights');
            }
        }
        if (didFocusChange) {
            object_values_1.default(visibleDays).forEach((days) => {
                Object.keys(days).forEach((day) => {
                    const momentObj = moment_1.default(day);
                    if (this.isBlocked(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked');
                    }
                    if (isOutsideRange(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked-out-of-range');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked-out-of-range');
                    }
                    if (isDayBlocked(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked-calendar');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked-calendar');
                    }
                    if (isDayHighlighted(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'highlighted-calendar');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'highlighted-calendar');
                    }
                });
            });
        }
        const today = moment_1.default();
        if (!isSameDay_1.default(this.today, today)) {
            modifiers = this.deleteModifier(modifiers, this.today, 'today');
            modifiers = this.addModifier(modifiers, today, 'today');
            this.today = today;
        }
        if (Object.keys(modifiers).length > 0) {
            this.setState({
                visibleDays: Object.assign({}, visibleDays, modifiers),
            });
        }
        if (didFocusChange || phrases !== this.props.phrases) {
            // set the appropriate CalendarDay phrase based on focusedInput
            let chooseAvailableDate = phrases.chooseAvailableDate;
            if (focusedInput === Constants_1.START_DATE) {
                chooseAvailableDate = phrases.chooseAvailableStartDate;
            }
            else if (focusedInput === Constants_1.END_DATE) {
                chooseAvailableDate = phrases.chooseAvailableEndDate;
            }
            this.setState({
                phrases: Object.assign({}, phrases, { chooseAvailableDate }),
            });
        }
    }
    onDayClick(day, e) {
        const { keepOpenOnDateSelect, minimumNights, onBlur } = this.props;
        if (e)
            e.preventDefault();
        if (this.isBlocked(day))
            return;
        const { focusedInput, onFocusChange, onClose } = this.props;
        let { startDate, endDate } = this.props;
        if (focusedInput === Constants_1.START_DATE) {
            onFocusChange(Constants_1.END_DATE);
            startDate = day;
            if (isInclusivelyAfterDay_1.default(day, endDate)) {
                endDate = null;
            }
        }
        else if (focusedInput === Constants_1.END_DATE) {
            const firstAllowedEndDate = startDate && startDate.clone().add(minimumNights, 'days');
            if (!startDate) {
                endDate = day;
                onFocusChange(Constants_1.START_DATE);
            }
            else if (isInclusivelyAfterDay_1.default(day, firstAllowedEndDate)) {
                endDate = day;
                if (!keepOpenOnDateSelect) {
                    onFocusChange(null);
                    onClose({ startDate, endDate });
                }
            }
            else {
                startDate = day;
                endDate = null;
            }
        }
        this.props.onDatesChange({ startDate, endDate });
        onBlur();
    }
    onDayMouseEnter(day) {
        if (this.isTouchDevice)
            return;
        const { startDate, endDate, focusedInput, minimumNights } = this.props;
        const { hoverDate, visibleDays } = this.state;
        if (focusedInput) {
            let modifiers = {};
            modifiers = this.deleteModifier(modifiers, hoverDate, 'hovered');
            modifiers = this.addModifier(modifiers, day, 'hovered');
            if (startDate && !endDate && focusedInput === Constants_1.END_DATE) {
                if (isAfterDay_1.default(hoverDate, startDate)) {
                    const endSpan = hoverDate.clone().add(1, 'day');
                    modifiers = this.deleteModifierFromRange(modifiers, startDate, endSpan, 'hovered-span');
                }
                if (!this.isBlocked(day) && isAfterDay_1.default(day, startDate)) {
                    const endSpan = day.clone().add(1, 'day');
                    modifiers = this.addModifierToRange(modifiers, startDate, endSpan, 'hovered-span');
                }
            }
            if (!startDate && endDate && focusedInput === Constants_1.START_DATE) {
                if (isBeforeDay_1.default(hoverDate, endDate)) {
                    modifiers = this.deleteModifierFromRange(modifiers, hoverDate, endDate, 'hovered-span');
                }
                if (!this.isBlocked(day) && isBeforeDay_1.default(day, endDate)) {
                    modifiers = this.addModifierToRange(modifiers, day, endDate, 'hovered-span');
                }
            }
            if (startDate) {
                const startSpan = startDate.clone().add(1, 'day');
                const endSpan = startDate.clone().add(minimumNights + 1, 'days');
                modifiers = this.deleteModifierFromRange(modifiers, startSpan, endSpan, 'after-hovered-start');
                if (isSameDay_1.default(day, startDate)) {
                    const newStartSpan = startDate.clone().add(1, 'day');
                    const newEndSpan = startDate.clone().add(minimumNights + 1, 'days');
                    modifiers =
                        this.addModifierToRange(modifiers, newStartSpan, newEndSpan, 'after-hovered-start');
                }
            }
            this.setState({
                hoverDate: day,
                visibleDays: Object.assign({}, visibleDays, modifiers),
            });
        }
    }
    onDayMouseLeave(day) {
        const { startDate, endDate, minimumNights } = this.props;
        const { hoverDate, visibleDays } = this.state;
        if (this.isTouchDevice || !hoverDate)
            return;
        let modifiers = {};
        modifiers = this.deleteModifier(modifiers, hoverDate, 'hovered');
        if (startDate && !endDate && isAfterDay_1.default(hoverDate, startDate)) {
            const endSpan = hoverDate.clone().add(1, 'day');
            modifiers = this.deleteModifierFromRange(modifiers, startDate, endSpan, 'hovered-span');
        }
        if (!startDate && endDate && isAfterDay_1.default(endDate, hoverDate)) {
            modifiers = this.deleteModifierFromRange(modifiers, hoverDate, endDate, 'hovered-span');
        }
        if (startDate && isSameDay_1.default(day, startDate)) {
            const startSpan = startDate.clone().add(1, 'day');
            const endSpan = startDate.clone().add(minimumNights + 1, 'days');
            modifiers = this.deleteModifierFromRange(modifiers, startSpan, endSpan, 'after-hovered-start');
        }
        this.setState({
            hoverDate: null,
            visibleDays: Object.assign({}, visibleDays, modifiers),
        });
    }
    onPrevMonthClick() {
        const { onPrevMonthClick, numberOfMonths, enableOutsideDays } = this.props;
        const { currentMonth, visibleDays } = this.state;
        const newVisibleDays = {};
        Object.keys(visibleDays).sort().slice(0, numberOfMonths + 1).forEach((month) => {
            newVisibleDays[month] = visibleDays[month];
        });
        const prevMonth = currentMonth.clone().subtract(2, 'months');
        const prevMonthVisibleDays = getVisibleDays_1.default(prevMonth, 1, enableOutsideDays, true);
        this.setState({
            currentMonth: currentMonth.clone().subtract(1, 'month'),
            visibleDays: Object.assign({}, newVisibleDays, this.getModifiers(prevMonthVisibleDays)),
        });
        onPrevMonthClick();
    }
    onNextMonthClick() {
        const { onNextMonthClick, numberOfMonths, enableOutsideDays } = this.props;
        const { currentMonth, visibleDays } = this.state;
        const newVisibleDays = {};
        Object.keys(visibleDays).sort().slice(1).forEach((month) => {
            newVisibleDays[month] = visibleDays[month];
        });
        const nextMonth = currentMonth.clone().add(numberOfMonths + 1, 'month');
        const nextMonthVisibleDays = getVisibleDays_1.default(nextMonth, 1, enableOutsideDays, true);
        this.setState({
            currentMonth: currentMonth.clone().add(1, 'month'),
            visibleDays: Object.assign({}, newVisibleDays, this.getModifiers(nextMonthVisibleDays)),
        });
        onNextMonthClick();
    }
    onMultiplyScrollableMonths() {
        const { numberOfMonths, enableOutsideDays } = this.props;
        const { currentMonth, visibleDays } = this.state;
        const numberOfVisibleMonths = Object.keys(visibleDays).length;
        const nextMonth = currentMonth.clone().add(numberOfVisibleMonths, 'month');
        const newVisibleDays = getVisibleDays_1.default(nextMonth, numberOfMonths, enableOutsideDays, true);
        this.setState({
            visibleDays: Object.assign({}, visibleDays, this.getModifiers(newVisibleDays)),
        });
    }
    getFirstFocusableDay(newMonth) {
        const { startDate, endDate, focusedInput, minimumNights, numberOfMonths } = this.props;
        let focusedDate = newMonth.clone().startOf('month');
        if (focusedInput === Constants_1.START_DATE && startDate) {
            focusedDate = startDate.clone();
        }
        else if (focusedInput === Constants_1.END_DATE && !endDate && startDate) {
            focusedDate = startDate.clone().add(minimumNights, 'days');
        }
        else if (focusedInput === Constants_1.END_DATE && endDate) {
            focusedDate = endDate.clone();
        }
        if (this.isBlocked(focusedDate)) {
            const days = [];
            const lastVisibleDay = newMonth.clone().add(numberOfMonths - 1, 'months').endOf('month');
            let currentDay = focusedDate.clone();
            while (!isAfterDay_1.default(currentDay, lastVisibleDay)) {
                currentDay = currentDay.clone().add(1, 'day');
                days.push(currentDay);
            }
            const viableDays = days.filter(day => !this.isBlocked(day));
            if (viableDays.length > 0)
                focusedDate = viableDays[0];
        }
        return focusedDate;
    }
    getModifiers(visibleDays) {
        const modifiers = {};
        Object.keys(visibleDays).forEach((month) => {
            modifiers[month] = {};
            visibleDays[month].forEach((day) => {
                modifiers[month][toISODateString_1.default(day)] = this.getModifiersForDay(day);
            });
        });
        return modifiers;
    }
    getModifiersForDay(day) {
        return new Set(Object.keys(this.modifiers).filter(modifier => this.modifiers[modifier](day)));
    }
    getStateForNewMonth(nextProps) {
        const { initialVisibleMonth, numberOfMonths, enableOutsideDays, orientation, startDate, } = nextProps;
        const initialVisibleMonthThunk = initialVisibleMonth || (startDate ? () => startDate : () => this.today);
        const currentMonth = initialVisibleMonthThunk();
        const withoutTransitionMonths = orientation === Constants_1.VERTICAL_SCROLLABLE;
        const visibleDays = this.getModifiers(getVisibleDays_1.default(currentMonth, numberOfMonths, enableOutsideDays, withoutTransitionMonths));
        return { currentMonth, visibleDays };
    }
    addModifier(updatedDays, day, modifier) {
        const { numberOfMonths: numberOfVisibleMonths, enableOutsideDays, orientation } = this.props;
        const { currentMonth: firstVisibleMonth, visibleDays } = this.state;
        let currentMonth = firstVisibleMonth;
        let numberOfMonths = numberOfVisibleMonths;
        if (orientation !== Constants_1.VERTICAL_SCROLLABLE) {
            currentMonth = currentMonth.clone().subtract(1, 'month');
            numberOfMonths += 2;
        }
        if (!day || !isDayVisible_1.default(day, currentMonth, numberOfMonths, enableOutsideDays)) {
            return updatedDays;
        }
        const iso = toISODateString_1.default(day);
        let updatedDaysAfterAddition = Object.assign({}, updatedDays);
        if (enableOutsideDays) {
            const monthsToUpdate = Object.keys(visibleDays).filter(monthKey => (Object.keys(visibleDays[monthKey]).indexOf(iso) > -1));
            updatedDaysAfterAddition = monthsToUpdate.reduce((days, monthIso) => {
                const month = updatedDays[monthIso] || visibleDays[monthIso];
                const modifiers = new Set(month[iso]);
                modifiers.add(modifier);
                return Object.assign({}, days, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
            }, updatedDaysAfterAddition);
        }
        else {
            const monthIso = toISOMonthString_1.default(day);
            const month = updatedDays[monthIso] || visibleDays[monthIso];
            const modifiers = new Set(month[iso]);
            modifiers.add(modifier);
            updatedDaysAfterAddition = Object.assign({}, updatedDaysAfterAddition, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
        }
        return updatedDaysAfterAddition;
    }
    addModifierToRange(updatedDays, start, end, modifier) {
        let days = updatedDays;
        let spanStart = start.clone();
        while (isBeforeDay_1.default(spanStart, end)) {
            days = this.addModifier(days, spanStart, modifier);
            spanStart = spanStart.clone().add(1, 'day');
        }
        return days;
    }
    deleteModifier(updatedDays, day, modifier) {
        const { numberOfMonths: numberOfVisibleMonths, enableOutsideDays, orientation } = this.props;
        const { currentMonth: firstVisibleMonth, visibleDays } = this.state;
        let currentMonth = firstVisibleMonth;
        let numberOfMonths = numberOfVisibleMonths;
        if (orientation !== Constants_1.VERTICAL_SCROLLABLE) {
            currentMonth = currentMonth.clone().subtract(1, 'month');
            numberOfMonths += 2;
        }
        if (!day || !isDayVisible_1.default(day, currentMonth, numberOfMonths, enableOutsideDays)) {
            return updatedDays;
        }
        const iso = toISODateString_1.default(day);
        let updatedDaysAfterDeletion = Object.assign({}, updatedDays);
        if (enableOutsideDays) {
            const monthsToUpdate = Object.keys(visibleDays).filter(monthKey => (Object.keys(visibleDays[monthKey]).indexOf(iso) > -1));
            updatedDaysAfterDeletion = monthsToUpdate.reduce((days, monthIso) => {
                const month = updatedDays[monthIso] || visibleDays[monthIso];
                const modifiers = new Set(month[iso]);
                modifiers.delete(modifier);
                return Object.assign({}, days, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
            }, updatedDaysAfterDeletion);
        }
        else {
            const monthIso = toISOMonthString_1.default(day);
            const month = updatedDays[monthIso] || visibleDays[monthIso];
            const modifiers = new Set(month[iso]);
            modifiers.delete(modifier);
            updatedDaysAfterDeletion = Object.assign({}, updatedDaysAfterDeletion, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
        }
        return updatedDaysAfterDeletion;
    }
    deleteModifierFromRange(updatedDays, start, end, modifier) {
        let days = updatedDays;
        let spanStart = start.clone();
        while (isBeforeDay_1.default(spanStart, end)) {
            days = this.deleteModifier(days, spanStart, modifier);
            spanStart = spanStart.clone().add(1, 'day');
        }
        return days;
    }
    doesNotMeetMinimumNights(day) {
        const { startDate, isOutsideRange, focusedInput, minimumNights } = this.props;
        if (focusedInput !== Constants_1.END_DATE)
            return false;
        if (startDate) {
            const dayDiff = day.diff(startDate.clone().startOf('day').hour(12), 'days');
            return dayDiff < minimumNights && dayDiff >= 0;
        }
        return isOutsideRange(moment_1.default(day).subtract(minimumNights, 'days'));
    }
    isDayAfterHoveredStartDate(day) {
        const { startDate, endDate, minimumNights } = this.props;
        const { hoverDate } = this.state || {};
        return !!startDate && !endDate && !this.isBlocked(day) && isNextDay_1.default(hoverDate, day) &&
            minimumNights > 0 && isSameDay_1.default(hoverDate, startDate);
    }
    isEndDate(day) {
        return isSameDay_1.default(day, this.props.endDate);
    }
    isHovered(day) {
        const { hoverDate } = this.state || {};
        const { focusedInput } = this.props;
        return !!focusedInput && isSameDay_1.default(day, hoverDate);
    }
    isInHoveredSpan(day) {
        const { startDate, endDate } = this.props;
        const { hoverDate } = this.state || {};
        const isForwardRange = !!startDate && !endDate &&
            (day.isBetween(startDate, hoverDate) ||
                isSameDay_1.default(hoverDate, day));
        const isBackwardRange = !!endDate && !startDate &&
            (day.isBetween(hoverDate, endDate) ||
                isSameDay_1.default(hoverDate, day));
        const isValidDayHovered = hoverDate && !this.isBlocked(hoverDate);
        return (isForwardRange || isBackwardRange) && isValidDayHovered;
    }
    isInSelectedSpan(day) {
        const { startDate, endDate } = this.props;
        return day.isBetween(startDate, endDate);
    }
    isLastInRange(day) {
        return this.isInSelectedSpan(day) && isNextDay_1.default(day, this.props.endDate);
    }
    isStartDate(day) {
        return isSameDay_1.default(day, this.props.startDate);
    }
    isBlocked(day) {
        const { isDayBlocked, isOutsideRange } = this.props;
        return isDayBlocked(day) || isOutsideRange(day) || this.doesNotMeetMinimumNights(day);
    }
    isToday(day) {
        return isSameDay_1.default(day, this.today);
    }
    render() {
        const { numberOfMonths, orientation, monthFormat, renderMonth, navPrev, navNext, onOutsideClick, withPortal, enableOutsideDays, firstDayOfWeek, hideKeyboardShortcutsPanel, daySize, focusedInput, renderDay, renderCalendarInfo, onBlur, isFocused, showKeyboardShortcuts, isRTL, } = this.props;
        const { currentMonth, phrases, visibleDays } = this.state;
        return (react_1.default.createElement(DayPicker_1.default, { ref: (ref) => { this.dayPicker = ref; }, orientation: orientation, enableOutsideDays: enableOutsideDays, modifiers: visibleDays, numberOfMonths: numberOfMonths, onDayClick: this.onDayClick, onDayMouseEnter: this.onDayMouseEnter, onDayMouseLeave: this.onDayMouseLeave, onPrevMonthClick: this.onPrevMonthClick, onNextMonthClick: this.onNextMonthClick, onMultiplyScrollableMonths: this.onMultiplyScrollableMonths, monthFormat: monthFormat, renderMonth: renderMonth, withPortal: withPortal, hidden: !focusedInput, initialVisibleMonth: () => currentMonth, daySize: daySize, onOutsideClick: onOutsideClick, navPrev: navPrev, navNext: navNext, renderDay: renderDay, renderCalendarInfo: renderCalendarInfo, firstDayOfWeek: firstDayOfWeek, hideKeyboardShortcutsPanel: hideKeyboardShortcutsPanel, isFocused: isFocused, getFirstFocusableDay: this.getFirstFocusableDay, onBlur: onBlur, showKeyboardShortcuts: showKeyboardShortcuts, phrases: phrases, isRTL: isRTL }));
    }
}
exports.default = DayPickerRangeController;
DayPickerRangeController.propTypes = propTypes;
DayPickerRangeController.defaultProps = defaultProps;
