"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const react_moment_proptypes_1 = require("react-moment-proptypes");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const moment_1 = require("moment");
const object_values_1 = require("object.values");
const is_touch_device_1 = require("is-touch-device");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const isSameDay_1 = require("../utils/isSameDay");
const isAfterDay_1 = require("../utils/isAfterDay");
const getVisibleDays_1 = require("../utils/getVisibleDays");
const isDayVisible_1 = require("../utils/isDayVisible");
const toISODateString_1 = require("../utils/toISODateString");
const toISOMonthString_1 = require("../utils/toISOMonthString");
const ScrollableOrientationShape_1 = require("../shapes/ScrollableOrientationShape");
const DayOfWeekShape_1 = require("../shapes/DayOfWeekShape");
const Constants_1 = require("../Constants");
const DayPicker_1 = require("./DayPicker");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    date: react_moment_proptypes_1.default.momentObj,
    onDateChange: prop_types_1.default.func,
    focused: prop_types_1.default.bool,
    onFocusChange: prop_types_1.default.func,
    onClose: prop_types_1.default.func,
    keepOpenOnDateSelect: prop_types_1.default.bool,
    minimumNights: prop_types_1.default.number,
    isOutsideRange: prop_types_1.default.func,
    isDayBlocked: prop_types_1.default.func,
    isDayHighlighted: prop_types_1.default.func,
    // DayPicker props
    renderMonth: prop_types_1.default.func,
    enableOutsideDays: prop_types_1.default.bool,
    numberOfMonths: prop_types_1.default.number,
    orientation: ScrollableOrientationShape_1.default,
    withPortal: prop_types_1.default.bool,
    initialVisibleMonth: prop_types_1.default.func,
    firstDayOfWeek: DayOfWeekShape_1.default,
    hideKeyboardShortcutsPanel: prop_types_1.default.bool,
    daySize: airbnb_prop_types_1.nonNegativeInteger,
    navPrev: prop_types_1.default.node,
    navNext: prop_types_1.default.node,
    onPrevMonthClick: prop_types_1.default.func,
    onNextMonthClick: prop_types_1.default.func,
    onOutsideClick: prop_types_1.default.func,
    renderDay: prop_types_1.default.func,
    renderCalendarInfo: prop_types_1.default.func,
    // accessibility
    onBlur: prop_types_1.default.func,
    isFocused: prop_types_1.default.bool,
    showKeyboardShortcuts: prop_types_1.default.bool,
    // i18n
    monthFormat: prop_types_1.default.string,
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.DayPickerPhrases)),
    isRTL: prop_types_1.default.bool,
    theme: prop_types_1.default.any,
});
const defaultProps = {
    date: undefined,
    onDateChange() { },
    focused: false,
    onFocusChange() { },
    onClose() { },
    keepOpenOnDateSelect: false,
    minimumNights: 1,
    isOutsideRange() { },
    isDayBlocked() { },
    isDayHighlighted() { },
    // DayPicker props
    renderMonth: null,
    enableOutsideDays: false,
    numberOfMonths: 1,
    orientation: Constants_1.HORIZONTAL_ORIENTATION,
    withPortal: false,
    hideKeyboardShortcutsPanel: false,
    initialVisibleMonth: null,
    firstDayOfWeek: null,
    daySize: Constants_1.DAY_SIZE,
    navPrev: null,
    navNext: null,
    onPrevMonthClick() { },
    onNextMonthClick() { },
    onOutsideClick() { },
    renderDay: null,
    renderCalendarInfo: null,
    // accessibility
    onBlur() { },
    isFocused: false,
    showKeyboardShortcuts: false,
    // i18n
    monthFormat: 'MMMM YYYY',
    phrases: defaultPhrases_1.DayPickerPhrases,
    isRTL: false,
};
class DayPickerSingleDateController extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.isTouchDevice = false;
        this.today = moment_1.default();
        this.modifiers = {
            today: day => this.isToday(day),
            blocked: day => this.isBlocked(day),
            'blocked-calendar': day => props.isDayBlocked(day),
            'blocked-out-of-range': day => props.isOutsideRange(day),
            'highlighted-calendar': day => props.isDayHighlighted(day),
            valid: day => !this.isBlocked(day),
            hovered: day => this.isHovered(day),
            selected: day => this.isSelected(day),
        };
        const { currentMonth, visibleDays } = this.getStateForNewMonth(props);
        this.state = {
            hoverDate: null,
            currentMonth,
            visibleDays,
        };
        this.onDayMouseEnter = this.onDayMouseEnter.bind(this);
        this.onDayMouseLeave = this.onDayMouseLeave.bind(this);
        this.onDayClick = this.onDayClick.bind(this);
        this.onPrevMonthClick = this.onPrevMonthClick.bind(this);
        this.onNextMonthClick = this.onNextMonthClick.bind(this);
        this.getFirstFocusableDay = this.getFirstFocusableDay.bind(this);
    }
    componentDidMount() {
        this.isTouchDevice = is_touch_device_1.default();
    }
    componentWillReceiveProps(nextProps) {
        const { date, focused, isOutsideRange, isDayBlocked, isDayHighlighted, initialVisibleMonth, numberOfMonths, enableOutsideDays, } = nextProps;
        let { visibleDays } = this.state;
        if (isOutsideRange !== this.props.isOutsideRange) {
            this.modifiers['blocked-out-of-range'] = day => isOutsideRange(day);
        }
        if (isDayBlocked !== this.props.isDayBlocked) {
            this.modifiers['blocked-calendar'] = day => isDayBlocked(day);
        }
        if (isDayHighlighted !== this.props.isDayHighlighted) {
            this.modifiers['highlighted-calendar'] = day => isDayHighlighted(day);
        }
        if (initialVisibleMonth !== this.props.initialVisibleMonth ||
            numberOfMonths !== this.props.numberOfMonths ||
            enableOutsideDays !== this.props.enableOutsideDays) {
            const newMonthState = this.getStateForNewMonth(nextProps);
            const currentMonth = newMonthState.currentMonth;
            visibleDays = newMonthState.visibleDays;
            this.setState({
                currentMonth,
                visibleDays,
            });
        }
        const didDateChange = date !== this.props.date;
        const didFocusChange = focused !== this.props.focused;
        let modifiers = {};
        if (didDateChange) {
            modifiers = this.deleteModifier(modifiers, this.props.date, 'selected');
            modifiers = this.addModifier(modifiers, date, 'selected');
        }
        if (didFocusChange) {
            object_values_1.default(visibleDays).forEach((days) => {
                Object.keys(days).forEach((day) => {
                    const momentObj = moment_1.default(day);
                    if (this.isBlocked(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked');
                    }
                    if (isOutsideRange(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked-out-of-range');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked-out-of-range');
                    }
                    if (isDayBlocked(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'blocked-calendar');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'blocked-calendar');
                    }
                    if (isDayHighlighted(momentObj)) {
                        modifiers = this.addModifier(modifiers, momentObj, 'highlighted-calendar');
                    }
                    else {
                        modifiers = this.deleteModifier(modifiers, momentObj, 'highlighted-calendar');
                    }
                });
            });
        }
        const today = moment_1.default();
        if (!isSameDay_1.default(this.today, today)) {
            modifiers = this.deleteModifier(modifiers, this.today, 'today');
            modifiers = this.addModifier(modifiers, today, 'today');
            this.today = today;
        }
        if (Object.keys(modifiers).length > 0) {
            this.setState({
                visibleDays: Object.assign({}, visibleDays, modifiers),
            });
        }
    }
    componentWillUpdate() {
        this.today = moment_1.default();
    }
    onDayClick(day, e) {
        if (e)
            e.preventDefault();
        if (this.isBlocked(day))
            return;
        const { onDateChange, keepOpenOnDateSelect, onFocusChange, onClose, } = this.props;
        onDateChange(day);
        if (!keepOpenOnDateSelect) {
            onFocusChange({ focused: null });
            onClose({ date: day });
        }
    }
    onDayMouseEnter(day) {
        if (this.isTouchDevice)
            return;
        const { hoverDate, visibleDays } = this.state;
        let modifiers = this.deleteModifier({}, hoverDate, 'hovered');
        modifiers = this.addModifier(modifiers, day, 'hovered');
        this.setState({
            hoverDate: day,
            visibleDays: Object.assign({}, visibleDays, modifiers),
        });
    }
    onDayMouseLeave() {
        const { hoverDate, visibleDays } = this.state;
        if (this.isTouchDevice || !hoverDate)
            return;
        const modifiers = this.deleteModifier({}, hoverDate, 'hovered');
        this.setState({
            hoverDate: null,
            visibleDays: Object.assign({}, visibleDays, modifiers),
        });
    }
    onPrevMonthClick() {
        const { onPrevMonthClick, numberOfMonths, enableOutsideDays } = this.props;
        const { currentMonth, visibleDays } = this.state;
        const newVisibleDays = {};
        Object.keys(visibleDays).sort().slice(0, numberOfMonths + 1).forEach((month) => {
            newVisibleDays[month] = visibleDays[month];
        });
        const prevMonth = currentMonth.clone().subtract(1, 'month');
        const prevMonthVisibleDays = getVisibleDays_1.default(prevMonth, 1, enableOutsideDays);
        this.setState({
            currentMonth: prevMonth,
            visibleDays: Object.assign({}, newVisibleDays, this.getModifiers(prevMonthVisibleDays)),
        });
        onPrevMonthClick();
    }
    onNextMonthClick() {
        const { onNextMonthClick, numberOfMonths, enableOutsideDays } = this.props;
        const { currentMonth, visibleDays } = this.state;
        const newVisibleDays = {};
        Object.keys(visibleDays).sort().slice(1).forEach((month) => {
            newVisibleDays[month] = visibleDays[month];
        });
        const nextMonth = currentMonth.clone().add(numberOfMonths, 'month');
        const nextMonthVisibleDays = getVisibleDays_1.default(nextMonth, 1, enableOutsideDays);
        this.setState({
            currentMonth: currentMonth.clone().add(1, 'month'),
            visibleDays: Object.assign({}, newVisibleDays, this.getModifiers(nextMonthVisibleDays)),
        });
        onNextMonthClick();
    }
    getFirstFocusableDay(newMonth) {
        const { date, numberOfMonths } = this.props;
        let focusedDate = newMonth.clone().startOf('month');
        if (date) {
            focusedDate = date.clone();
        }
        if (this.isBlocked(focusedDate)) {
            const days = [];
            const lastVisibleDay = newMonth.clone().add(numberOfMonths - 1, 'months').endOf('month');
            let currentDay = focusedDate.clone();
            while (!isAfterDay_1.default(currentDay, lastVisibleDay)) {
                currentDay = currentDay.clone().add(1, 'day');
                days.push(currentDay);
            }
            const viableDays = days.filter(day => !this.isBlocked(day) && isAfterDay_1.default(day, focusedDate));
            if (viableDays.length > 0)
                focusedDate = viableDays[0];
        }
        return focusedDate;
    }
    getModifiers(visibleDays) {
        const modifiers = {};
        Object.keys(visibleDays).forEach((month) => {
            modifiers[month] = {};
            visibleDays[month].forEach((day) => {
                modifiers[month][toISODateString_1.default(day)] = this.getModifiersForDay(day);
            });
        });
        return modifiers;
    }
    getModifiersForDay(day) {
        return new Set(Object.keys(this.modifiers).filter(modifier => this.modifiers[modifier](day)));
    }
    getStateForNewMonth(nextProps) {
        const { initialVisibleMonth, date, numberOfMonths, enableOutsideDays } = nextProps;
        const initialVisibleMonthThunk = initialVisibleMonth || (date ? () => date : () => this.today);
        const currentMonth = initialVisibleMonthThunk();
        const visibleDays = this.getModifiers(getVisibleDays_1.default(currentMonth, numberOfMonths, enableOutsideDays));
        return { currentMonth, visibleDays };
    }
    addModifier(updatedDays, day, modifier) {
        const { numberOfMonths: numberOfVisibleMonths, enableOutsideDays, orientation } = this.props;
        const { currentMonth: firstVisibleMonth, visibleDays } = this.state;
        let currentMonth = firstVisibleMonth;
        let numberOfMonths = numberOfVisibleMonths;
        if (orientation !== Constants_1.VERTICAL_SCROLLABLE) {
            currentMonth = currentMonth.clone().subtract(1, 'month');
            numberOfMonths += 2;
        }
        if (!day || !isDayVisible_1.default(day, currentMonth, numberOfMonths, enableOutsideDays)) {
            return updatedDays;
        }
        const iso = toISODateString_1.default(day);
        let updatedDaysAfterAddition = Object.assign({}, updatedDays);
        if (enableOutsideDays) {
            const monthsToUpdate = Object.keys(visibleDays).filter(monthKey => (Object.keys(visibleDays[monthKey]).indexOf(iso) > -1));
            updatedDaysAfterAddition = monthsToUpdate.reduce((days, monthIso) => {
                const month = updatedDays[monthIso] || visibleDays[monthIso];
                const modifiers = new Set(month[iso]);
                modifiers.add(modifier);
                return Object.assign({}, days, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
            }, updatedDaysAfterAddition);
        }
        else {
            const monthIso = toISOMonthString_1.default(day);
            const month = updatedDays[monthIso] || visibleDays[monthIso];
            const modifiers = new Set(month[iso]);
            modifiers.add(modifier);
            updatedDaysAfterAddition = Object.assign({}, updatedDaysAfterAddition, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
        }
        return updatedDaysAfterAddition;
    }
    deleteModifier(updatedDays, day, modifier) {
        const { numberOfMonths: numberOfVisibleMonths, enableOutsideDays, orientation } = this.props;
        const { currentMonth: firstVisibleMonth, visibleDays } = this.state;
        let currentMonth = firstVisibleMonth;
        let numberOfMonths = numberOfVisibleMonths;
        if (orientation !== Constants_1.VERTICAL_SCROLLABLE) {
            currentMonth = currentMonth.clone().subtract(1, 'month');
            numberOfMonths += 2;
        }
        if (!day || !isDayVisible_1.default(day, currentMonth, numberOfMonths, enableOutsideDays)) {
            return updatedDays;
        }
        const iso = toISODateString_1.default(day);
        let updatedDaysAfterDeletion = Object.assign({}, updatedDays);
        if (enableOutsideDays) {
            const monthsToUpdate = Object.keys(visibleDays).filter(monthKey => (Object.keys(visibleDays[monthKey]).indexOf(iso) > -1));
            updatedDaysAfterDeletion = monthsToUpdate.reduce((days, monthIso) => {
                const month = updatedDays[monthIso] || visibleDays[monthIso];
                const modifiers = new Set(month[iso]);
                modifiers.delete(modifier);
                return Object.assign({}, days, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
            }, updatedDaysAfterDeletion);
        }
        else {
            const monthIso = toISOMonthString_1.default(day);
            const month = updatedDays[monthIso] || visibleDays[monthIso];
            const modifiers = new Set(month[iso]);
            modifiers.delete(modifier);
            updatedDaysAfterDeletion = Object.assign({}, updatedDaysAfterDeletion, { [monthIso]: Object.assign({}, month, { [iso]: modifiers }) });
        }
        return updatedDaysAfterDeletion;
    }
    isBlocked(day) {
        const { isDayBlocked, isOutsideRange } = this.props;
        return isDayBlocked(day) || isOutsideRange(day);
    }
    isHovered(day) {
        const { hoverDate } = this.state || {};
        return isSameDay_1.default(day, hoverDate);
    }
    isSelected(day) {
        return isSameDay_1.default(day, this.props.date);
    }
    isToday(day) {
        return isSameDay_1.default(day, this.today);
    }
    render() {
        const { numberOfMonths, orientation, monthFormat, renderMonth, navPrev, navNext, withPortal, focused, enableOutsideDays, hideKeyboardShortcutsPanel, daySize, firstDayOfWeek, renderDay, renderCalendarInfo, isFocused, isRTL, } = this.props;
        const { phrases, currentMonth, visibleDays } = this.state;
        return (react_1.default.createElement(DayPicker_1.default, { orientation: orientation, enableOutsideDays: enableOutsideDays, modifiers: visibleDays, numberOfMonths: numberOfMonths, onDayClick: this.onDayClick, onDayMouseEnter: this.onDayMouseEnter, onDayMouseLeave: this.onDayMouseLeave, onPrevMonthClick: this.onPrevMonthClick, onNextMonthClick: this.onNextMonthClick, monthFormat: monthFormat, withPortal: withPortal, hidden: !focused, hideKeyboardShortcutsPanel: hideKeyboardShortcutsPanel, initialVisibleMonth: () => currentMonth, firstDayOfWeek: firstDayOfWeek, navPrev: navPrev, navNext: navNext, renderMonth: renderMonth, renderDay: renderDay, renderCalendarInfo: renderCalendarInfo, isFocused: isFocused, getFirstFocusableDay: this.getFirstFocusableDay, onBlur: this.onDayPickerBlur, phrases: phrases, daySize: daySize, isRTL: isRTL }));
    }
}
exports.default = DayPickerSingleDateController;
DayPickerSingleDateController.propTypes = propTypes;
DayPickerSingleDateController.defaultProps = defaultProps;
