"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const prop_types_1 = require("prop-types");
const airbnb_prop_types_1 = require("airbnb-prop-types");
const classnames_1 = require("classnames");
const defaultPhrases_1 = require("../defaultPhrases");
const getPhrasePropTypes_1 = require("../utils/getPhrasePropTypes");
const react_css_themr_1 = require("react-css-themr");
const DateInput_1 = require("./DateInput");
const close_svg_1 = require("../svg/close.svg");
const calendar_svg_1 = require("../svg/calendar.svg");
const ThemeIdentifiers_1 = require("./../../ThemeIdentifiers");
const baseTheme = require("./../style/style.scss");
const propTypes = airbnb_prop_types_1.forbidExtraProps({
    id: prop_types_1.default.string.isRequired,
    placeholder: prop_types_1.default.string,
    displayValue: prop_types_1.default.string,
    inputValue: prop_types_1.default.string,
    screenReaderMessage: prop_types_1.default.string,
    focused: prop_types_1.default.bool,
    isFocused: prop_types_1.default.bool,
    disabled: prop_types_1.default.bool,
    required: prop_types_1.default.bool,
    readOnly: prop_types_1.default.bool,
    showCaret: prop_types_1.default.bool,
    showClearDate: prop_types_1.default.bool,
    customCloseIcon: prop_types_1.default.node,
    showDefaultInputIcon: prop_types_1.default.bool,
    customInputIcon: prop_types_1.default.node,
    isRTL: prop_types_1.default.bool,
    onChange: prop_types_1.default.func,
    onClearDate: prop_types_1.default.func,
    onFocus: prop_types_1.default.func,
    onKeyDownShiftTab: prop_types_1.default.func,
    onKeyDownTab: prop_types_1.default.func,
    onKeyDownArrowDown: prop_types_1.default.func,
    // i18n
    phrases: prop_types_1.default.shape(getPhrasePropTypes_1.default(defaultPhrases_1.SingleDatePickerInputPhrases)),
    theme: prop_types_1.default.any,
});
const defaultProps = {
    placeholder: 'Select Date',
    displayValue: '',
    inputValue: '',
    screenReaderMessage: '',
    focused: false,
    isFocused: false,
    disabled: false,
    required: false,
    readOnly: false,
    showCaret: false,
    showClearDate: false,
    showDefaultInputIcon: false,
    customCloseIcon: null,
    customInputIcon: null,
    isRTL: false,
    onChange() { },
    onClearDate() { },
    onFocus() { },
    onKeyDownShiftTab() { },
    onKeyDownTab() { },
    onKeyDownArrowDown() { },
    // i18n
    phrases: defaultPhrases_1.SingleDatePickerInputPhrases,
};
class SingleDatePickerInput extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            isClearDateHovered: false,
        };
        this.onClearDateMouseEnter = this.onClearDateMouseEnter.bind(this);
        this.onClearDateMouseLeave = this.onClearDateMouseLeave.bind(this);
    }
    onClearDateMouseEnter() {
        this.setState({
            isClearDateHovered: true,
        });
    }
    onClearDateMouseLeave() {
        this.setState({
            isClearDateHovered: false,
        });
    }
    render() {
        const { isClearDateHovered } = this.state;
        const { id, placeholder, displayValue, inputValue, focused, isFocused, disabled, required, readOnly, showCaret, showClearDate, showDefaultInputIcon, phrases, onClearDate, onChange, onFocus, onKeyDownShiftTab, onKeyDownTab, onKeyDownArrowDown, screenReaderMessage, customCloseIcon, customInputIcon, isRTL, theme, } = this.props;
        const inputIcon = customInputIcon || (react_1.default.createElement(calendar_svg_1.default, null));
        const closeIcon = customCloseIcon || (react_1.default.createElement(close_svg_1.default, null));
        const screenReaderText = screenReaderMessage || phrases.keyboardNavigationInstructions;
        return (react_1.default.createElement("div", { className: classnames_1.default(theme['SingleDatePickerInput'], {
                [theme['SingleDatePickerInput--rtl']]: isRTL,
            }) },
            (showDefaultInputIcon || customInputIcon !== null) && (react_1.default.createElement("button", { type: "button", className: theme["SingleDatePickerInput__calendar-icon"], disabled: disabled, "aria-label": phrases.focusStartDate, onClick: onFocus }, inputIcon)),
            react_1.default.createElement(DateInput_1.default, { id: id, placeholder: placeholder, displayValue: displayValue, inputValue: inputValue, screenReaderMessage: screenReaderText, focused: focused, isFocused: isFocused, disabled: disabled, required: required, readOnly: readOnly, showCaret: showCaret, onChange: onChange, onFocus: onFocus, onKeyDownShiftTab: onKeyDownShiftTab, onKeyDownTab: onKeyDownTab, onKeyDownArrowDown: onKeyDownArrowDown }),
            showClearDate && (react_1.default.createElement("button", { type: "button", className: classnames_1.default(theme['SingleDatePickerInput__clear-date'], {
                    [theme['SingleDatePickerInput__clear-date--hide']]: !displayValue,
                    [theme['SingleDatePickerInput__clear-date--hover']]: isClearDateHovered,
                }), "aria-label": phrases.clearDate, onMouseEnter: this.onClearDateMouseEnter, onMouseLeave: this.onClearDateMouseLeave, onClick: onClearDate },
                react_1.default.createElement("div", { className: theme["DateRangePickerInput__close"] }, closeIcon)))));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.DATEPICKER, baseTheme)(SingleDatePickerInput);
SingleDatePickerInput.propTypes = propTypes;
SingleDatePickerInput.defaultProps = defaultProps;
