"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const DisplayText_1 = require("../DisplayText");
const theme = {
    displayText: 'DisplayText',
    sizeSmall: 'sizeSmall',
    sizeMedium: 'sizeMedium',
    sizeLarge: 'sizeLarge',
    sizeExtraLarge: 'sizeExtraLarge',
};
describe('<DisplayText />', () => {
    describe('when default props are provided', () => {
        it('basic displaytext should have rendered one div element', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
            expect(displaytextWrapper.find('p')).toHaveLength(1);
        });
        it('basic displaytext should have default DisplayText css class on div', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
            expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
        });
        it('basic displaytext should have default sizeMedium css class on div', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
            expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
        });
    });
    describe('element property', () => {
        describe('when not set', () => {
            it('basic displaytext should have rendered one div element', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p')).toHaveLength(1);
            });
            it('basic displaytext should have default DisplayText css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
            });
            it('basic displaytext should have default sizeMedium css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
            });
            it('should verify element when not defined/set', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.prop('element')).toBeUndefined();
                expect(displaytextWrapper.find('element')).toHaveLength(0);
            });
        });
        describe('when set', () => {
            it('should verify element when set as h1 with css class and div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { element: 'h1', theme: theme }, "Good Morning, Hardik."));
                expect(displaytextWrapper.prop('element')).toBe('h1');
                expect(displaytextWrapper.find('h1')).toHaveLength(1);
                expect(displaytextWrapper.find('h1').at(0).hasClass('DisplayText')).toBe(true);
                expect(displaytextWrapper.find('h1').at(0).hasClass('sizeMedium')).toBe(true);
            });
        });
    });
    describe('size property', () => {
        describe('when not set', () => {
            it('basic displaytext should have rendered one div element', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p')).toHaveLength(1);
            });
            it('basic displaytext should have default DisplayText css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
            });
            it('basic displaytext should have default sizeMedium css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
            });
            it('should verify size when not defined/set', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning, Hardik."));
                expect(displaytextWrapper.prop('size')).toBeUndefined();
                expect(displaytextWrapper.find('size')).toHaveLength(0);
            });
        });
        describe('when set', () => {
            it('basic displaytext should have rendered one div element', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'extraLarge', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p')).toHaveLength(1);
            });
            it('basic displaytext should have default DisplayText css on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'extraLarge', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
            });
            it('should verify size when set as extraLarge with css class', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'extraLarge', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.prop('size')).toBe('extraLarge');
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeExtraLarge')).toBe(true);
            });
            it('should verify size when set as large with css class', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'large', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.prop('size')).toBe('large');
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeLarge')).toBe(true);
            });
            it('should verify size when set as medium with css class', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'medium', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.prop('size')).toBe('medium');
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
            });
            it('should verify size when set as medium with css class', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { size: 'small', theme: theme }, "Good Morning."));
                expect(displaytextWrapper.prop('size')).toBe('small');
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeSmall')).toBe(true);
            });
        });
    });
    describe('children property', () => {
        describe('when not set', () => {
            it('basic displaytext should have rendered one div element', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p')).toHaveLength(1);
            });
            it('basic displaytext should have default DisplayText css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
            });
            it('basic displaytext should have default sizeMedium css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
            });
            it('should verify children not defined', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }));
                expect(displaytextWrapper.prop('children')).toBeUndefined();
                expect(displaytextWrapper.find('children')).toHaveLength(0);
            });
        });
        describe('when set', () => {
            it('basic displaytext should have rendered one div element', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p')).toHaveLength(1);
            });
            it('basic displaytext should have default DisplayText css on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p').at(0).hasClass('DisplayText')).toBe(true);
            });
            it('basic displaytext should have default sizeMedium css class on div', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning."));
                expect(displaytextWrapper.find('p').at(0).hasClass('sizeMedium')).toBe(true);
            });
            it('should verify children when set', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { theme: theme }, "Good Morning"));
                expect(displaytextWrapper.prop('children')).toBe('Good Morning');
                expect(displaytextWrapper.prop('children')).toBeDefined();
            });
            it('should verify children when set in same tag', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { children: "Good Morning", theme: theme }));
                expect(displaytextWrapper.prop('children')).toBe('Good Morning');
                expect(displaytextWrapper.prop('children')).toBeDefined();
            });
            it('should verify children when set as blank', () => {
                const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { children: "", theme: theme }));
                expect(displaytextWrapper.prop('children')).toBeDefined();
            });
        });
    });
    describe('Verify all property together', () => {
        it('basic displaytext should have rendered one div element', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { element: "h3", size: "small", theme: theme }, "Good evening"));
            expect(displaytextWrapper.find('h3')).toHaveLength(1);
        });
        it('basic displaytext should have DisplayText css class on div', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { element: "h3", size: "small", theme: theme }, "Good evening"));
            expect(displaytextWrapper.find('h3').at(0).hasClass('DisplayText')).toBe(true);
        });
        it('basic displaytext should have sizeSmall css class on div', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { element: "h3", size: "small", theme: theme }, "Good evening"));
            expect(displaytextWrapper.find('h3').at(0).hasClass('sizeSmall')).toBe(true);
        });
        it('should verify all properties are set', () => {
            const displaytextWrapper = enzyme_1.mount(React.createElement(DisplayText_1.default, { element: "h3", size: "small", theme: theme }, "Good evening"));
            expect(displaytextWrapper.prop('element')).toBe('h3');
            expect(displaytextWrapper.prop('size')).toBe('small');
            expect(displaytextWrapper.prop('children')).toBe('Good evening');
        });
    });
});
