"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const EventListener_1 = require("../EventListener");
describe('<EventListener />', () => {
    it('calls handler when the appropriate event is fired', () => {
        const spy = jest.fn();
        enzyme_1.mount(React.createElement(EventListener_1.default, { event: "resize", handler: spy }));
        window.dispatchEvent(new Event('resize'));
        expect(spy).toHaveBeenCalled();
    });
    it('does not call handler when a different event is fired', () => {
        const spy = jest.fn();
        enzyme_1.mount(React.createElement(EventListener_1.default, { event: "click", handler: spy }));
        window.dispatchEvent(new Event('resize'));
        expect(spy).not.toHaveBeenCalled();
    });
    it('removes listener when unmounted', () => {
        const spy = jest.fn();
        enzyme_1.mount(React.createElement(EventListener_1.default, { event: "resize", handler: spy })).unmount();
        window.dispatchEvent(new Event('resize'));
        expect(spy).not.toHaveBeenCalled();
    });
});
