"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const TextField_1 = require("../../TextField/TextField");
const FormLayout_1 = require("../FormLayout");
const Group_1 = require("../Group");
describe('<FormLayout />', () => {
    const theme = {
        formLayout: 'FormLayout',
        condensed: 'condensed',
        title: 'Title',
        items: 'Items',
        helpText: 'HelpText',
        item: 'Item',
    };
    describe('Default FormLayout', () => {
        it('should verify formlayout without children has 1 div tag', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null));
            expect(formlayoutWrapper.find('div').length).toBe(1);
        });
        it('should verify number of components and keys respect to the position', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(TextField_1.default, { label: "Store name" }),
                React.createElement(TextField_1.default, { label: "Account email" })));
            expect(formlayoutWrapper.find('input').length).toBe(2);
            expect(formlayoutWrapper.children().at(0).key()).toBe('0/.0');
            expect(formlayoutWrapper.children().at(1).key()).toBe('1/.1');
        });
        it('should verify that it has 2 Textfields as children', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(TextField_1.default, { label: "Store name" }),
                React.createElement(TextField_1.default, { label: "Account email" })));
            expect(formlayoutWrapper.find('TextField').length).toBe(2);
        });
    });
    describe('Formlayout with Field Groups', () => {
        it('should verify formlayout with Group and do not have any children has 3 div tag', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, { condensed: true })));
            expect(formlayoutWrapper.find('div').length).toBe(3);
        });
        it('should verify formlayout Group when Group is defined', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, null,
                    React.createElement(TextField_1.default, { type: "number", label: "Minimum order" }),
                    React.createElement(TextField_1.default, { type: "number", label: "Maximum order" }))));
            expect(formlayoutWrapper.find(Group_1.default).length).toBe(1);
        });
        it('should verify the formlayout with Groups and keys respect to the position', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, null,
                    React.createElement(TextField_1.default, { type: "number", label: "Minimum order" }),
                    React.createElement(TextField_1.default, { type: "number", label: "Maximum order" }))));
            expect(formlayoutWrapper.children().childAt(0).childAt(0).key()).toBe('.0');
            expect(formlayoutWrapper.children().childAt(0).childAt(1).key()).toBe('.1');
        });
    });
    describe('Formlayout with condensed option', () => {
        it('should verify the formlayout with condensed format', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, { condensed: true },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Width" }),
                    React.createElement(TextField_1.default, { label: "Height" }),
                    React.createElement(TextField_1.default, { label: "Unit" }))));
            expect(formlayoutWrapper.childAt(0).prop('condensed')).toBe(true);
            expect(formlayoutWrapper.children().childAt(0).childAt(0).key()).toBe('.0');
            expect(formlayoutWrapper.children().childAt(0).childAt(1).key()).toBe('.1');
            expect(formlayoutWrapper.children().childAt(0).childAt(2).key()).toBe('.2');
            expect(formlayoutWrapper.children().childAt(0).childAt(3).key()).toBe('.3');
        });
        it('should verify form layout when condensed is undefined', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, { title: "groupTitle" },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Width" }),
                    React.createElement(TextField_1.default, { label: "Height" }),
                    React.createElement(TextField_1.default, { label: "Unit" }))));
            expect(formlayoutWrapper.childAt(0).prop('condensed')).toBeFalsy();
        });
        it('should verify form layout when condensed is false', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, null,
                React.createElement(Group_1.default, { title: "groupTitle", condensed: false },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Width" }),
                    React.createElement(TextField_1.default, { label: "Height" }),
                    React.createElement(TextField_1.default, { label: "Unit" }))));
            expect(formlayoutWrapper.childAt(0).prop('condensed')).toBe(false);
        });
    });
    describe('Formlayout with Theme applied', () => {
        it('should verify formlayout class for first div tag', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, { theme: theme },
                React.createElement(Group_1.default, { theme: theme, condensed: true },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Height" }))));
            expect(formlayoutWrapper.find('div').at(0).hasClass('FormLayout')).toBe(true);
        });
        it('should verify condensed class when condensed set', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, { theme: theme },
                React.createElement(Group_1.default, { theme: theme, condensed: true },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Height" }))));
            expect(formlayoutWrapper.find('div').at(1).hasClass('condensed')).toBe(true);
        });
        it('should verify condensed class when condensed set', () => {
            const formlayoutWrapper = enzyme_1.mount(React.createElement(FormLayout_1.default, { theme: theme },
                React.createElement(Group_1.default, { theme: theme, condensed: true },
                    React.createElement(TextField_1.default, { label: "Length" }),
                    React.createElement(TextField_1.default, { label: "Height" }))));
            expect(formlayoutWrapper.find('div').at(2).hasClass('Items')).toBe(true);
        });
    });
});
