"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const icons_1 = require("../../icons");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Icon.scss");
exports.BUNDLED_ICONS = {
    add: icons_1.add,
    alert: icons_1.alert,
    arrowDown: icons_1.arrowDown,
    arrowLeft: icons_1.arrowLeft,
    arrowRight: icons_1.arrowRight,
    arrowUp: icons_1.arrowUp,
    calendar: icons_1.calendar,
    cancel: icons_1.cancel,
    cancelSmall: icons_1.cancelSmall,
    caretDown: icons_1.caretDown,
    caretUp: icons_1.caretUp,
    chevronDown: icons_1.chevronDown,
    chevronLeft: icons_1.chevronLeft,
    chevronRight: icons_1.chevronRight,
    chevronUp: icons_1.chevronUp,
    circleCancel: icons_1.circleCancel,
    circleChevronDown: icons_1.circleChevronDown,
    circleChevronLeft: icons_1.circleChevronLeft,
    circleChevronRight: icons_1.circleChevronRight,
    circleChevronUp: icons_1.circleChevronUp,
    circlePlus: icons_1.circlePlus,
    conversation: icons_1.conversation,
    disable: icons_1.disable,
    dispute: icons_1.dispute,
    duplicate: icons_1.duplicate,
    embed: icons_1.embed,
    external: icons_1.external,
    horizontalDots: icons_1.horizontalDots,
    notes: icons_1.notes,
    print: icons_1.print,
    refresh: icons_1.refresh,
    risk: icons_1.risk,
    search: icons_1.search,
    spinner: icons_1.spinner,
    view: icons_1.view,
    delete: icons_1.delete,
    export: icons_1.export,
    import: icons_1.import,
};
const COLORS_WITH_BACKDROPS = ['teal', 'tealDark', 'greenDark', 'redDark', 'yellowDark', 'ink'];
const icon = ({ source, color, backdrop, accessibilityLabel, style, theme, }) => {
    if (color && backdrop && COLORS_WITH_BACKDROPS.indexOf(color) < 0) {
        // tslint:disable-next-line no-console
        console.warn(`The ${color} icon doesn't accept backdrops. The icon colors that have backdrops are: ${COLORS_WITH_BACKDROPS.join(', ')}`);
    }
    const className = styles_1.classNames(theme.icon, color && theme[styles_1.variationName('color', color)], backdrop && theme.hasBackdrop);
    let contentMarkup;
    if (!source) {
        // tslint:disable-next-line no-console
        console.warn(`The source prop is null in Icon Component.`);
    }
    else if (source === 'placeholder') {
        contentMarkup = React.createElement("div", { className: theme.placeholder });
    }
    else {
        const iconSource = typeof source === 'string' ? exports.BUNDLED_ICONS[source] : source;
        if (iconSource) {
            contentMarkup = (React.createElement("svg", { className: theme.svg, viewBox: iconSource.viewBox, dangerouslySetInnerHTML: { __html: iconSource.body } }));
        }
    }
    return (React.createElement("span", { className: className, style: style, "aria-label": accessibilityLabel }, contentMarkup));
};
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.ICON, baseTheme)(icon);
