"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const Label_1 = require("../Label");
exports.labelID = Label_1.labelID;
const Message_1 = require("../Message");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Labelled.scss");
const labelled = (_a) => {
    var { id, label, errors, children, labelHidden, helpText, required, focused, hasValue, style, theme } = _a, rest = tslib_1.__rest(_a, ["id", "label", "errors", "children", "labelHidden", "helpText", "required", "focused", "hasValue", "style", "theme"]);
    const wrapperClassName = styles_1.classNames(labelHidden && theme.hidden);
    const labelWrapperClassName = styles_1.classNames(theme.labelWrapper, required && theme.required, focused && theme.focused, (errors && errors) && theme.invalid, !hasValue && theme.empty);
    const helpTextMarkup = helpText
        ? React.createElement("div", { className: theme.helpText, id: helpTextID(id) }, helpText)
        : null;
    const errorId = errorID(id);
    const errorMarkup = errors
        ? (React.createElement(Message_1.default, { id: errorId, isVisible: true }, errors instanceof Array ? errors.join(', ') : (typeof errors === 'string' ? errors : 'An error occurred.')))
        : null;
    const labelMarkup = label
        ? (React.createElement("div", { className: labelWrapperClassName, id: 'labelMarkup' },
            React.createElement(Label_1.default, Object.assign({ id: id, hidden: false, focused: focused, hasValue: hasValue, required: required }, rest), label)))
        : null;
    return (React.createElement("div", { className: wrapperClassName, "aria-describedby": errorId, id: 'labelled.tsx', style: style },
        errorMarkup,
        labelMarkup,
        children,
        helpTextMarkup));
};
function errorID(id) {
    return `${id}Error`;
}
exports.errorID = errorID;
function helpTextID(id) {
    return `${id}HelpText`;
}
exports.helpTextID = helpTextID;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.LABELLED, baseTheme)(labelled);
