"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Link_1 = require("../Link");
const theme = {
    external: 'external',
    url: 'https://www.google.co.in',
    children: 'children',
};
describe('<Link />', () => {
    describe('onClick()', () => {
        it('should verify the Link is clicked', () => {
            const spy = jest.fn();
            const linkWrapper = enzyme_1.shallow(React.createElement(Link_1.default, { onClick: spy }, "Test"));
            linkWrapper.simulate('click');
        });
    });
    describe('external property', () => {
        describe('when not set', () => {
            it('should not have external element', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, null));
                expect(linkWrapper.find('external')).toHaveLength(0);
            });
            it('should external element is undfine', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, null));
                expect(linkWrapper.prop('external')).toBeUndefined();
            });
        });
        describe('when set to true', () => {
            it('should verify the external is true', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, { external: true }));
                expect(linkWrapper.prop('external')).toBe(true);
            });
        });
        describe('when set to false', () => {
            it('should verify the external is false', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, { external: false }));
                expect(linkWrapper.prop('external')).toBe(false);
            });
        });
    });
    describe('url prop', () => {
        describe('when set', () => {
            it('should verify the url', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, { url: theme.url }));
                expect(linkWrapper.prop('url')).toBe(theme.url);
            });
        });
        describe('when not set', () => {
            it('should verify the url', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, null));
                expect(linkWrapper.prop('url')).toBeUndefined();
            });
            it('should not have url element', () => {
                const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, null));
                expect(linkWrapper.find('url')).toHaveLength(0);
            });
        });
    });
    describe('set children property', () => {
        it('should verify children text', () => {
            const linkWrapper = enzyme_1.mount(React.createElement(Link_1.default, null, "Please click here"));
            expect(linkWrapper.prop('children')).toBe('Please click here');
        });
    });
});
