"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
// tslint:disable-next-line
const TextField_1 = require("../TextField");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const parseMask_1 = require("./parseMask");
const environment_1 = require("./environment");
const string_1 = require("./string");
const defer_1 = require("./defer");
const baseTheme = require("./MaskTextField.scss");
class MaskTextField extends React.PureComponent {
    constructor(props) {
        super(props);
        this.hasValue = false;
        this.getInputDOMNode = () => {
            const input = this.input;
            if (!input) {
                return null;
            }
            return this.input._reactInternalInstance._renderedComponent._instance.input;
        };
        this.getInputValue = () => {
            const input = this.getInputDOMNode();
            if (!input) {
                return null;
            }
            return input.value;
        };
        this.setInputValue = (value) => {
            const input = this.getInputDOMNode();
            if (!input) {
                return;
            }
            this.setState({ ['value']: value });
        };
        this.getLeftEditablePos = (pos) => {
            for (let i = pos; i >= 0; --i) {
                if (!string_1.isPermanentChar(this.maskOptions, i)) {
                    return i;
                }
            }
            return null;
        };
        this.getRightEditablePos = (pos) => {
            const { mask } = this.maskOptions;
            for (let i = pos; i < mask.length; ++i) {
                if (!string_1.isPermanentChar(this.maskOptions, i)) {
                    return i;
                }
            }
            return null;
        };
        this.setCursorToEnd = () => {
            const filledLen = string_1.getFilledLength(this.maskOptions, this.state.value);
            const pos = this.getRightEditablePos(filledLen);
            if (pos !== null) {
                this.setCursorPos(pos);
            }
        };
        this.setSelection = (start, len = 0) => {
            const input = this.getInputDOMNode();
            if (!input) {
                return;
            }
            const end = start + len;
            if ('selectionStart' in input && 'selectionEnd' in input) {
                input.selectionStart = start;
                input.selectionEnd = end;
            }
            else {
                const range = input.createTextRange();
                range.collapse(true);
                range.moveStart('character', start);
                range.moveEnd('character', end - start);
                range.select();
            }
        };
        this.getSelection = () => {
            const input = this.getInputDOMNode();
            let start = 0;
            let end = 0;
            if ('selectionStart' in input && 'selectionEnd' in input) {
                start = input.selectionStart;
                end = input.selectionEnd;
            }
            return {
                start,
                end,
                length: end - start,
            };
        };
        this.getCursorPos = () => {
            return this.getSelection().start;
        };
        this.setCursorPos = (pos) => {
            this.setSelection(pos, 0);
            defer_1.default(() => {
                this.setSelection(pos, 0);
            });
            this.lastCursorPos = pos;
        };
        this.isFocused = () => {
            return document.activeElement === this.getInputDOMNode();
        };
        this.getStringValue = (value) => {
            return !value && value !== 0 ? '' : value + '';
        };
        this.onKeyDown = (event) => {
            this.backspaceOrDeleteRemoval = undefined;
            if (typeof this.props.onKeyDown === 'function') {
                this.props.onKeyDown(event);
            }
            const { key, ctrlKey, metaKey, defaultPrevented } = event;
            if (ctrlKey || metaKey || defaultPrevented) {
                return;
            }
            if (key === 'Backspace' || key === 'Delete') {
                this.backspaceOrDeleteRemoval = {
                    key,
                    selection: this.getSelection(),
                };
                defer_1.default(() => {
                    this.backspaceOrDeleteRemoval = undefined;
                });
            }
        };
        this.onChange = (event) => {
            const { paste } = this;
            const { mask, maskChar, lastEditablePos, prefix } = this.maskOptions;
            let value = this.getInputValue();
            const oldValue = this.state.value === undefined ? '' : this.state.value;
            if (paste) {
                this.paste = null;
                this.pasteText(paste.value, value, paste.selection, event);
                return;
            }
            let selection = this.getSelection();
            let cursorPos = selection.end;
            const maskLen = mask.length;
            const valueLen = value.length;
            const oldValueLen = oldValue.length;
            let clearedValue;
            let enteredString;
            if (this.backspaceOrDeleteRemoval) {
                const deleteFromRight = this.backspaceOrDeleteRemoval.key === 'Delete';
                value = this.state.value;
                selection = this.backspaceOrDeleteRemoval.selection;
                cursorPos = selection.start;
                this.backspaceOrDeleteRemoval = undefined;
                if (selection.length) {
                    value = string_1.clearRange(this.maskOptions, value, selection.start, selection.length);
                }
                else if (selection.start < prefix.length || (!deleteFromRight && selection.start === prefix.length)) {
                    cursorPos = prefix.length;
                }
                else {
                    const editablePos = deleteFromRight
                        ? this.getRightEditablePos(cursorPos)
                        : this.getLeftEditablePos(cursorPos - 1);
                    if (editablePos !== null) {
                        value = string_1.clearRange(this.maskOptions, value, editablePos, 1);
                        cursorPos = editablePos;
                    }
                }
            }
            else if (valueLen > oldValueLen) {
                const enteredStringLen = valueLen - oldValueLen;
                const startPos = selection.end - enteredStringLen;
                enteredString = value.substr(startPos, enteredStringLen);
                if (startPos < lastEditablePos && (enteredStringLen !== 1 || enteredString !== mask[startPos])) {
                    cursorPos = this.getRightEditablePos(startPos);
                }
                else {
                    cursorPos = startPos;
                }
                value = value.substr(0, startPos) + value.substr(startPos + enteredStringLen);
                clearedValue = string_1.clearRange(this.maskOptions, value, startPos, maskLen - startPos);
                clearedValue = string_1.insertString(this.maskOptions, clearedValue, enteredString, cursorPos);
                value = string_1.insertString(this.maskOptions, oldValue, enteredString, cursorPos);
                if (enteredStringLen !== 1 || (cursorPos >= prefix.length && cursorPos < lastEditablePos)) {
                    cursorPos = Math.max(string_1.getFilledLength(this.maskOptions, clearedValue), cursorPos);
                    if (cursorPos < lastEditablePos) {
                        cursorPos = this.getRightEditablePos(cursorPos);
                    }
                }
                else if (cursorPos < lastEditablePos) {
                    cursorPos++;
                }
            }
            else if (valueLen < oldValueLen) {
                const removedLen = maskLen - valueLen;
                enteredString = value.substr(0, selection.end);
                const clearOnly = enteredString === oldValue.substr(0, selection.end);
                clearedValue = string_1.clearRange(this.maskOptions, oldValue, selection.end, removedLen);
                if (maskChar) {
                    value = string_1.insertString(this.maskOptions, clearedValue, enteredString, 0);
                }
                clearedValue = string_1.clearRange(this.maskOptions, clearedValue, selection.end, maskLen - selection.end);
                clearedValue = string_1.insertString(this.maskOptions, clearedValue, enteredString, 0);
                if (!clearOnly) {
                    cursorPos = Math.max(string_1.getFilledLength(this.maskOptions, clearedValue), cursorPos);
                    if (cursorPos < lastEditablePos) {
                        cursorPos = this.getRightEditablePos(cursorPos);
                    }
                }
                else if (cursorPos < prefix.length) {
                    cursorPos = prefix.length;
                }
            }
            value = string_1.formatValue(this.maskOptions, value);
            this.setInputValue(value);
            if (typeof this.props.onChange === 'function') {
                this.props.onChange(event);
            }
            if (this.isWindowsPhoneBrowser) {
                defer_1.default(() => {
                    this.setSelection(cursorPos, 0);
                });
            }
            else {
                this.setCursorPos(cursorPos);
            }
        };
        this.onFocus = (event) => {
            if (!this.state.value) {
                const prefix = this.maskOptions.prefix;
                const value = string_1.formatValue(this.maskOptions, prefix);
                const inputValue = string_1.formatValue(this.maskOptions, value);
                const isInputValueChanged = inputValue !== event.target.value;
                if (isInputValueChanged) {
                    event.target.value = inputValue;
                }
                this.setState({ ['value']: inputValue });
                if (isInputValueChanged && typeof this.props.onChange === 'function') {
                    this.props.onChange(event.target.value);
                }
                this.setCursorToEnd();
            }
            else if (string_1.getFilledLength(this.maskOptions, this.state.value) < this.maskOptions.mask.length) {
                this.setCursorToEnd();
            }
            if (typeof this.props.onFocus === 'function') {
                this.props.onFocus(event);
            }
        };
        this.onBlur = (event) => {
            if (!this.props.alwaysShowMask && string_1.isEmpty(this.maskOptions, this.state.value)) {
                const inputValue = '';
                const isInputValueChanged = inputValue !== this.getInputValue();
                if (isInputValueChanged) {
                    this.setInputValue(inputValue);
                }
                if (isInputValueChanged && typeof this.props.onChange === 'function') {
                    this.props.onChange(event);
                }
            }
            if (typeof this.props.onBlur === 'function') {
                this.props.onBlur(event);
            }
        };
        this.onPaste = (event) => {
            if (typeof this.props.onPaste === 'function') {
                this.props.onPaste(event);
            }
            if (this.isAndroidBrowser && !event.defaultPrevented) {
                this.paste = {
                    value: this.getInputValue(),
                    selection: this.getSelection(),
                };
                this.setInputValue('');
            }
        };
        this.pasteText = (incValue, text, selection, event) => {
            let cursorPos = selection.start;
            let value = incValue;
            if (selection.length) {
                value = string_1.clearRange(this.maskOptions, value, cursorPos, selection.length);
            }
            const textLen = string_1.getInsertStringLength(this.maskOptions, value, text, cursorPos);
            value = string_1.insertString(this.maskOptions, value, text, cursorPos);
            cursorPos += textLen;
            cursorPos = this.getRightEditablePos(cursorPos) || cursorPos;
            if (value !== this.getInputValue()) {
                this.setInputValue(value);
                if (event && typeof this.props.onChange === 'function') {
                    this.props.onChange(event);
                }
            }
            this.setCursorPos(cursorPos);
        };
        const { mask, maskChar, formatChars, alwaysShowMask } = props;
        let { defaultValue, value } = props;
        this.hasValue = value != null;
        this.maskOptions = parseMask_1.default(mask, maskChar, formatChars);
        if (defaultValue == null) {
            defaultValue = '';
        }
        if (value == null) {
            value = defaultValue;
        }
        value = this.getStringValue(value);
        if (this.maskOptions.mask && (alwaysShowMask || value)) {
            value = string_1.formatValue(this.maskOptions, value);
        }
        this.state = {
            value,
        };
    }
    componentDidMount() {
        this.isAndroidBrowser = environment_1.isAndroidBrowser();
        this.isWindowsPhoneBrowser = environment_1.isWindowsPhoneBrowser();
        this.isAndroidFirefox = environment_1.isAndroidFirefox();
        if (this.getInputValue() !== this.state.value) {
            this.setInputValue(this.state.value);
        }
    }
    componentWillReceiveProps(nextProps) {
        const oldMaskOptions = this.maskOptions;
        this.hasValue = nextProps.value != null;
        this.maskOptions = parseMask_1.default(nextProps.mask, nextProps.maskChar, nextProps.formatChars);
        if (!this.maskOptions.mask) {
            this.lastCursorPos = 0;
            return;
        }
        const isMaskChanged = this.maskOptions.mask && this.maskOptions.mask !== oldMaskOptions.mask;
        const showEmpty = nextProps.alwaysShowMask || this.isFocused();
        let newValue = this.hasValue
            ? this.getStringValue(nextProps.value)
            : this.state.value;
        if (!oldMaskOptions.mask && !this.hasValue) {
            newValue = this.getInputDOMNode().value;
        }
        if (isMaskChanged || (this.maskOptions.mask && (newValue || showEmpty))) {
            newValue = string_1.formatValue(this.maskOptions, newValue);
            if (isMaskChanged) {
                let pos = this.lastCursorPos;
                const filledLen = string_1.getFilledLength(this.maskOptions, newValue);
                if (pos === null || filledLen < pos) {
                    if (string_1.isFilled(this.maskOptions, newValue)) {
                        pos = filledLen;
                    }
                    else {
                        pos = this.getRightEditablePos(filledLen);
                    }
                    this.setCursorPos(pos);
                }
            }
        }
        if (this.maskOptions.mask && string_1.isEmpty(this.maskOptions, newValue) && !showEmpty && (!this.hasValue || !nextProps.value)) {
            newValue = '';
        }
        this.setState({ ['value']: newValue });
    }
    componentDidUpdate() {
        if (this.getInputValue() !== this.state.value) {
            this.setInputValue(this.state.value);
        }
    }
    render() {
        const _a = this.props, { mask, alwaysShowMask, maskChar, formatChars } = _a, props = tslib_1.__rest(_a, ["mask", "alwaysShowMask", "maskChar", "formatChars"]);
        let copyProps;
        if (this.maskOptions.mask) {
            if (!props.disabled && !props.readOnly) {
                const handlersKeys = ['onFocus', 'onBlur', 'onChange', 'onKeyDown', 'onPaste'];
                copyProps = handlersKeys.reduce((currObj, key) => {
                    return Object.assign({}, currObj, { [key]: this[key] });
                }, Object.assign({}, props));
            }
        }
        const passProps = copyProps ? copyProps : props;
        return React.createElement(TextField_1.default, Object.assign({ value: this.state.value, ref: ref => this.input = ref }, passProps));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.MASK_TEXT_FIELD, baseTheme)(MaskTextField);
