"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function isPermanentChar(maskOptions, pos) {
    return maskOptions.permanents.indexOf(pos) !== -1;
}
exports.isPermanentChar = isPermanentChar;
function isAllowedChar(maskOptions, pos, character) {
    const { mask, charsRules } = maskOptions;
    if (!character) {
        return false;
    }
    if (isPermanentChar(maskOptions, pos)) {
        return mask[pos] === character;
    }
    const ruleChar = mask[pos];
    const charRule = charsRules[ruleChar];
    return (new RegExp(charRule)).test(character);
}
exports.isAllowedChar = isAllowedChar;
function isEmpty(maskOptions, value) {
    return value
        .split('')
        .every((character, i) => {
        return isPermanentChar(maskOptions, i) || !isAllowedChar(maskOptions, i, character);
    });
}
exports.isEmpty = isEmpty;
function getFilledLength(maskOptions, paramValue) {
    let value = paramValue;
    const { maskChar, prefix } = maskOptions;
    if (!maskChar) {
        while (value.length > prefix.length && isPermanentChar(maskOptions, value.length - 1)) {
            value = value.slice(0, value.length - 1);
        }
        return value.length;
    }
    let filledLength = prefix.length;
    for (let i = value.length; i >= prefix.length; i--) {
        const character = value[i];
        const isEnteredCharacter = !isPermanentChar(maskOptions, i) && isAllowedChar(maskOptions, i, character);
        if (isEnteredCharacter) {
            filledLength = i + 1;
            break;
        }
    }
    return filledLength;
}
exports.getFilledLength = getFilledLength;
function isFilled(maskOptions, value) {
    return getFilledLength(maskOptions, value) === maskOptions.mask.length;
}
exports.isFilled = isFilled;
function formatValue(maskOptions, paramValue) {
    const { maskChar, mask, prefix } = maskOptions;
    let value = paramValue;
    if (!maskChar) {
        value = insertString(maskOptions, '', value, 0);
        value = value.slice(0, getFilledLength(maskOptions, value));
        if (value.length < prefix.length) {
            value = prefix;
        }
        return value;
    }
    if (value) {
        const emptyValue = formatValue(maskOptions, '');
        return insertString(maskOptions, emptyValue, value, 0);
    }
    for (let i = 0; i < mask.length; i++) {
        if (isPermanentChar(maskOptions, i)) {
            value += mask[i];
        }
        else {
            value += maskChar;
        }
    }
    return value;
}
exports.formatValue = formatValue;
function clearRange(maskOptions, paramValue, paramStart, len) {
    let value = paramValue;
    let start = paramStart;
    const end = start + len;
    const { maskChar, mask, prefix } = maskOptions;
    const arrayValue = value.split('');
    if (!maskChar) {
        start = Math.max(prefix.length, start);
        arrayValue.splice(start, end - start);
        value = arrayValue.join('');
        return formatValue(maskOptions, value);
    }
    return arrayValue
        .map((character, i) => {
        if (i < start || i >= end) {
            return character;
        }
        if (isPermanentChar(maskOptions, i)) {
            return mask[i];
        }
        return maskChar;
    })
        .join('');
}
exports.clearRange = clearRange;
function insertString(maskOptions, paramValue, insertStr, paramInsertPos) {
    let value = paramValue;
    let insertPos = paramInsertPos;
    const { mask, maskChar, prefix } = maskOptions;
    const arrayInsertStr = insertStr.split('');
    const isInputFilled = isFilled(maskOptions, value);
    const isUsablePosition = (pos, character) => {
        return !isPermanentChar(maskOptions, pos) || character === mask[pos];
    };
    const isUsableCharacter = (character, pos) => {
        return !maskChar || !isPermanentChar(maskOptions, pos) || character !== maskChar;
    };
    if (!maskChar && insertPos > value.length) {
        value += mask.slice(value.length, insertPos);
    }
    arrayInsertStr.every((insertCharacter) => {
        while (!isUsablePosition(insertPos, insertCharacter)) {
            if (insertPos >= value.length) {
                value += mask[insertPos];
            }
            if (!isUsableCharacter(insertCharacter, insertPos)) {
                return true;
            }
            insertPos++;
            if (insertPos >= mask.length) {
                return false;
            }
        }
        const isAllowed = isAllowedChar(maskOptions, insertPos, insertCharacter) || insertCharacter === maskChar;
        if (!isAllowed) {
            return true;
        }
        if (insertPos < value.length) {
            if (maskChar || isInputFilled || insertPos < prefix.length) {
                value = value.slice(0, insertPos) + insertCharacter + value.slice(insertPos + 1);
            }
            else {
                value = value.slice(0, insertPos) + insertCharacter + value.slice(insertPos);
                value = formatValue(maskOptions, value);
            }
        }
        else if (!maskChar) {
            value += insertCharacter;
        }
        insertPos++;
        return insertPos < mask.length;
    });
    return value;
}
exports.insertString = insertString;
function getInsertStringLength(maskOptions, value, insertStr, paramInsertPos) {
    let insertPos = paramInsertPos;
    const { mask, maskChar } = maskOptions;
    const arrayInsertStr = insertStr.split('');
    const initialInsertPos = insertPos;
    const isUsablePosition = (pos, character) => {
        return !isPermanentChar(maskOptions, pos) || character === mask[pos];
    };
    arrayInsertStr.every((insertCharacter) => {
        while (!isUsablePosition(insertPos, insertCharacter)) {
            insertPos++;
            if (insertPos >= mask.length) {
                return false;
            }
        }
        const isAllowed = isAllowedChar(maskOptions, insertPos, insertCharacter) || insertCharacter === maskChar;
        if (isAllowed) {
            insertPos++;
        }
        return insertPos < mask.length;
    });
    return insertPos - initialInsertPos;
}
exports.getInsertStringLength = getInsertStringLength;
