"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Message_1 = require("../Message");
describe('<Message />', () => {
    const theme = {
        messageBlock: 'messageBlock',
        messagePrompt: 'messagePrompt',
        after: 'after',
    };
    describe('when default props are provided', () => {
        it('basic message should have rendered 1 noscript element', () => {
            const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }));
            expect(messageWrapper.find('noscript')).toHaveLength(1);
        });
    });
    describe('id property', () => {
        describe('when set', () => {
            it('basic message should have rendered 1 noscript element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }));
                expect(messageWrapper.find('noscript')).toHaveLength(1);
            });
            it('should verify id when set', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }));
                expect(messageWrapper.prop('id')).toBe('10101');
            });
        });
    });
    describe('children property', () => {
        describe('when not set', () => {
            it('basic message should have rendered 1 noscript element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }));
                expect(messageWrapper.find('noscript')).toHaveLength(1);
            });
            it('should verify children when is not set/defined', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }));
                expect(messageWrapper.prop('children')).toBeUndefined();
                expect(messageWrapper.find('children')).toHaveLength(0);
            });
        });
        describe('when set', () => {
            it('basic message should have rendered 1 noscript element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }, "Click Here"));
                expect(messageWrapper.find('noscript')).toHaveLength(1);
                expect(messageWrapper.prop('children')).toBe('Click Here');
            });
            it('should verify children when is set', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }, "Click Here"));
                expect(messageWrapper.prop('children')).toBe('Click Here');
            });
        });
    });
    describe('isVisible property', () => {
        describe('when not set', () => {
            it('basic message should have rendered 1 noscript element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", theme: theme }, "Click Here"));
                expect(messageWrapper.find('noscript')).toHaveLength(1);
            });
        });
        describe('when set to true', () => {
            it('basic message should have rendered 1 div element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.find('div')).toHaveLength(1);
            });
            it('basic message should have rendered 1 span element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.find('span')).toHaveLength(1);
            });
            it('basic message should have messageBlock css class on div', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.find('div').hasClass('messageBlock')).toBe(true);
            });
            it('basic message should have messagePrompt css class on span', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.find('span').hasClass('messagePrompt')).toBe(true);
            });
            it('should verify isVisible set as true', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.prop('isVisible')).toBe(true);
            });
            it('should verify children when isVisible set as true', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
                expect(messageWrapper.prop('children')).toBe('Click Here');
            });
        });
        describe('when set to false', () => {
            it('basic message should have rendered 1 noscript element', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: false, theme: theme }, "Click Here"));
                expect(messageWrapper.find('noscript')).toHaveLength(1);
            });
            it('should verify isVisible set as false', () => {
                const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: false, theme: theme }, "Click Here"));
                expect(messageWrapper.prop('isVisible')).toBe(false);
            });
        });
    });
    describe('verify all property together', () => {
        it('basic message should have rendered 1 div and 1 span element', () => {
            const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
            expect(messageWrapper.find('div')).toHaveLength(1);
            expect(messageWrapper.find('span')).toHaveLength(1);
        });
        it('basic message should have messageBlock css class on div', () => {
            const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
            expect(messageWrapper.find('div').hasClass('messageBlock')).toBe(true);
        });
        it('basic message should have messagePrompt css class on span', () => {
            const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
            expect(messageWrapper.find('span').hasClass('messagePrompt')).toBe(true);
        });
        it('should verify all properties are set', () => {
            const messageWrapper = enzyme_1.mount(React.createElement(Message_1.default, { id: "10101", isVisible: true, theme: theme }, "Click Here"));
            expect(messageWrapper.prop('id')).toBe('10101');
            expect(messageWrapper.prop('isVisible')).toBe(true);
            expect(messageWrapper.prop('children')).toBe('Click Here');
        });
    });
});
