"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const types_1 = require("../../types");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const KeypressListener_1 = require("../KeypressListener");
const helpers_1 = require("./helpers");
const Dialog_1 = require("./Dialog");
const baseTheme = require("./Modal.scss");
const velocity = require("velocity-animate");
const bodyStyle = (pading, overflow) => {
    const body = document.getElementsByTagName('body');
    body[0].style.paddingRight = pading;
    body[0].style.overflow = overflow;
};
const getModalElement = (id) => {
    return {
        modal: helpers_1.default.getElement(`modal-${id}`),
        dialog: helpers_1.default.getElement(`dialog-${id}`),
    };
};
class Modal extends React.Component {
    constructor(props) {
        super(props);
        this.animate = {
            in: (modal, dialog) => this.animateIn(modal, dialog),
            out: (modal, dialog) => this.animateOut(modal, dialog),
        };
        this.trigger = {
            body: 'Open',
            animate: this.animate,
        };
        this.handleCloseClick = (event) => {
            event.preventDefault();
            const props = this.props;
            const { modal, dialog } = getModalElement(props.id);
            this.trigger.animate.out(modal, dialog);
            setTimeout(() => bodyStyle('', ''), 200);
        };
        this.handleToggleClick = (e) => {
            const props = this.props;
            const { modal, dialog } = getModalElement(props.id);
            if (!this.state.show) {
                bodyStyle('16px', 'hidden');
                this.trigger.animate.in(modal, dialog);
            }
            else {
                const target = e.target;
                const id = (target ? target.dataset.id : undefined);
                if (typeof id !== 'undefined') {
                    const prefix = id.substr(0, id.indexOf('-'));
                    if (prefix === 'modal' && this.props.closeOnBackgroud) {
                        this.handleCloseClick(e);
                    }
                }
            }
        };
        this.state = {
            show: false,
        };
    }
    animateIn(modal, dialog) {
        this.setState({ show: true });
        velocity(modal, { opacity: 1 }, { display: 'block' }, 300);
        velocity(dialog, { translateY: 1, opacity: 1 }, { display: 'block' }, 200);
    }
    animateOut(modal, dialog) {
        this.setState({ show: false });
        velocity(modal, { opacity: 0 }, { display: 'none' }, 300);
        velocity(dialog, { translateY: -100, opacity: 0 }, { display: 'none' }, 200);
    }
    render() {
        const props = this.props;
        const cssClassNames = helpers_1.default.cleanClasses([
            props.theme.overflow,
            props.backdropEnabled ? props.theme.modal : null,
            props.className,
        ]);
        const ignoreProps = [
            'blank',
            'className',
            'close',
            'footer',
            'header',
            'activator',
            'id',
            'show',
            'trigger',
            'closeOnBackgroud',
            'modalOverflow',
            'backdropEnabled',
            'closeOnEsc',
            'size',
            'theme',
        ];
        const closeonEscProp = this.props.closeOnEsc ? (React.createElement(KeypressListener_1.default, { keyCode: types_1.Keys.ESCAPE, handler: this.handleCloseClick })) : null;
        const cleanProps = helpers_1.default.cleanProps(ignoreProps)(Object.assign({}, props, { ok: null, show: null, trigger: null, close: null, closeOnBackgroud: null, modalOverflow: null, closeOnEsc: null, backdropEnabled: null, header: null }));
        return (React.createElement("div", null,
            React.createElement("span", { onClick: this.handleToggleClick }, this.props.activator),
            closeonEscProp,
            React.createElement("div", Object.assign({}, cleanProps, { className: cssClassNames, "data-id": `modal-${props.id}`, onClick: (this.props.close || this.props.closeOnBackgroud || this.props.closeOnEsc) ? this.handleToggleClick : null }),
                React.createElement(Dialog_1.default, { footer: props.footer, header: props.header, id: props.id, onClose: this.handleCloseClick, closeOnBackgroud: props.closeOnBackgroud ? this.handleToggleClick : undefined, close: props.close, modalOverflow: props.modalOverflow, backdropEnabled: props.backdropEnabled, size: props.size },
                    React.createElement("div", { className: props.modalOverflow ? props.theme.autoHeight : null },
                        "  ",
                        props.children)))));
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.MODAL, baseTheme)((Modal));
