"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Modal_1 = require("../Modal");
const Button_1 = require("../../Button");
const Heading_1 = require("../../Heading");
describe('<Modal />', () => {
    const footerNode = React.createElement(Button_1.default, null, " Save ");
    const headerNode = React.createElement(Heading_1.default, null, "This is a Modal Header!!");
    const childBody = React.createElement("span", null,
        React.createElement("h1", null, "Hello, world"),
        " ",
        React.createElement("p", null, " test L"));
    const activatorNode = React.createElement(Button_1.default, null, "Modal");
    describe('when default props are provided', () => {
        it('basic Modal should have rendered 5 div elements with default props', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('Close Prop', () => {
        it('When not set', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to false', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, close: false, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('close')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to true', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, close: true, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('close')).toBe(true);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(7);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('closeOnBackgroud Prop', () => {
        it('When not set', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to false', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, closeOnBackgroud: false, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('closeOnBackgroud')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to true', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, closeOnBackgroud: true, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('closeOnBackgroud')).toBe(true);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('closeOnEsc Prop', () => {
        it('When not set', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to false', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, closeOnEsc: false, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('closeOnEsc')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to true', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, closeOnEsc: true, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('closeOnEsc')).toBe(true);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('modalOverflow Prop', () => {
        it('When not set', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to false', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, modalOverflow: false, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('modalOverflow')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to true', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, modalOverflow: true, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('modalOverflow')).toBe(true);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('backdropEnabled Prop', () => {
        it('When not set', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to false', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, backdropEnabled: false, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('backdropEnabled')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When set to true', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, backdropEnabled: true, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('backdropEnabled')).toBe(true);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('Size Prop', () => {
        it('When Size type is string with undefined', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When Size type is string with Small', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, size: "Small", show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('size')).toBe('Small');
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
        });
        it('When Size type is string with Medium', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, size: "Medium", show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('size')).toBe('Medium');
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
        });
        it('When Size type is string with Large', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, size: "Large", show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('size')).toBe('Large');
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
        });
        it('When Size type is Number', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, size: 500, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('size')).toBe(500);
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('header Prop', () => {
        it('When header type is string with undefined', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, header: "", show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('header')).toBe('');
            expect(subject.find('div')).toHaveLength(4);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When header type is string with any value', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, header: "This is my header!!", show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('header')).toBe('This is my header!!');
            expect(subject.find('div')).toHaveLength(5);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
        it('When header type is any React Node', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, header: headerNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('header')).toMatchObject(headerNode);
            expect(subject.find('div')).toHaveLength(5);
            expect(subject.find('span')).toHaveLength(4);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
    describe('footer Prop', () => {
        it('When footer type is React Node', () => {
            const subject = enzyme_1.mount(React.createElement(Modal_1.default, { activator: activatorNode, footer: footerNode, show: false }, childBody));
            expect(subject.prop('show')).toBe(false);
            expect(subject.prop('footer')).toMatchObject(footerNode);
            expect(subject.find('div')).toHaveLength(5);
            expect(subject.find('span')).toHaveLength(6);
            expect(subject.find('button').exists()).toBe(true);
        });
    });
});
