"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const components_1 = require("@shopify/react-utilities/components");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const styles_1 = require("@shopify/react-utilities/styles");
const other_1 = require("@shopify/javascript-utilities/other");
const focus_1 = require("@shopify/javascript-utilities/focus");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const OffCanvasContent_1 = require("./OffCanvasContent");
const baseTheme = require("./OffCanvas.scss");
const getUniqueID = other_1.createUniqueIDFactory('OffCanvasContent');
let OffCanvas = class OffCanvas extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            active: false,
        };
        this.id = getUniqueID();
        this.handleClick = () => {
            this.setState({ active: !this.state.active });
        };
    }
    componentDidMount() {
        this.setAccessibilityAttributes();
    }
    componentDidUpdate() {
        this.setAccessibilityAttributes();
    }
    renderLayer() {
        const { id, activatorNode } = this;
        if (activatorNode == null) {
            return null;
        }
        const { active, children, flip, mode, overlay, width = 'medium', theme, } = this.props;
        const containerClassName = styles_1.classNames(theme.offcanvas, overlay && theme.overlay, flip && theme.flip, width === 'small' && theme.small, width === 'medium' && theme.medium, width === 'large' && theme.large, this.state.active && theme.open);
        const barClassName = styles_1.classNames(theme.bar, mode === 'slide' && theme.animation, mode === 'push' && theme.animation);
        const bodyElement = document.body;
        const rootElement = document.getElementById('root');
        if (bodyElement !== null) {
            bodyElement.className = this.state.active ? (theme.container) : '';
            bodyElement.className += overlay && this.state.active ? ' ' + (theme.overlay) : '';
            bodyElement.className += flip && this.state.active ? ' ' + (theme.flip) : '';
            if (width === 'small') {
                bodyElement.className += this.state.active ? ' ' + (theme.small) : '';
            }
            if (width === 'medium') {
                bodyElement.className += this.state.active ? ' ' + (theme.medium) : '';
            }
            if (width === 'large') {
                bodyElement.className += this.state.active ? ' ' + (theme.large) : '';
            }
            if (mode === 'push' || mode === 'reveal') {
                bodyElement.className += this.state.active ? ' ' + (theme.animation) : '';
                if (rootElement !== null) {
                    if (flip) {
                        rootElement.style.left = width && this.state.active ? `-${width}` : '';
                    }
                    else {
                        rootElement.style.left = width && this.state.active ? `${width}` : '';
                    }
                }
            }
        }
        const bar = [
            React.createElement("div", { className: barClassName, style: width ? { width: `${width}` } : undefined, key: id },
                React.createElement(OffCanvasContent_1.default, { id: id, activator: activatorNode, active: active || this.state.active, onClose: other_1.noop, onCancel: this.handleClick, closeButton: this.props.closeButton },
                    React.createElement("div", { className: theme.label, "aria-live": 'assertive' }, children))),
        ];
        return (React.createElement("div", { className: containerClassName }, mode === 'reveal'
            ?
                React.createElement("div", { className: theme.reveal, style: width && this.state.active ? { width: `${width}` } : undefined }, bar)
            :
                bar));
    }
    render() {
        const { activatorWrapper: WRAPPERCOMPONENT = 'span' } = this.props;
        return (React.createElement(WRAPPERCOMPONENT, { onClick: this.handleClick, ref: this.setActivator }, this.props.activator));
    }
    setActivator(node) {
        if (node == null) {
            this.activatorNode = null;
            this.activatorContainer = null;
            return;
        }
        this.activatorNode = node.firstElementChild;
        this.activatorContainer = node;
    }
    setAccessibilityAttributes() {
        const { activatorContainer, id } = this;
        if (activatorContainer == null) {
            return;
        }
        const firstFocusable = focus_1.findFirstFocusableNode(activatorContainer);
        const accessibilityNode = firstFocusable || activatorContainer;
        accessibilityNode.tabIndex = 0;
        accessibilityNode.setAttribute('aria-describedby', id);
        accessibilityNode.setAttribute('aria-expanded', this.state.active.toString());
        accessibilityNode.setAttribute('aria-label', this.props.accessibilityLabel ? this.props.accessibilityLabel : '');
    }
};
tslib_1.__decorate([
    autobind_1.default
], OffCanvas.prototype, "setActivator", null);
OffCanvas = tslib_1.__decorate([
    components_1.layeredComponent({ idPrefix: 'OffCanvas' })
], OffCanvas);
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.OFFCANVAS, baseTheme)(OffCanvas);
