"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Button_1 = require("../../Button");
const OffCanvas_1 = require("../../OffCanvas");
describe('<OffCanvas />', () => {
    const children = React.createElement("div", null,
        React.createElement("p", null, "Test"),
        React.createElement("ul", null,
            React.createElement("li", null, "Link 1"),
            React.createElement("li", null, "Link 2"),
            React.createElement("li", null, "Link 3")));
    const activatorNode = React.createElement(Button_1.default, null, " OffCanvas ");
    describe('when default props are provided', () => {
        it('default OffCanvas with default props', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBeUndefined;
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
    });
    describe('Mode', () => {
        it('when set to slide', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to reveal', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "reveal", activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBe('reveal');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
    });
    describe('Active', () => {
        it('when not set', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.prop('active')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to true', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, active: true }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.prop('active')).toBe(true);
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to false', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, active: false }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.prop('active')).toBe(false);
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
    });
    describe('Flip', () => {
        it('when not set', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to true', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, flip: true }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBe(true);
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to false', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, flip: false }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBe(false);
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
    });
    describe('Overlay', () => {
        it('when not set', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBeUndefined;
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to true', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, overlay: true }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBe(true);
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
        it('when set to false', () => {
            const canvasMenu = enzyme_1.mount(React.createElement(OffCanvas_1.default, { mode: "slide", activator: activatorNode, overlay: false }, children));
            expect(canvasMenu.prop('mode')).toBe('slide');
            expect(canvasMenu.prop('overlay')).toBe(false);
            expect(canvasMenu.prop('flip')).toBeUndefined;
            expect(canvasMenu.find('button').exists()).toBe(true);
        });
    });
});
