"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const TextField_1 = require("./TextField");
const PickerEnum_1 = require("./PickerEnum");
const baseTheme = require("./Picker.scss");
const Card_1 = require("./Card");
class Picker extends React.Component {
    constructor(props) {
        super(props);
        this.handleChange = (value) => {
            this.setState({ ['people']: value });
            this.setState({ ['searchItems']: value ? this.props.source.filter(x => x.name.startsWith(value)) : [] });
        };
        this.handleRemove = (event) => {
            const item = this.state.selectedItems.find(x => x.name === event.currentTarget.previousElementSibling.innerText);
            const items = this.state.selectedItems;
            if (this.props.minSelectedItems !== undefined && this.props.minSelectedItems === items.length) {
                return;
            }
            if (item !== undefined) {
                const index = items.indexOf(item);
                if (index !== -1) {
                    items.splice(index, 1);
                }
            }
            this.setState({ ['selectedItems']: items });
            return;
        };
        this.handleSelect = (event) => {
            const item = this.state.searchItems.find(x => x.name === event.currentTarget.text);
            const items = this.state.selectedItems;
            if (this.props.maxSelectedItems !== undefined && this.props.maxSelectedItems === items.length) {
                return;
            }
            if (item !== undefined) {
                if (!items.some(x => x.name === item.name)) {
                    items.push(item);
                }
            }
            this.setState({ ['selectedItems']: items });
            this.setState({ ['searchItems']: [] });
            return;
        };
        this.handleMoreInfo = () => {
            this.setState({ ['moreInfo']: !this.state.moreInfo });
            return;
        };
        this.state = {
            people: '',
            searchItems: [],
            selectedItems: [],
            moreInfo: false,
            value: '',
            input: [],
            suggestions: [],
            chipListState: [],
            focusArr: [],
            itemsList: this.props.source,
            focused: 0,
            number: 0,
        };
    }
    render() {
        function escapeRegexCharacters(str) {
            return str.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
        }
        const autoSuggestMethods = {
            onSuggestionsClearRequested: () => this.setState({ suggestions: [] }),
            getSuggestions: (value) => {
                const escapedValue = escapeRegexCharacters(value.trim());
                if (escapedValue === '') {
                    return [];
                }
                const regex = new RegExp(escapedValue, 'i');
                return this.state.itemsList.filter((language) => regex.test(language.name ? language.name : ''));
            },
            getSuggestionValue: (suggestion) => {
                return suggestion.name;
            },
            onChange: (event, { newValue, method }) => {
                this.setState({
                    value: newValue,
                });
            },
            onKeyDown: (e, focusArr, chipListState) => {
                if ((e.keyCode === 8) && this.state.chipListState.length && !this.state.value.length) {
                    const chipListState = this.state.chipListState.slice(0, this.state.chipListState.length - 1);
                    const selectedChip = this.state.chipListState.slice(this.state.chipListState.length - 1)[0];
                    const itemsList = this.state.itemsList.concat(selectedChip);
                    this.setState({
                        chipListState,
                        itemsList,
                    });
                }
            },
            onSuggestionsFetchRequested: ({ value }) => {
                if (value) {
                    this.setState({
                        suggestions: autoSuggestMethods.getSuggestions(value),
                    });
                }
            },
            updateList: (input) => {
                const langIndex = this.state.itemsList.indexOf(input);
                const itemsListLength = this.state.itemsList;
                const newLangState = itemsListLength.slice(0, langIndex).concat(itemsListLength.slice(langIndex + 1, itemsListLength.length));
                this.setState({
                    itemsList: newLangState,
                });
            },
            onSuggestionSelected: (event, { suggestion }) => {
                suggestion.text = suggestion.name;
                autoSuggestMethods.updateList(suggestion);
                const chipListState = this.state.chipListState.concat(suggestion);
                const item = Object.assign({}, chipListState[0], { tabIndex: 0 });
                chipListState[0] = item;
                this.setState({
                    chipListState,
                    value: '',
                });
            },
            chipRemove: (item) => {
                const number = typeof item === 'number' ? item : this.state.chipListState.indexOf(item);
                const existingChipList = this.state.chipListState;
                const addedItem = this.state.chipListState.slice(number, number + 1);
                const addedItemObj = Object.assign({}, addedItem[0], { tabIndex: -1 });
                const chipListState = existingChipList.slice(0, number).concat(existingChipList.slice(number + 1));
                const itemsList = this.state.itemsList.concat([addedItemObj]);
                const focusArr = this.state.focusArr.slice(0, number).concat(this.state.focusArr.slice(number + 1));
                if (chipListState.length)
                    chipListState[0].tabIndex = 0;
                let focused;
                if (number === chipListState.length)
                    focused = number - 1;
                else if (number === chipListState.length && number > 0)
                    focused = number;
                else
                    focused = 0;
                this.setState({
                    itemsList,
                    chipListState,
                    focusArr,
                    number,
                });
            },
            storeInputReference: (autosuggest) => {
                if (autosuggest !== null) {
                    if (this.state.input !== autosuggest.props.inputProps.value) {
                        this.setState({ input: autosuggest.props.inputProps.value });
                    }
                }
            },
            storeFocus: (e) => {
                if (!this.state.focusArr.includes(e) && e !== null) {
                    const focusArr = this.state.focusArr.length ? this.state.focusArr.concat([e]) : [e];
                    this.setState({ focusArr });
                }
            },
            renderSuggestion: (suggestion, { isHighlighted, query }) => {
                const index = (suggestion.name ? suggestion.name.toLowerCase().indexOf(query.toLowerCase()) : 0);
                const nameBefore = (suggestion.name ? suggestion.name.slice(0, index) : '');
                const queryData = (suggestion.name ? suggestion.name.slice(index, index + query.length) : '');
                const nameAfter = (suggestion.name ? suggestion.name.slice(index + query.length) : '');
                if (isHighlighted)
                    return React.createElement(Card_1.default, { isHighlighted: true, image: suggestion.image, nameBefore: nameBefore, bold: queryData, nameAfter: nameAfter, email: suggestion.email, alt: suggestion.alt });
                else
                    return (React.createElement(Card_1.default, { image: suggestion.image, nameBefore: nameBefore, bold: queryData, nameAfter: nameAfter, email: suggestion.email, alt: suggestion.alt }));
            },
        };
        const { value, suggestions, chipListState } = this.state;
        const inputProps = {
            value,
            onChange: autoSuggestMethods.onChange,
            onKeyDown: autoSuggestMethods.onKeyDown,
        };
        const stateProps = { value, suggestions, chipListState, inputProps };
        const { autoSuggest, filterPlaceHolder, selectedResultsBehavior, moreInfoComponent, chipComponent, searchResultComponent, searchBehavior = this.handleChange, moreInfoComponentShowOn = PickerEnum_1.DisplayMoreInfo.onClick, onSelect = this.handleSelect, onRemove = this.handleRemove, onMoreInfo = this.handleMoreInfo, theme, } = this.props;
        let className = '';
        if (selectedResultsBehavior === 'hide') {
            className = theme.pickerResultHide;
        }
        else {
            className = theme.pickerResultShow;
        }
        return (React.createElement("div", null,
            React.createElement("div", null,
                React.createElement("div", { className: className }, this.state.selectedItems.map((i) => {
                    return React.createElement(chipComponent, { onRemove, key: i.id, clickable: false, removable: true }, [i.name]);
                })),
                React.createElement(TextField_1.default, { autoSuggest: autoSuggest, autoSuggestMethods: autoSuggestMethods, label: "People", value: this.state.people, placeholder: filterPlaceHolder, onChange: searchBehavior, stateProps: stateProps })),
            React.createElement("div", null, this.state.searchItems.map((i) => {
                return React.createElement(searchResultComponent, { moreInfoComponent, moreInfoComponentShowOn, key: i.id, clickable: true, onClick: onSelect, handleMoreInfo: onMoreInfo }, [i.name]);
            }))));
    }
}
exports.UnthemedPicker = Picker;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.PICKER, baseTheme)(Picker);
