"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const styles_1 = require("@shopify/react-utilities/styles");
const AutoSuggestText_1 = require("./AutoSuggestText");
const Labelled_1 = require("../Labelled");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./TextField.scss");
class TextField extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = { height: null };
    }
    render() {
        const { value = '', placeholder, label, required, theme, autoSuggest, autoSuggestMethods, } = this.props;
        const backdrop = autoSuggest ? theme.backdropAutosuggest : theme.backdrop;
        const className = styles_1.classNames(theme.textField, Boolean(value) && theme.hasValue, theme.disabled, theme.readOnly, theme.error, theme.multiline, backdrop);
        const input = React.createElement('input', {
            name,
            value,
            placeholder,
            required,
            formNoValidate: true,
            className: theme.input,
            onChange: this.handleChange,
            ref: this.setInput,
            'aria-required': required ? true : false,
        });
        const inputValue = autoSuggest ?
            React.createElement(AutoSuggestText_1.default, { placeholder: placeholder, autoSuggestMethods: autoSuggestMethods, stateProps: this.props.stateProps })
            : input;
        const hasValue = (!!this.props.value && this.props.value.length > 0);
        return (React.createElement(Labelled_1.default, { label: label, id: 'textfield!!!' + label, action: undefined, focused: this.state.focused, hasValue: hasValue, required: required },
            React.createElement("div", { className: className }, inputValue)));
    }
    setInput(input) {
        this.input = input;
    }
    handleChange(event) {
        const { onChange } = this.props;
        if (onChange == null) {
            return;
        }
        onChange(event.currentTarget.value);
    }
}
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "setInput", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleChange", null);
exports.UnthemedTextField = TextField;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.TEXT_FIELD, baseTheme)(TextField);
