"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const components_1 = require("@shopify/react-utilities/components");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const other_1 = require("@shopify/javascript-utilities/other");
const focus_1 = require("@shopify/javascript-utilities/focus");
const PopoverOverlay_1 = require("./PopoverOverlay");
const getUniqueID = other_1.createUniqueIDFactory('Popover');
let Popover = class Popover extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            activatorFocused: false,
        };
        this.id = getUniqueID();
    }
    componentDidMount() {
        this.setAccessibilityAttributes();
    }
    componentDidUpdate() {
        this.setAccessibilityAttributes();
    }
    renderLayer() {
        const _a = this.props, { children, onClose, activator, activatorWrapper } = _a, rest = tslib_1.__rest(_a, ["children", "onClose", "activator", "activatorWrapper"]);
        if (this.activatorNode == null) {
            return null;
        }
        return (React.createElement(PopoverOverlay_1.default, Object.assign({ id: this.id, activator: this.activatorNode, onClose: this.handleClose }, rest), children));
    }
    render() {
        const { activatorWrapper: WRAPPERCOMPONENT = 'div' } = this.props;
        return (React.createElement(WRAPPERCOMPONENT, { ref: this.setActivator }, React.Children.only(this.props.activator)));
    }
    setAccessibilityAttributes() {
        const { id, activatorContainer } = this;
        if (activatorContainer == null) {
            return;
        }
        const firstFocusable = focus_1.findFirstFocusableNode(activatorContainer);
        const focusableActivator = firstFocusable || activatorContainer;
        focusableActivator.tabIndex = 0;
        focusableActivator.setAttribute('aria-controls', id);
        focusableActivator.setAttribute('aria-owns', id);
        focusableActivator.setAttribute('aria-haspopup', 'true');
        focusableActivator.setAttribute('aria-expanded', String(this.props.active));
    }
    handleClose(source) {
        if (!!this.props.onClose) {
            this.props.onClose(source);
        }
        if (this.activatorContainer == null) {
            return;
        }
        if (source === PopoverOverlay_1.CloseSource.FocusOut ||
            source === PopoverOverlay_1.CloseSource.EscapeKeypress) {
            focus_1.focusFirstFocusableNode(this.activatorContainer, false);
        }
    }
    setActivator(node) {
        if (node == null) {
            this.activatorNode = null;
            this.activatorContainer = null;
            return;
        }
        this.activatorNode = node.firstElementChild;
        this.activatorContainer = node;
    }
};
tslib_1.__decorate([
    autobind_1.default
], Popover.prototype, "handleClose", null);
tslib_1.__decorate([
    autobind_1.default
], Popover.prototype, "setActivator", null);
Popover = tslib_1.__decorate([
    components_1.layeredComponent({ idPrefix: 'Popover' })
], Popover);
exports.default = Popover;
