"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const dom_1 = require("@shopify/javascript-utilities/dom");
const fastdom_1 = require("@shopify/javascript-utilities/fastdom");
const focus_1 = require("@shopify/javascript-utilities/focus");
const styles_1 = require("@shopify/react-utilities/styles");
const components_1 = require("@shopify/react-utilities/components");
const animation_1 = require("@shopify/react-utilities/animation");
const types_1 = require("../../types");
const shared_1 = require("../shared");
const EventListener_1 = require("../EventListener");
const KeypressListener_1 = require("../KeypressListener");
const PositionedOverlay_1 = require("../PositionedOverlay");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const Pane_1 = require("./Pane");
const baseTheme = require("./Popover.scss");
var CloseSource;
(function (CloseSource) {
    CloseSource[CloseSource["Click"] = 0] = "Click";
    CloseSource[CloseSource["EscapeKeypress"] = 1] = "EscapeKeypress";
    CloseSource[CloseSource["FocusOut"] = 2] = "FocusOut";
    CloseSource[CloseSource["ScrollOut"] = 3] = "ScrollOut";
})(CloseSource = exports.CloseSource || (exports.CloseSource = {}));
class PopoverOverlay extends React.PureComponent {
    componentDidUpdate({ active: wasActive }) {
        const { active, preventAutofocus } = this.props;
        if (!active || preventAutofocus || !active || active === wasActive) {
            return;
        }
        if (this.contentNode == null) {
            return;
        }
        fastdom_1.write(() => {
            if (this.contentNode == null) {
                return;
            }
            const focusableChild = focus_1.findFirstFocusableNode(this.contentNode);
            (focusableChild || this.contentNode).focus();
        });
    }
    render() {
        const { active, theme } = this.props;
        const selector = `.${theme.popover}`;
        const markup = active
            ? (React.createElement(animation_1.TransitionGroup.TransitionChild, { render: this.renderOverlay, selector: selector, skipAppearing: true, skipEntering: true }))
            : null;
        return (React.createElement(animation_1.TransitionGroup, null, markup));
    }
    renderOverlay(transitionStatus) {
        const { active, activator, preferredPosition = 'below', } = this.props;
        return (React.createElement(PositionedOverlay_1.default, { active: active, activator: activator, preferredPosition: preferredPosition, render: this.renderPopover.bind(this, transitionStatus), onScrollOut: this.handleScrollOut }));
    }
    renderPopover(transitionStatus, overlayDetails) {
        const { measuring, left, desiredHeight, positioning, activatorRect, } = overlayDetails;
        const { id, children, sectioned, theme, } = this.props;
        const className = styles_1.classNames(theme.popover, transitionStatus && animationVariations(transitionStatus, theme), positioning === 'above' && theme.positionedAbove, measuring && theme.measuring);
        const tipMarkup = !measuring
            ? (React.createElement("div", { style: { left: activatorRect.center.x - left }, className: theme.tip }))
            : null;
        const contentStyles = measuring
            ? undefined
            : { height: desiredHeight };
        const content = (React.createElement("div", { id: id, tabIndex: -1, className: theme.content, style: contentStyles, ref: this.setContentNode }, renderPopoverContent(children, { sectioned })));
        return (React.createElement("div", Object.assign({ className: className }, shared_1.overlay.props),
            React.createElement(EventListener_1.default, { event: "click", handler: this.handleClick }),
            React.createElement(EventListener_1.default, { event: "touchstart", handler: this.handleClick }),
            React.createElement(KeypressListener_1.default, { keyCode: types_1.Keys.ESCAPE, handler: this.handleEscape }),
            tipMarkup,
            React.createElement("div", { className: theme.focusTracker, tabIndex: 0, onFocus: this.handleFocusFirstItem }),
            React.createElement("div", { className: theme.wrapper }, content),
            React.createElement("div", { className: theme.focusTracker, tabIndex: 0, onFocus: this.handleFocusLastItem })));
    }
    setContentNode(node) {
        this.contentNode = node;
    }
    handleClick(event) {
        const target = event.target;
        const { contentNode, props: { activator, onClose } } = this;
        if ((contentNode != null && dom_1.nodeContainsDescendant(contentNode, target)) ||
            dom_1.nodeContainsDescendant(activator, target)) {
            return;
        }
        onClose(CloseSource.Click);
    }
    handleScrollOut() {
        this.props.onClose(CloseSource.ScrollOut);
    }
    handleEscape() {
        this.props.onClose(CloseSource.EscapeKeypress);
    }
    handleFocusFirstItem() {
        this.props.onClose(CloseSource.FocusOut);
    }
    handleFocusLastItem() {
        this.props.onClose(CloseSource.FocusOut);
    }
}
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "renderOverlay", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "renderPopover", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "setContentNode", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "handleClick", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "handleScrollOut", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "handleEscape", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "handleFocusFirstItem", null);
tslib_1.__decorate([
    autobind_1.default
], PopoverOverlay.prototype, "handleFocusLastItem", null);
function renderPopoverContent(children, props) {
    const childrenArray = React.Children.toArray(children);
    if (components_1.isElementOfType(childrenArray[0], Pane_1.default)) {
        return childrenArray;
    }
    return components_1.wrapWithComponent(childrenArray, Pane_1.default, props);
}
function animationVariations(status, theme) {
    switch (status) {
        case animation_1.TransitionStatus.Leaving:
            return theme.leaving;
        default:
            return null;
    }
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.POPOVER, baseTheme)(PopoverOverlay);
