"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const events_1 = require("@shopify/javascript-utilities/events");
const geometry_1 = require("@shopify/javascript-utilities/geometry");
const dom_1 = require("@shopify/javascript-utilities/dom");
const Scrollable_1 = require("../Scrollable");
const shared_1 = require("../shared");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const math_1 = require("./math");
const baseTheme = require("./PositionedOverlay.scss");
class PositionedOverlay extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            measuring: true,
            activatorRect: geometry_1.getRectForNode(this.props.activator),
            left: 0,
            top: 0,
            height: 0,
            positioning: 'below',
            zIndex: -1,
            outsideScrollableContainer: false,
        };
    }
    componentDidMount() {
        this.scrollableContainer = Scrollable_1.forNode(this.props.activator);
        events_1.addEventListener(this.scrollableContainer, 'scroll', this.handleMeasurement);
        events_1.addEventListener(window, 'resize', this.handleMeasurement);
        this.handleMeasurement();
    }
    componentDidUpdate() {
        const { outsideScrollableContainer, top } = this.state;
        const { onScrollOut, active } = this.props;
        if (active && onScrollOut != null && top !== 0 && outsideScrollableContainer) {
            onScrollOut();
        }
    }
    componentWillUnmount() {
        events_1.removeEventListener(this.scrollableContainer, 'scroll', this.handleMeasurement);
        events_1.removeEventListener(window, 'resize', this.handleMeasurement);
    }
    render() {
        const { left, top, zIndex } = this.state;
        const { render, theme } = this.props;
        return (React.createElement("div", { className: theme.positionedOverlay, style: { top, left, zIndex }, ref: (input) => {
                this.setOverlay(input);
            } }, render(this.overlayDetails())));
    }
    overlayDetails() {
        const { measuring, left, positioning, height, activatorRect } = this.state;
        return {
            measuring,
            left,
            positioning,
            activatorRect,
            desiredHeight: height,
        };
    }
    setOverlay(node) {
        this.overlay = node;
    }
    handleMeasurement() {
        this.setState({
            left: 0,
            top: 0,
            height: 0,
            positioning: 'below',
            measuring: true,
        }, () => {
            const { activator, preferredPosition = 'below', onScrollOut, } = this.props;
            const activatorRect = geometry_1.getRectForNode(activator);
            const overlayRect = geometry_1.getRectForNode(this.overlay);
            const scrollableContainerRect = geometry_1.getRectForNode(this.scrollableContainer);
            const overlayMargins = this.overlay.firstElementChild
                ? getMarginsForNode(this.overlay.firstElementChild)
                : { activator: 0, container: 0, horizontal: 0 };
            const containerRect = geometry_1.getRectForNode(window);
            const zIndex = getZIndexForLayerFromNode(activator) + 1;
            const verticalPosition = math_1.calculateVerticalPosition(activatorRect, overlayRect, overlayMargins, scrollableContainerRect, containerRect, preferredPosition);
            const horizontalPosition = math_1.calculateHorizontalPosition(activatorRect, overlayRect, containerRect);
            this.setState({
                zIndex,
                measuring: false,
                activatorRect: geometry_1.getRectForNode(activator),
                left: window.scrollX + horizontalPosition,
                top: window.scrollY + verticalPosition.top,
                height: verticalPosition.height,
                positioning: verticalPosition.positioning,
                outsideScrollableContainer: onScrollOut != null && math_1.rectIsOutsideOfRect(activatorRect, scrollableContainerRect),
            });
        });
    }
}
tslib_1.__decorate([
    autobind_1.default
], PositionedOverlay.prototype, "overlayDetails", null);
tslib_1.__decorate([
    autobind_1.default
], PositionedOverlay.prototype, "setOverlay", null);
tslib_1.__decorate([
    autobind_1.default
], PositionedOverlay.prototype, "handleMeasurement", null);
function getMarginsForNode(node) {
    const styles = window.getComputedStyle(node);
    return {
        activator: parseFloat(styles.marginTop || ''),
        container: parseFloat(styles.marginBottom || ''),
        horizontal: parseFloat(styles.marginLeft || ''),
    };
}
function getZIndexForLayerFromNode(node) {
    const layerNode = dom_1.closest(node, shared_1.layer.selector) || document.body;
    const zIndex = parseInt(window.getComputedStyle(layerNode).zIndex || '0', 10);
    return isNaN(zIndex) ? 0 : zIndex;
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.POSITIONED_OVERLAY, baseTheme)(PositionedOverlay);
