"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const utils_1 = require("./utils");
const cellMetaDataShape = require('./PropTypeShapes/CellMetaDataShape');
require("./themes/react-data-grid-row.scss");
class RowGroup extends react_1.Component {
    constructor(props) {
        super(props);
        this.onRowExpandToggle = this.onRowExpandToggle.bind(this);
        this.onRowExpandClick = this.onRowExpandClick.bind(this);
        this.setScrollLeft = this.setScrollLeft.bind(this);
    }
    onRowExpandToggle(expand) {
        let shouldExpand = expand == null ? !this.props.isExpanded : expand;
        let meta = this.props.cellMetaData;
        if (meta != null && meta.onRowExpandToggle && typeof (meta.onRowExpandToggle) === 'function') {
            meta.onRowExpandToggle({ rowIdx: this.props.idx, shouldExpand: shouldExpand, columnGroupName: this.props.columnGroupName, name: this.props.name });
        }
    }
    onRowExpandClick() {
        this.onRowExpandToggle(!this.props.isExpanded);
    }
    setScrollLeft(scrollLeft) {
        if (this.rowGroupRenderer) {
            this.rowGroupRenderer.setScrollLeft ? this.rowGroupRenderer.setScrollLeft(scrollLeft) : null;
        }
    }
    render() {
        let lastColumn = utils_1.default.last(this.props.columns);
        let style = { width: lastColumn.left + lastColumn.width };
        return (react_1.default.createElement("div", { style: style, className: "react-grid-row-group" },
            react_1.default.createElement(this.props.renderer, Object.assign({ ref: (node) => { this.rowGroupRenderer = node; } }, this.props, { onRowExpandClick: this.onRowExpandClick, onRowExpandToggle: this.onRowExpandToggle }))));
    }
}
RowGroup.propTypes = {
    height: react_1.PropTypes.number.isRequired,
    columns: react_1.PropTypes.oneOfType([react_1.PropTypes.object, react_1.PropTypes.array]).isRequired,
    row: react_1.PropTypes.any.isRequired,
    cellRenderer: react_1.PropTypes.func,
    cellMetaData: react_1.PropTypes.shape(cellMetaDataShape),
    isSelected: react_1.PropTypes.bool,
    idx: react_1.PropTypes.number.isRequired,
    expandedRows: react_1.PropTypes.arrayOf(react_1.PropTypes.object),
    extraClasses: react_1.PropTypes.string,
    forceUpdate: react_1.PropTypes.bool,
    subRowDetails: react_1.PropTypes.object,
    isRowHovered: react_1.PropTypes.bool,
    colVisibleStart: react_1.PropTypes.number.isRequired,
    colVisibleEnd: react_1.PropTypes.number.isRequired,
    colDisplayStart: react_1.PropTypes.number.isRequired,
    colDisplayEnd: react_1.PropTypes.number.isRequired,
    isScrolling: react_1.default.PropTypes.bool.isRequired,
    columnGroupName: react_1.PropTypes.string.isRequired,
    isExpanded: react_1.PropTypes.bool.isRequired,
    treeDepth: react_1.PropTypes.number.isRequired,
    name: react_1.PropTypes.string.isRequired,
    renderer: react_1.PropTypes.func
};
const DefaultRowGroupRenderer = (props) => {
    let treeDepth = props.treeDepth || 0;
    let marginLeft = treeDepth * 20;
    let style = {
        height: '50px',
        border: '1px solid #dddddd',
        paddingTop: '15px',
        paddingLeft: '5px'
    };
    let onKeyDown = (e) => {
        if (e.key === 'ArrowLeft') {
            props.onRowExpandToggle(false);
        }
        if (e.key === 'ArrowRight') {
            props.onRowExpandToggle(true);
        }
        if (e.key === 'Enter') {
            props.onRowExpandToggle(!props.isExpanded);
        }
    };
    return (react_1.default.createElement("div", { style: style, onKeyDown: onKeyDown, tabIndex: 0 },
        react_1.default.createElement("span", { className: "row-expand-icon", style: { float: 'left', marginLeft: marginLeft, cursor: 'pointer' }, onClick: props.onRowExpandClick }, props.isExpanded ? String.fromCharCode('9660') : String.fromCharCode('9658')),
        react_1.default.createElement("strong", null,
            props.columnGroupName,
            ": ",
            props.name)));
};
DefaultRowGroupRenderer.propTypes = {
    onRowExpandClick: react_1.PropTypes.func.isRequired,
    onRowExpandToggle: react_1.PropTypes.func.isRequired,
    isExpanded: react_1.PropTypes.bool.isRequired,
    treeDepth: react_1.PropTypes.number.isRequired,
    name: react_1.PropTypes.string.isRequired,
    columnGroupName: react_1.PropTypes.string.isRequired,
    hideColumnName: react_1.PropTypes.bool
};
RowGroup.defaultProps = {
    renderer: DefaultRowGroupRenderer
};
exports.default = RowGroup;
