"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const events_1 = require("@shopify/javascript-utilities/events");
const dom_1 = require("@shopify/javascript-utilities/dom");
const styles_1 = require("@shopify/react-utilities/styles");
const shared_1 = require("../shared");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Scrollable.scss");
class Scrollable extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            topShadow: false,
            bottomShadow: false,
        };
    }
    componentDidMount() {
        if (this.scrollArea == null || !this.props.shadow) {
            return;
        }
        events_1.addEventListener(this.scrollArea, 'scroll', this.handleScroll);
        this.handleScroll();
    }
    componentWillUnmount() {
        if (this.scrollArea == null || !this.props.shadow) {
            return;
        }
        events_1.removeEventListener(this.scrollArea, 'scroll', this.handleScroll);
    }
    render() {
        const { topShadow, bottomShadow } = this.state;
        const _a = this.props, { children, className, horizontal, vertical = true, shadow, theme } = _a, rest = tslib_1.__rest(_a, ["children", "className", "horizontal", "vertical", "shadow", "theme"]);
        const finalClassName = styles_1.classNames(className, theme.scrollable, vertical && theme.vertical, horizontal && theme.horizontal, topShadow && theme.hasTopShadow, bottomShadow && theme.hasBottomShadow);
        return (React.createElement("div", Object.assign({ className: finalClassName }, shared_1.scrollable.props, rest, { ref: (input) => { this.setScrollArea(input); } }), children));
    }
    setScrollArea(scrollArea) {
        this.scrollArea = scrollArea;
    }
    handleScroll() {
        const { scrollArea } = this;
        if (scrollArea == null || !this.props.shadow) {
            return;
        }
        const { scrollTop, clientHeight, scrollHeight } = scrollArea;
        const shouldBottomShadow = !(scrollTop + clientHeight >= scrollHeight);
        const shouldTopShadow = scrollTop > 0;
        this.setState({
            topShadow: shouldTopShadow,
            bottomShadow: shouldBottomShadow,
        });
    }
}
tslib_1.__decorate([
    autobind_1.default
], Scrollable.prototype, "setScrollArea", null);
tslib_1.__decorate([
    autobind_1.default
], Scrollable.prototype, "handleScroll", null);
function forNode(node) {
    return dom_1.closest(node, shared_1.scrollable.selector) || document.body;
}
exports.forNode = forNode;
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.SCROLLABLE, baseTheme)(Scrollable);
