"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const styles_1 = require("@shopify/react-utilities/styles");
const other_1 = require("@shopify/javascript-utilities/other");
const Labelled_1 = require("../Labelled");
const Icon_1 = require("../Icon");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./Select.scss");
const arrow_svg_1 = require("./icons/arrow.svg");
const PLACEHOLDER_VALUE = '__placeholder__';
const getUniqueID = other_1.createUniqueIDFactory('Select');
const select = ({ id = getUniqueID(), name, groups, options, labelHidden, labelAction, helpText, label, error, value, placeholder, disabled, onChange, onFocus, onBlur, theme, }) => {
    let optionsMarkup;
    if (options != null) {
        optionsMarkup = options.map(renderOption);
    }
    else if (groups != null) {
        optionsMarkup = groups.map(renderGroup);
    }
    const isPlaceholder = value == null && placeholder != null;
    const className = styles_1.classNames(theme.select, error && theme.error, disabled && theme.disabled, isPlaceholder && theme.placeholder);
    const handleChange = onChange
        ? ((event) => onChange(event.currentTarget.value))
        : undefined;
    const describedBy = [];
    if (helpText) {
        describedBy.push(Labelled_1.helpTextID(id));
    }
    if (error && typeof error === 'string') {
        describedBy.push(Labelled_1.errorID(id));
    }
    const placeholderOption = isPlaceholder
        ? React.createElement("option", { label: placeholder, value: PLACEHOLDER_VALUE, disabled: true, hidden: true })
        : null;
    return (React.createElement(Labelled_1.default, { id: id, label: label, errors: error, action: labelAction, labelHidden: labelHidden, helpText: helpText },
        React.createElement("div", { className: className },
            React.createElement("select", { id: id, name: name ? name : 'select', value: value, defaultValue: PLACEHOLDER_VALUE, className: theme.input, disabled: disabled, onFocus: onFocus, onBlur: onBlur, onChange: handleChange, "aria-invalid": Boolean(error), "aria-describedby": describedBy.length ? describedBy.join(' ') : undefined },
                placeholderOption,
                optionsMarkup),
            React.createElement("div", { className: theme.icon },
                React.createElement(Icon_1.default, { source: arrow_svg_1.default })),
            React.createElement("div", { className: theme.backdrop }))));
};
exports.UnthemedSelect = select;
function renderOption(option) {
    if (typeof option === 'string') {
        return React.createElement("option", { key: option, value: option }, option);
    }
    else {
        return React.createElement("option", { key: option.value, value: option.value }, option.label);
    }
}
function renderGroup(groupOrOption) {
    if (groupOrOption.hasOwnProperty('title')) {
        const { title, options } = groupOrOption;
        return (React.createElement("optgroup", { label: title, key: title }, options.map(renderOption)));
    }
    return renderOption(groupOrOption);
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.SELECT, baseTheme)(select);
