"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Spinner_1 = require("../Spinner");
describe('<Spinner />', () => {
    describe('When default props provided', () => {
        const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, null));
        it('Basic Spinner have rendered one span element', () => {
            expect(spinnerWrapper.find('span')).toHaveLength(1);
        });
    });
    describe('size property ', () => {
        describe('When not set', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, null));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('varify size property when it is not set', () => {
                expect(spinnerWrapper.prop('size')).toBeFalsy();
            });
        });
        describe('size property large applied', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, { size: "large" }));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('varify size property when it set to large', () => {
                expect(spinnerWrapper.prop('size')).toBe('large');
            });
        });
        describe('when size property small applied', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, { size: "small" }));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('varify size property when it set to small', () => {
                expect(spinnerWrapper.prop('size')).toBe('small');
            });
        });
    });
    describe('color property', () => {
        describe('when not set', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, null));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('Varify color property when it is not set', () => {
                expect(spinnerWrapper.prop('color')).toBeFalsy();
            });
        });
        describe('when set to white', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, { color: "white" }));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('Varify color property when it is set to white', () => {
                expect(spinnerWrapper.prop('color')).toBe('white');
            });
        });
    });
    describe('accessibilityLabel property', () => {
        describe('when not set', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, null));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('Varify accessibilityLabel property when it is not set', () => {
                expect(spinnerWrapper.prop('accessibilityLabel')).toBeFalsy();
            });
            it('Varify aria-label property of span when accessibilityLabel prop is not set', () => {
                expect(spinnerWrapper.find('span').prop('aria-label')).toBeFalsy();
            });
        });
        describe('when set to loading', () => {
            const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, { accessibilityLabel: "loading" }));
            it('Basic Spinner have rendered one span element', () => {
                expect(spinnerWrapper.find('span')).toHaveLength(1);
            });
            it('Varify accessibilityLabel property when it is set', () => {
                expect(spinnerWrapper.prop('accessibilityLabel')).toBe('loading');
            });
            it('Varify aria-label property of span when accessibilityLabel prop is set', () => {
                expect(spinnerWrapper.find('span').prop('aria-label')).toBe('loading');
            });
        });
    });
    describe('verify all property together', () => {
        const spinnerWrapper = enzyme_1.mount(React.createElement(Spinner_1.default, { color: "inkLightest", size: "small", accessibilityLabel: "loading" }));
        it('varify size property when it set to small', () => {
            expect(spinnerWrapper.prop('size')).toBe('small');
        });
        it('Basic Spinner have rendered one span element', () => {
            expect(spinnerWrapper.find('span')).toHaveLength(1);
        });
        it('Varify color property when it is set to inkLightest', () => {
            expect(spinnerWrapper.prop('color')).toBe('inkLightest');
        });
        it('Varify accessibilityLabel property when it is set', () => {
            expect(spinnerWrapper.prop('accessibilityLabel')).toBe('loading');
        });
        it('Varify aria-label property of span when accessibilityLabel prop is not set', () => {
            expect(spinnerWrapper.find('span').prop('aria-label')).toBe('loading');
        });
    });
});
