"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Tag_1 = require("../Tag");
const theme = {
    tag: 'Wholesale',
    button: 'Button',
};
describe('<Tag />', () => {
    describe('onRemove property', () => {
        it('should verify the remove', () => {
            const onRemoveClick = jest.fn();
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, { onRemove: onRemoveClick }));
            tagWrapper.find('button').simulate('click');
            expect(onRemoveClick).toHaveBeenCalledTimes(1);
        });
    });
    describe('when default props are provided', () => {
        it('basic tag should have rendered 3 span elements', () => {
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, { theme: theme }));
            expect(tagWrapper.find('span')).toHaveLength(3);
        });
        it('should have default Tag css class on span', () => {
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, { theme: theme }));
            expect(tagWrapper.find('span').at(0).hasClass('Wholesale')).toBe(true);
        });
        it('should have default Icon-Button css class on span', () => {
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, { theme: theme }));
            expect(tagWrapper.find('button').hasClass('Button')).toBe(true);
        });
    });
    describe('children property ', () => {
        it('should verify the children text', () => {
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, null, "Wholesale"));
            expect(tagWrapper.prop('children')).toBe('Wholesale');
        });
        it('should verify the children', () => {
            const tagWrapper = enzyme_1.mount(React.createElement(Tag_1.default, { children: "Wholesale" }));
            expect(tagWrapper.prop('children')).toBe('Wholesale');
        });
    });
});
