"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const EventListener_1 = require("../EventListener");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./TextField.scss");
class Resizer extends React.PureComponent {
    componentDidMount() {
        this.handleHeightCheck();
        if (process.env.NODE_ENV === 'development') {
            // We need to defer the calculation in development so the
            // styles have time to be injected.
            setTimeout(this.handleHeightCheck, 0);
        }
    }
    componentDidUpdate() {
        this.handleHeightCheck();
    }
    render() {
        const { contents, minimumLines } = this.props;
        const minimumLinesMarkup = minimumLines
            ? (React.createElement("div", { ref: (input) => { this.setMinimumLinesNode(input); }, className: this.props.theme.dummyInput, dangerouslySetInnerHTML: { __html: getContentsForMinimumLines(minimumLines) } }))
            : null;
        return (React.createElement("div", { "aria-hidden": true, className: this.props.theme.resizer },
            React.createElement(EventListener_1.default, { event: "resize", handler: this.handleHeightCheck }),
            React.createElement("div", { ref: (input) => { this.setContentNode(input); }, className: this.props.theme.dummyInput, dangerouslySetInnerHTML: { __html: getFinalContents(contents) } }),
            minimumLinesMarkup));
    }
    handleHeightCheck() {
        const contentHeight = this.contentNode.offsetHeight;
        const minimumHeight = this.setMinimumLinesNode ? this.minimumLinesNode.offsetHeight : 0;
        const newHeight = Math.max(contentHeight, minimumHeight);
        const { currentHeight, onHeightChange } = this.props;
        if (newHeight !== currentHeight) {
            onHeightChange(newHeight);
        }
    }
    setContentNode(node) {
        this.contentNode = node;
    }
    setMinimumLinesNode(node) {
        this.minimumLinesNode = node;
    }
}
tslib_1.__decorate([
    autobind_1.default
], Resizer.prototype, "handleHeightCheck", null);
tslib_1.__decorate([
    autobind_1.default
], Resizer.prototype, "setContentNode", null);
tslib_1.__decorate([
    autobind_1.default
], Resizer.prototype, "setMinimumLinesNode", null);
const ENTITIES_TO_REPLACE = {
    '&': '&amp;',
    '<': '&lt;',
    '>': '&gt;',
    '\n': '<br>',
};
const REPLACE_REGEX = /[\n&<>]/g;
function replaceEntity(entity) {
    return ENTITIES_TO_REPLACE[entity] || entity;
}
function getContentsForMinimumLines(minimumLines) {
    let content = '';
    for (let line = 0; line < minimumLines; line += 1) {
        content += '<br>';
    }
    return content;
}
function getFinalContents(contents) {
    return contents
        ? `${contents.replace(REPLACE_REGEX, replaceEntity)}<br>`
        : '<br>';
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.TEXT_FIELD, baseTheme)(Resizer);
