"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const other_1 = require("@shopify/javascript-utilities/other");
const styles_1 = require("@shopify/react-utilities/styles");
const Labelled_1 = require("../Labelled");
const Connected_1 = require("../Connected");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const baseTheme = require("./TextField.scss");
const Resizer_1 = require("./Resizer");
const Spinner_1 = require("./Spinner");
const getUniqueID = other_1.createUniqueIDFactory('TextField');
class TextField extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = { height: null };
    }
    render() {
        const _a = this.props, { id = getUniqueID(), value = '', placeholder, disabled, readOnly, autoFocus, type, name, errors, multiline, connectedRight, connectedLeft, label, labelAction, labelHidden, helpText, enableTextCounter, maxLength, prefix, suffix, required, theme, onFocus, onBlur, autoComplete, style, resizable } = _a, rest = tslib_1.__rest(_a, ["id", "value", "placeholder", "disabled", "readOnly", "autoFocus", "type", "name", "errors", "multiline", "connectedRight", "connectedLeft", "label", "labelAction", "labelHidden", "helpText", "enableTextCounter", "maxLength", "prefix", "suffix", "required", "theme", "onFocus", "onBlur", "autoComplete", "style", "resizable"]);
        const { height } = this.state;
        const className = styles_1.classNames(theme.textField, Boolean(value) && theme.hasValue, disabled && theme.disabled, readOnly && theme.readOnly, errors && theme.error, multiline && theme.multiline, resizable && theme.resizable);
        const prefixMarkup = prefix
            ? React.createElement("div", { onClick: this.handleInputFocus, className: theme.prefix, id: `${id}prefix` }, prefix)
            : null;
        const suffixMarkup = suffix
            ? React.createElement("div", { onClick: this.handleInputFocus, className: theme.suffix, id: `${id}suffix` }, suffix)
            : null;
        const spinnerMarkup = type === 'number'
            ? React.createElement(Spinner_1.default, { onClick: this.handleInputFocus, onChange: this.handleNumberChange })
            : null;
        const componentStyle = (multiline && height) ? Object.assign({ height }, style) : style;
        const resizer = multiline === null
            ? null
            : (React.createElement(Resizer_1.default, { contents: value || placeholder, currentHeight: height, minimumLines: typeof multiline === 'number' ? multiline : 3, onHeightChange: this.handleExpandingResize }));
        let counterTextMarkup;
        if (enableTextCounter) {
            const maxLengthString = maxLength ? '/' + maxLength : '';
            const textCount = this.props.value ? this.props.value.toString().length : 0;
            const minLengthRed = this.props.minLength ? this.props.minLength : 0;
            counterTextMarkup =
                React.createElement("div", { className: theme.counterText, id: `${id}counter` },
                    React.createElement("span", { className: minLengthRed > textCount ? theme.red : '' }, textCount),
                    maxLengthString);
        }
        const describedBy = [];
        if (errors) {
            describedBy.push(Labelled_1.errorID(id));
        }
        if (helpText) {
            describedBy.push(Labelled_1.helpTextID(id));
        }
        const labelledBy = [Labelled_1.labelID(id)];
        if (prefix) {
            labelledBy.push(`${id}Prefix`);
        }
        if (suffix) {
            labelledBy.push(`${id}Suffix`);
        }
        const input = React.createElement(multiline ? 'textarea' : 'input', Object.assign({}, rest, { name,
            id,
            type,
            disabled,
            readOnly,
            autoFocus,
            value,
            placeholder,
            required, onFocus: this.handleInputOnFocus, onBlur: this.handleInputOnBlur, style: componentStyle, formNoValidate: true, autoComplete: normalizeAutoComplete(autoComplete), className: theme.input, onChange: this.onChange, onKeyDown: this.onKeyDown, ref: this.setInput, 'aria-required': required ? true : false, 'aria-describedby': describedBy.length ? describedBy.join(' ') : undefined, 'aria-labelledby': labelledBy.join(' '), 'aria-invalid': Boolean(errors) }));
        const hasValue = (!!this.props.value && this.props.value.length > 0);
        return (React.createElement(Labelled_1.default, { label: label, id: id, errors: errors, action: labelAction, labelHidden: labelHidden, helpText: helpText, focused: this.state.focused, hasValue: hasValue, required: required },
            React.createElement(Connected_1.default, { left: connectedLeft, right: connectedRight },
                React.createElement("div", { className: className },
                    prefixMarkup,
                    input,
                    suffixMarkup,
                    spinnerMarkup,
                    React.createElement("div", { className: theme.backdrop }),
                    resizer)),
            counterTextMarkup));
    }
    setInput(input) {
        this.input = input;
    }
    handleNumberChange(steps) {
        const { onChange, value, step = 1, min = -Infinity, max = Infinity } = this.props;
        if (onChange == null) {
            return;
        }
        const numericValue = value ? parseFloat(value) : 0;
        if (isNaN(numericValue)) {
            return;
        }
        const newValue = Math.min(max, Math.max(numericValue + (steps * step), min));
        onChange(String(newValue));
    }
    handleExpandingResize(height) {
        this.setState({ height });
    }
    onChange(event) {
        const { onChange } = this.props;
        if (onChange == null) {
            return;
        }
        const value = this.props.value ? this.props.value : '';
        const maxLength = this.props.maxLength ? this.props.maxLength : Number.POSITIVE_INFINITY;
        if (value.length < maxLength && event.currentTarget.value.length <= maxLength) {
            onChange(event.currentTarget.value);
        }
    }
    onKeyDown(e) {
        const { onChange } = this.props;
        if (onChange == null) {
            return;
        }
        const value = this.props.value ? this.props.value : '';
        const maxLength = this.props.maxLength ? this.props.maxLength : Number.POSITIVE_INFINITY;
        if (value.length >= maxLength && e.keyCode === 8) {
            onChange(e.currentTarget.value.slice(0, e.currentTarget.value.length - 1));
            e.preventDefault();
        }
    }
    handleInputOnFocus(e) {
        this.setState((prevState) => (Object.assign({}, prevState, { focused: true })));
        const { onFocus } = this.props;
        if (onFocus == null) {
            return;
        }
        onFocus(e);
    }
    handleInputOnBlur(e) {
        this.setState((prevState) => (Object.assign({}, prevState, { focused: false })));
        const { onBlur } = this.props;
        if (onBlur == null) {
            return;
        }
        onBlur(e);
    }
    handleInputFocus() {
        this.input.focus();
    }
}
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "setInput", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleNumberChange", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleExpandingResize", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "onChange", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "onKeyDown", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleInputOnFocus", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleInputOnBlur", null);
tslib_1.__decorate([
    autobind_1.default
], TextField.prototype, "handleInputFocus", null);
exports.UnthemedTextField = TextField;
function normalizeAutoComplete(autoComplete) {
    if (autoComplete == null) {
        return autoComplete;
    }
    return autoComplete ? 'on' : 'off';
}
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.TEXT_FIELD, baseTheme)(TextField);
