"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const react_css_themr_1 = require("react-css-themr");
const components_1 = require("@shopify/react-utilities/components");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const other_1 = require("@shopify/javascript-utilities/other");
const focus_1 = require("@shopify/javascript-utilities/focus");
const ThemeIdentifiers_1 = require("../ThemeIdentifiers");
const TooltipOverlay_1 = require("./TooltipOverlay");
const baseTheme = require("./Tooltip.scss");
const getUniqueID = other_1.createUniqueIDFactory('TooltipContent');
let Tooltip = class Tooltip extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            active: false,
        };
        this.id = getUniqueID();
    }
    componentDidMount() {
        this.setAccessibilityAttributes();
    }
    componentDidUpdate() {
        this.setAccessibilityAttributes();
    }
    renderLayer() {
        const { id, activatorNode } = this;
        if (activatorNode == null) {
            return null;
        }
        const { preferredPosition = 'below', active, light, content, theme, } = this.props;
        return (React.createElement(TooltipOverlay_1.default, { id: id, preferredPosition: preferredPosition, activator: activatorNode, active: active || this.state.active, onClose: other_1.noop, light: light },
            React.createElement("div", { className: theme.label }, content)));
    }
    render() {
        const { activatorWrapper: WRAPPERCOMPONENT = 'span' } = this.props;
        return (React.createElement(WRAPPERCOMPONENT, { onFocus: this.handleFocus, onBlur: this.handleBlur, onMouseEnter: this.handleMouseEnter, onMouseLeave: this.handleMouseLeave, ref: this.setActivator }, this.props.children));
    }
    setActivator(node) {
        if (node == null) {
            this.activatorNode = null;
            this.activatorContainer = null;
            return;
        }
        this.activatorNode = node.firstElementChild;
        this.activatorContainer = node;
    }
    handleFocus() {
        this.setState({ active: true });
    }
    handleBlur() {
        this.setState({ active: false });
    }
    handleMouseEnter() {
        this.setState({ active: true });
    }
    handleMouseLeave() {
        this.setState({ active: false });
    }
    setAccessibilityAttributes() {
        const { activatorContainer, id } = this;
        if (activatorContainer == null) {
            return;
        }
        const firstFocusable = focus_1.findFirstFocusableNode(activatorContainer);
        const accessibilityNode = firstFocusable || activatorContainer;
        accessibilityNode.tabIndex = 0;
        accessibilityNode.setAttribute('aria-describedby', id);
    }
};
tslib_1.__decorate([
    autobind_1.default
], Tooltip.prototype, "setActivator", null);
tslib_1.__decorate([
    autobind_1.default
], Tooltip.prototype, "handleFocus", null);
tslib_1.__decorate([
    autobind_1.default
], Tooltip.prototype, "handleBlur", null);
tslib_1.__decorate([
    autobind_1.default
], Tooltip.prototype, "handleMouseEnter", null);
tslib_1.__decorate([
    autobind_1.default
], Tooltip.prototype, "handleMouseLeave", null);
Tooltip = tslib_1.__decorate([
    components_1.layeredComponent({ idPrefix: 'Tooltip' })
], Tooltip);
exports.default = react_css_themr_1.themr(ThemeIdentifiers_1.TOOLTIP, baseTheme)(Tooltip);
