"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = require("react");
const autobind_1 = require("@shopify/javascript-utilities/autobind");
const styles_1 = require("@shopify/react-utilities/styles");
const shared_1 = require("../shared");
const PositionedOverlay_1 = require("../PositionedOverlay");
const styles = require("./Tooltip.scss");
class TooltipOverlay extends React.PureComponent {
    render() {
        const markup = this.props.active
            ? this.renderOverlay()
            : null;
        return markup;
    }
    renderOverlay() {
        const { active, activator, preferredPosition = 'below', } = this.props;
        return (React.createElement(PositionedOverlay_1.default, { active: active, activator: activator, preferredPosition: preferredPosition, render: this.renderTooltip.bind(this) }));
    }
    renderTooltip(overlayDetails) {
        const { left, measuring, desiredHeight, positioning, activatorRect, } = overlayDetails;
        const { id, children, light } = this.props;
        const tipStyle = calculateTipPosition(activatorRect.center.x, left);
        const containerClassName = styles_1.classNames(styles.tooltip, light && styles.light, measuring && styles.measuring, positioning === 'above' && styles.positionedAbove);
        const contentStyles = measuring
            ? undefined
            : { maxHeight: desiredHeight };
        const tipMarkup = !measuring
            ? React.createElement("div", { style: tipStyle, className: styles.tip })
            : null;
        return (React.createElement("div", Object.assign({ className: containerClassName }, shared_1.layer.props),
            tipMarkup,
            React.createElement("div", { className: styles.wrapper },
                React.createElement("div", { id: id, role: "tooltip", className: styles.content, style: contentStyles }, children))));
    }
}
tslib_1.__decorate([
    autobind_1.default
], TooltipOverlay.prototype, "renderOverlay", null);
tslib_1.__decorate([
    autobind_1.default
], TooltipOverlay.prototype, "renderTooltip", null);
exports.default = TooltipOverlay;
function calculateTipPosition(activatorRectXAxisCenter, left) {
    return { left: activatorRectXAxisCenter - left };
}
