"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const enzyme_1 = require("enzyme");
const Tooltip_1 = require("../Tooltip");
const Link_1 = require("../../Link");
const theme = {
    tooltip: 'Tooltip',
    measuring: 'measuring',
    positionedAbove: 'positionedAbove',
    light: 'light',
    Wrapper: 'Wrapper',
    Content: 'Content',
    Tip: 'Tip',
    Label: 'Label',
};
describe('<Tooltip />', () => {
    describe('when default props are provided', () => {
        it('basic tooltip should have rendered one span element', () => {
            const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme }));
            expect(tooltipWrapper.find('span')).toHaveLength(1);
        });
    });
    describe('children property', () => {
        describe('when set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify children property is defined as link', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.children().prop('children')).toBe('Order #1001');
            });
        });
        describe('when not set', () => {
            it('basic tooltip should have rendered one span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme }));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should not have children property', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme }));
                expect(tooltipWrapper.find('children')).toHaveLength(0);
            });
            it('should verify children property is not defined', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels." }));
                expect(tooltipWrapper.prop('children')).toBeUndefined();
            });
        });
    });
    describe('content property', () => {
        describe('when set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify content property is available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('content')).toBe('This order has shipping labels.');
            });
        });
    });
    describe('active property', () => {
        describe('when set to true', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", active: true, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify active property is available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", active: true, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('active')).toBe(true);
            });
        });
        describe('when set to false', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", active: false, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify active property is available and set to false', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", active: false, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('active')).toBe(false);
            });
        });
        describe('when not set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify active property is not defined', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('active')).toBeUndefined();
            });
            it('should verify active property is not available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('active')).toHaveLength(0);
            });
        });
    });
    describe('light property', () => {
        describe('when set to true', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", light: true, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify light property is available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", light: true, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('light')).toBe(true);
            });
        });
        describe('when set to false', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", light: false, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify light property is available and set as false', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", light: false, theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('light')).toBe(false);
            });
        });
        describe('when not set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify light property is not defined', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('light')).toBeUndefined();
            });
            it('should verify light property is not available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('light')).toHaveLength(0);
            });
        });
    });
    describe('preferredPosition property', () => {
        describe('when set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", preferredPosition: "below", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify preferredPosition property when position as below', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", preferredPosition: "below", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('preferredPosition')).toBe('below');
            });
            it('should verify preferredPosition property when position as above', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", preferredPosition: "above", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('preferredPosition')).toBe('above');
            });
            it('should verify preferredPosition property when position as mostSpace', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", preferredPosition: "mostSpace", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('preferredPosition')).toBe('mostSpace');
            });
        });
        describe('when not set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify preferredPosition property is not defined', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('preferredPosition')).toBeUndefined();
            });
            it('should verify preferredPosition property is not available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('preferredPosition')).toHaveLength(0);
            });
        });
    });
    describe('activatorWrapper property', () => {
        describe('when set', () => {
            it('basic tooltip should have rendered no span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", activatorWrapper: "Test", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(0);
            });
            it('should have rendered with one activatorWrapper element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", activatorWrapper: "Test", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('Test')).toHaveLength(1);
            });
            it('should verify activatorWrapper property is available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", activatorWrapper: "Test", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('activatorWrapper')).toBe('Test');
            });
        });
        describe('when not set', () => {
            it('basic tooltip should have rendered 1 span element', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('span')).toHaveLength(1);
            });
            it('should verify activatorWrapper property is not defined', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.prop('activatorWrapper')).toBeUndefined();
            });
            it('should verify activatorWrapper property is not available', () => {
                const tooltipWrapper = enzyme_1.mount(React.createElement(Tooltip_1.default, { content: "This order has shipping labels.", theme: theme },
                    React.createElement(Link_1.default, null, "Order #1001")));
                expect(tooltipWrapper.find('activatorWrapper')).toHaveLength(0);
            });
        });
    });
});
