"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const { isValidElement } = React;
exports.firstChild = () => (props) => {
    const childrenArray = React.Children.toArray(props.children);
    return childrenArray[0] || null;
};
exports.getDisplayName = () => (COMPONENT) => {
    return COMPONENT.displayName || COMPONENT.name || 'COMPONENT';
};
/// Wraps `element` in `Component`, if it is not already an instance of
/// `Component`. If `props` is passed, those will be added as props on the
/// wrapped component. If `element` is null, the component is not wrapped.
function wrapWithComponent(element, COMPONENT, props) {
    if (element == null) {
        return null;
    }
    return isElementOfType(element, COMPONENT)
        ? element
        : React.createElement(COMPONENT, Object.assign({}, props), element);
}
exports.wrapWithComponent = wrapWithComponent;
/// In development, we compare based on the name of the function because
/// React Hot Loader proxies React components in order to make updates. In
/// production we can simply compare the components for equality.
const isComponent = (aComponent, anotherComponent) => {
    if (aComponent.displayName && anotherComponent.displayName) {
        const isAComponentThemed = aComponent.displayName.indexOf('Themed') === 0;
        const isAnotherComponentThemed = anotherComponent.displayName.indexOf('Themed') === 0;
        if ((isAComponentThemed && !isAnotherComponentThemed) ||
            (!isAComponentThemed && isAnotherComponentThemed)) {
            return false;
        }
        return aComponent.displayName === anotherComponent.displayName;
    }
    return aComponent === anotherComponent;
};
/// Checks whether `element` is a React element of type `Component` (or one of
/// the passed components, if `Component` is an array of React components).
function isElementOfType(element, component) {
    if (element == null || !isValidElement(element) || typeof element.type === 'string') {
        return false;
    }
    const { type } = element;
    const components = Array.isArray(component) ? component : [component];
    return components.some(aComponent => typeof type !== 'string' && isComponent(aComponent, type));
}
exports.isElementOfType = isElementOfType;
